@@ -577,7 +577,7 @@ class case:
             s.write(hline)
 
         s.write('  Environment variables\n')
-        ek = os.environ.keys()
+        ek = list(os.environ.keys())
         ek.sort()
         for k in ek:
             s.write('    ' + k + '=' + os.environ[k] + '\n')
@@ -777,7 +777,7 @@ ${KERNEL_ROOT_DIR}/bin/salome/appli_gen.py --prefix=%(applidir)s --config=%(conf
         for a in apps:
 
             s_path = os.path.join(bin_dir, a[0])
-            s = open(s_path                     , 'w')
+            s = open(s_path, 'w')
 
             cs_exec_environment.write_shell_shebang(s)
 
@@ -839,9 +839,6 @@ export SALOME_INSTANCE=$3
         e_path = os.path.join(self.exec_dir, 'mpmd_configfile')
         e = open(e_path, 'w')
 
-        if mpi_env.type != 'BGP_MPI': # Comment lines not accepted on BG/P
-            e.write('# MPMD configuration file for mpiexec\n')
-
         app_id = 0
 
         for d in self.syr_domains:
@@ -908,7 +905,7 @@ export SALOME_INSTANCE=$3
 
     def generate_solver_mpmd_configfile_bgq(self, n_procs, mpi_env):
         """
-        Generate MPMD mpiexec config file fo BG/Q.
+        Generate MPMD mpiexec config file for BG/Q.
         """
 
         e_path = os.path.join(self.exec_dir, 'mpmd_configfile')
@@ -1134,7 +1131,6 @@ $appli/runSession killSalome.py
 unset PYTHONHOME
 $appli/runAppli -t
 $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
-echo "exit \$?" >> $localexec
 
 """
         s.write(template % {'salomeenv': self.package.config.salome_env,
