@@ -252,7 +252,7 @@ elif test "x$cs_gcc" = "xicc"; then
 
   # Default compiler flags
   # (temporarily disable "operands evaluated in unspecified order" remark -- 981)
-  cflags_default="-strict-ansi -std=c99 -funsigned-char -Wall -Wcheck -Wshadow -Wpointer-arith -Wmissing-prototypes -Wuninitialized -Wunused -wd981"
+  cflags_default="-strict-ansi -std=c99 -restrict -funsigned-char -Wall -Wcheck -Wshadow -Wpointer-arith -Wmissing-prototypes -Wuninitialized -Wunused -wd981"
   cflags_default_dbg="-g -O0 -traceback -w2 -Wp64 -ftrapuv"
   cflags_default_opt="-O2"
   cflags_default_hot="-O3"
@@ -399,14 +399,7 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
     grep 'Blue Gene' $outfile > /dev/null
     if test "$?" = "0" ; then
       # Default compiler flags (we assume that MPI wrappers are used)
-      cs_ibm_bg_type=`grep 'Blue Gene' $outfile | sed -e 's/.*Blue Gene\/\([A-Z]\).*/\1/'`
-      if test "x$cs_ibm_bg_type" = "xP" ; then
-        cppflags_default="-I/bgsys/drivers/ppcfloor/arch/include"
-        cflags_default="-qlanglvl=extc99"
-        cflags_default_opt="-O3"
-        cflags_default_hot="-O3 -qhot"
-        cflags_default_dbg="-g"
-      elif test -f /bgsys/drivers/ppcfloor/cnk/bin/bgq_kernel.elf ; then
+      if test -f /bgsys/drivers/ppcfloor/cnk/bin/bgq_kernel.elf ; then
         cs_ibm_bg_type="Q"
         cppflags_default=""
         cflags_default=""                    # "-qlanglvl=extc99" by default
@@ -458,41 +451,9 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
 
   case "$host_os" in
 
-    SUPER-UX* | superux*)
-
-     # Native NEC SX vectorizing C compiler (sxmpicc)
-     #-------------------------------------
-
-     $CC -V conftest.c 2>&1 | grep 'NEC' | grep 'SX' > /dev/null
-     if test "$?" = "0" ; then
-
-       echo "compiler '$CC' is NEC SX compiler"
-
-       # Version strings for logging purposes and known compiler flag
-       $CC -V conftest.c > $outfile 2>&1
-       cs_ac_cc_version=`grep ccom $outfile`
-       cs_cc_compiler_known=yes
-       cs_linker_set=yes
-
-       # Default compiler flags
-       cflags_default="-Kc99 -pvctl,loopcnt=2147483647"
-       cflags_default_opt=""
-       cflags_default_dbg=""
-       cflags_default_prf=""
-       cflags_default_omp=""
-
-       # Default linker flags
-       ldflags_default=""
-       ldflags_default_opt="-O"
-       ldflags_default_dbg="-g"
-       ldflags_default_prf="-pg"
-
-     fi
-     ;;
-
     *)
 
-      # Unknown
+      # Generic
       #--------
 
       cflags_default=""
@@ -637,14 +598,6 @@ elif test "x$cs_gxx" = "xicc"; then
   cxxflags_default_prf="-p"
   cxxflags_default_omp="-openmp"
 
-  # Modify default flags on certain systems
-
-  case "$host-os-$host_cpu" in
-    *ia64)
-      cxxflags_default_opt="-O2 -mcpu=itanium2-p9000"
-      ;;
-  esac
-
 # Otherwise, are we using clang ?
 #--------------------------------
 
@@ -722,12 +675,7 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
     grep 'Blue Gene' $outfile > /dev/null
     if test "$?" = "0" ; then
       # Default compiler flags (we assume that MPI wrappers are used)
-      if test "x$cs_ibm_bg_type" = "xP" ; then
-        cxxflags_default=""
-        cxxflags_default_opt="-O3"
-        cxxflags_default_hot="-O3 -qhot"
-        cxxflags_default_dbg="-g"
-      elif test "x$cs_ibm_bg_type" = "xQ" ; then
+      if test -f /bgsys/drivers/ppcfloor/cnk/bin/bgq_kernel.elf ; then
         cxxflags_default="-qlanglvl=redefmac"
         cxxflags_default_opt="-g -O3"
         cxxflags_default_hot="-g -O3 -qhot"
@@ -825,35 +773,9 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
 
   case "$host_os" in
 
-    SUPER-UX*)
-
-      # Native NEC SX vectorizing C compiler (sxmpicc)
-      #-------------------------------------
-
-      $CXX -V conftest.c 2>&1 | grep 'NEC' | grep 'SX' > /dev/null
-      if test "$?" = "0" ; then
-
-        echo "compiler '$CXX' is NEC SX compiler"
-
-        # Version strings for logging purposes and known compiler flag
-        $CXX -V conftest.c > $outfile 2>&1
-        cs_ac_cxx_version=`grep ccom $outfile`
-        cs_cxx_compiler_known=yes
-        cs_linker_set=yes
-
-        # Default compiler flags
-        cxxflags_default="-ftrace --pvctl,loopcnt=2147483647"
-        cxxflags_default_opt=""
-        cxxflags_default_dbg=""
-        cxxflags_default_prf=""
-        cxxflags_default_omp=""
-
-      fi
-      ;;
-
     *)
 
-      # Unknown
+      # Generic
       #--------
 
       cxxflags_default=""
@@ -974,15 +896,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     fcflags_default_prf="-p"
     fcflags_default_omp="-openmp"
 
-    # Modify default flags on certain systems
-
-    case "$host-os-$host_cpu" in
-      *ia64)
-        fcflags_default_opt="-O2 -mcpu=itanium2-p9000"
-        fcflags_default_hot="-O3 -mcpu=itanium2-p9000"
-        ;;
-    esac
-
   fi
 fi
 
@@ -1042,12 +955,7 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     if test "$?" = "0" ; then
 
       # Default compiler flags (we assume that MPI wrappers are used)
-      if test "$cs_ibm_bg_type" = "P" ; then
-        fcflags_default="-qextname -qsuffix=cpp=f90"
-        fcflags_default_dbg="-g"
-        fcflags_default_opt="-O3"
-        fcflags_default_hot="-O3 -qhot"
-      elif test "x$cs_ibm_bg_type" = "xQ" ; then
+      if test -f /bgsys/drivers/ppcfloor/cnk/bin/bgq_kernel.elf ; then
         fcflags_default="-qextname -qsuffix=cpp=f90"
         fcflags_default_dbg="-g -qcheck"
         fcflags_default_opt="-g -O3"
@@ -1073,7 +981,7 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     cs_ac_fc_version=`$FC -V 2>&1 | grep "Cray Fortran" | head -1`
     cs_fc_compiler_known=yes
 
-    fcflags_default="-eF -em"
+    fcflags_default="-eF -em -J."
     fcflags_default_dbg="-g"
     fcflags_default_opt="-O2"
     fcflags_default_prf="-h profile_generate" # resulting code must be run under CrayPat
@@ -1138,35 +1046,9 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
 
   case "$host_os" in
 
-    SUPER-UX* | superux*)
-
-      # Native NEC SX vectorizing Fortran compiler (sxmpif90)
-      #-------------------------------------------
-
-      $FC -V conftest.f 2>&1 | grep 'NEC' | grep 'SX' > /dev/null
-      if test "$?" = "0" ; then
-
-        echo "compiler '$FC' is NEC SX compiler"
-
-        # Version strings for logging purposes and known compiler flag
-        $FC -V conftest.f > $outfile 2>&1
-        cs_ac_fc_version=`grep ccom $outfile`
-        cs_fc_compiler_known=yes
-
-        # Default compiler flags
-        fcflags_default="-Ep -C hopt -I. -Wf,-pvctl,loopcnt=2147483647"
-        fcflags_default_opt=""
-        fcflags_default_hot=""
-        fcflags_default_dbg=""
-        fcflags_default_prf=""
-        fcflags_default_omp=""
-
-      fi
-      ;;
-
     *)
 
-      # Unknown
+      # Generic
       #--------
 
       fcflags_default=""
