@@ -274,7 +274,8 @@ class NewCaseDialogView(QDialog, Ui_NewCaseDialogForm):
 
             p = subprocess.Popen(cmd,
                                  stdout=subprocess.PIPE,
-                                 stderr=subprocess.PIPE)
+                                 stderr=subprocess.PIPE,
+                                 universal_newlines=True)
             output = p.communicate()
             if p.returncode != 0:
                 sys.stderr.write(output[1] + '\n')
@@ -898,7 +899,8 @@ class MainView(object):
         p = subprocess.Popen(cmd,
                              shell=True,
                              stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE)
+                             stderr=subprocess.PIPE,
+                             universal_newlines=True)
 
 
     @pyqtSignature("")
@@ -1230,8 +1232,8 @@ class MainView(object):
             if self.palette_default:
                 app.setPalette(self.palette_default)
             if self.font_default:
-                print self.font_default
-                print self.font()
+                print(self.font_default)
+                print(self.font())
                 self.setFont(self.font_default)
                 app.setFont(self.font_default)
             settings = QSettings()
