@@ -77,7 +77,7 @@ class XMLinit(Variables):
 
     def initialize(self):
         """
-        Verify that all Heading exist only once in the XMLDocument and
+        Verify that all Headings exist only once in the XMLDocument and
         create the missing heading.
         """
         msg = self.__initHeading()
@@ -96,17 +96,17 @@ class XMLinit(Variables):
         n = self.setNewProperty(node, 'yplus')
         n['support'] = 'boundary'
         n['label'] = 'Yplus'
-        n = self.setNewProperty(node, 'effort')
+        n = self.setNewProperty(node, 'stress')
         n['support'] = 'boundary'
-        n['label'] = 'Efforts'
-        if not node.xmlGetChildNode('property', name='effort_tangential'):
-            n = self.setNewProperty(node, 'effort_tangential')
-            n['label'] = 'Efforts, tangential'
+        n['label'] = 'Stress'
+        if not node.xmlGetChildNode('property', name='stress_tangential'):
+            n = self.setNewProperty(node, 'stress_tangential')
+            n['label'] = 'Stress, tangential'
             n['support'] = 'boundary'
             n.xmlInitNode('postprocessing_recording')['status']= "off"
-        if not node.xmlGetChildNode('property', name='effort_normal'):
-            n = self.setNewProperty(node, 'effort_normal')
-            n['label'] = 'Efforts, normal'
+        if not node.xmlGetChildNode('property', name='stress_normal'):
+            n = self.setNewProperty(node, 'stress_normal')
+            n['label'] = 'Stress, normal'
             n['support'] = 'boundary'
             n.xmlInitNode('postprocessing_recording')['status']= "off"
 
@@ -231,20 +231,27 @@ class XMLinit(Variables):
             self.__backwardCompatibilityFrom_3_1()
             self.__backwardCompatibilityFrom_3_2()
             self.__backwardCompatibilityFrom_3_3()
+            self.__backwardCompatibilityFrom_4_0()
         elif from_vers == "3.0":
             self.__backwardCompatibilityFrom_3_0()
             self.__backwardCompatibilityFrom_3_1()
             self.__backwardCompatibilityFrom_3_2()
             self.__backwardCompatibilityFrom_3_3()
+            self.__backwardCompatibilityFrom_4_0()
         elif from_vers == "3.1":
             self.__backwardCompatibilityFrom_3_1()
             self.__backwardCompatibilityFrom_3_2()
             self.__backwardCompatibilityFrom_3_3()
+            self.__backwardCompatibilityFrom_4_0()
         elif from_vers == "3.2":
             self.__backwardCompatibilityFrom_3_2()
             self.__backwardCompatibilityFrom_3_3()
+            self.__backwardCompatibilityFrom_4_0()
         elif from_vers == "3.3":
             self.__backwardCompatibilityFrom_3_3()
+            self.__backwardCompatibilityFrom_4_0()
+        elif from_vers == "4.0":
+            self.__backwardCompatibilityFrom_4_0()
 
 
     def __backwardCompatibilityBefore_3_0(self):
@@ -921,7 +928,7 @@ class XMLinit(Variables):
                 node['name'] = "thermal_flux"
 
 
-    def __backwardCompatibilityCurrentVersion(self):
+    def __backwardCompatibilityFrom_4_0(self):
         """
         Change XML in order to ensure backward compatibility.
         """
@@ -1024,6 +1031,58 @@ class XMLinit(Variables):
                 lst[i].xmlRemoveNode()
 
 
+
+    def __backwardCompatibilityCurrentVersion(self):
+        """
+        Change XML in order to ensure backward compatibility.
+        """
+        # update wall functions settings
+        XMLThermoPhysicalModelNode = self.case.xmlGetNode('thermophysical_models')
+        XMLTurbModelNode = XMLThermoPhysicalModelNode.xmlGetNode('turbulence')
+        if XMLTurbModelNode:
+            scaleModelNode = XMLTurbModelNode.xmlGetNode('scale_model')
+            wallFunctionNode = XMLTurbModelNode.xmlGetNode('wall_function')
+
+            if scaleModelNode and not wallFunctionNode:
+                scale = XMLTurbModelNode.xmlGetInt('scale_model')
+
+                if scale == 0:
+                    wallFunction = 2
+                elif scale == 1:
+                    wallFunction = 3
+                elif scale == 2:
+                    wallFunction = 4
+                else:
+                    wallFunction = 0
+
+                model = XMLTurbModelNode['model']
+                if model == 'v2f-BL-v2/k' or \
+                   model == 'Rij-EBRSM':
+                    wallFunction = 0
+
+                XMLTurbModelNode.xmlSetData('wall_function', wallFunction)
+                scaleModelNode.xmlRemoveNode()
+
+        node = XMLThermoPhysicalModelNode.xmlGetNode('velocity_pressure')
+        if node:
+            for f_name in ['effort', 'effort_tangential', 'effort_normal']:
+                nn = node.xmlGetChildNode('property', name=f_name)
+                if nn:
+                    s = None
+                    l = None
+                    ns = nn.xmlGetChildNode('postprocessing_recording')
+                    if ns:
+                        s = ns['status']
+                    l = nn['label']
+                    nn = node.xmlRemoveChild('property', name=f_name)
+                    l = 'Stress' + l[7:]
+                    nn = self.setNewProperty(node, 'stress' + f_name[6:])
+                    nn['label'] = l
+                    nn['support'] = 'boundary'
+                    if s:
+                        nn.xmlInitNode('postprocessing_recording')['status']= s
+
+
 #-------------------------------------------------------------------------------
 # XMLinit test case
 #-------------------------------------------------------------------------------
