@@ -747,7 +747,7 @@ class NumericalParamEquatTestCase(ModelTest):
                         </variable>
                         <property label="total_pressure" name="total_pressure"/>
                         <property label="Yplus" name="yplus" support="boundary"/>
-                        <property label="Efforts" name="effort" support="boundary"/>
+                        <property label="Stress" name="stress" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set scheme in NumericalParamEquationModel'
@@ -768,7 +768,7 @@ class NumericalParamEquatTestCase(ModelTest):
                     </variable>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
-                    <property label="Efforts" name="effort" support="boundary"/>
+                    <property label="Stress" name="stress" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set blending factor in NumericalParamEquationModel'
@@ -788,7 +788,7 @@ class NumericalParamEquatTestCase(ModelTest):
                     </variable>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
-                    <property label="Efforts" name="effort" support="boundary"/>
+                    <property label="Stress" name="stress" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set status of slope test in NumericalParamEquationModel'
@@ -808,7 +808,7 @@ class NumericalParamEquatTestCase(ModelTest):
                     </variable>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
-                    <property label="Efforts" name="effort" support="boundary"/>
+                    <property label="Stress" name="stress" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set status of flux reconstruction in NumericalParamEquationModel'
@@ -823,7 +823,7 @@ class NumericalParamEquatTestCase(ModelTest):
                     </variable>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
-                    <property label="Efforts" name="effort" support="boundary"/>
+                    <property label="Stress" name="stress" support="boundary"/>
                   </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc2),\
                 'Could not set status of flux reconstruction in NumericalParamEquationModel'
@@ -843,7 +843,7 @@ class NumericalParamEquatTestCase(ModelTest):
                     <variable label="Velocity" name="velocity"/>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
-                    <property label="Efforts" name="effort" support="boundary"/>
+                    <property label="Stress" name="stress" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set max of number of iterations in NumericalParamEquationModel'
@@ -871,7 +871,7 @@ class NumericalParamEquatTestCase(ModelTest):
                     </variable>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
-                    <property label="Efforts" name="effort" support="boundary"/>
+                    <property label="Stress" name="stress" support="boundary"/>
                  </velocity_pressure>"""
         assert model.node_vitpre == self.xmlNodeFromString(doc),\
                 'Could not set solver precision in NumericalParamEquationModel'
@@ -897,7 +897,7 @@ class NumericalParamEquatTestCase(ModelTest):
                     <variable label="Velocity" name="velocity"/>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
-                    <property label="Efforts" name="effort" support="boundary"/>
+                    <property label="Stress" name="stress" support="boundary"/>
                  </velocity_pressure>"""
         sca = """<additional_scalars>
                     <variable label="TempC" name="temperature_celsius" type="thermal">
