@@ -65,7 +65,7 @@ typedef enum {
 
 typedef enum {
 
-  CS_MATRIX_SCALAR,           /* Simple calar matrix */
+  CS_MATRIX_SCALAR,           /* Simple scalar matrix */
   CS_MATRIX_SCALAR_SYM,       /* Simple scalar symmetric matrix */
   CS_MATRIX_33_BLOCK_D,       /* Matrix with 3x3 diagonal blocks
                                  (and 3.I extradiagonal blocks) */
@@ -89,6 +89,19 @@ typedef struct _cs_matrix_t cs_matrix_t;
 
 typedef struct _cs_matrix_variant_t cs_matrix_variant_t;
 
+/* Information structure for extraction of matrix row */
+
+typedef struct {
+
+  cs_lnum_t          row_size;       /*< Row size from last call */
+  cs_lnum_t          buffer_size;    /*< Allocated buffer size */
+  const cs_lnum_t   *col_id;         /*< Pointer to local column ids */
+  cs_lnum_t        *_col_id;         /*< Pointer to local column ids copy */
+  const cs_real_t   *vals;           /*< Pointer to local row values */
+  cs_real_t        *_vals;           /*< Pointer to local row values copy */
+
+} cs_matrix_row_info_t;
+
 /*============================================================================
  *  Global variables
  *============================================================================*/
@@ -110,9 +123,9 @@ extern const char  *cs_matrix_fill_type_name[];
  *============================================================================*/
 
 /*----------------------------------------------------------------------------
- * Create a matrix Structure.
+ * Create a matrix structure.
  *
- * Note that the structure created maps to the given existing
+ * Note that the structure created usually maps to the given existing
  * cell global number, face -> cell connectivity arrays, and cell halo
  * structure, so it must be destroyed before they are freed
  * (usually along with the code's main face -> cell structure).
@@ -120,18 +133,17 @@ extern const char  *cs_matrix_fill_type_name[];
  * Note that the resulting matrix structure will contain either a full or
  * an empty main diagonal, and that the extra-diagonal structure is always
  * symmetric (though the coefficients my not be, and we may choose a
- * matrix format that does not exploit ths symmetry). If the face_cell
+ * matrix format that does not exploit this symmetry). If the edges
  * connectivity argument is NULL, the matrix will be purely diagonal.
  *
  * parameters:
- *   type        <-- Type of matrix considered
- *   have_diag   <-- Indicates if the diagonal structure contains nonzeroes
- *   n_cells     <-- Local number of cells
- *   n_cells_ext <-- Local number of cells + ghost cells sharing a face
- *   n_faces     <-- Local number of internal faces
- *   cell_num    <-- Optional global cell numbers (1 to n), or NULL
- *   face_cell   <-- Face -> cells connectivity
- *   halo        <-- Halo structure associated with cells, or NULL
+ *   type        <-- type of matrix considered
+ *   have_diag   <-- indicates if the diagonal structure contains nonzeroes
+ *   n_rows      <-- local number of rows
+ *   n_cols_ext  <-- number of columns + ghosts
+ *   n_edges     <-- local number of (undirected) graph edges
+ *   edges       <-- edges (symmetric row <-> column) connectivity
+ *   halo        <-- halo structure associated with cells, or NULL
  *   numbering   <-- vectorization or thread-related numbering info, or NULL
  *
  * returns:
@@ -141,37 +153,59 @@ extern const char  *cs_matrix_fill_type_name[];
 cs_matrix_structure_t *
 cs_matrix_structure_create(cs_matrix_type_t       type,
                            bool                   have_diag,
-                           cs_lnum_t              n_cells,
-                           cs_lnum_t              n_cells_ext,
-                           cs_lnum_t              n_faces,
+                           cs_lnum_t              n_rows,
+                           cs_lnum_t              n_cols_ext,
+                           cs_lnum_t              n_edges,
                            const cs_gnum_t       *cell_num,
-                           const cs_lnum_2_t     *face_cell,
+                           const cs_lnum_2_t     *edges,
                            const cs_halo_t       *halo,
                            const cs_numbering_t  *numbering);
 
 /*----------------------------------------------------------------------------
- * Create a matrix container using a given variant.
+ * Create a matrix structure based on a MSR connectivity definition.
  *
- * If the matrix variant is incompatible with the structure, it is ignored,
- * and defaults for that structure are used instead.
+ * Only CSR and MSR formats are handled.
+ *
+ * col_id is sorted row by row during the creation of this structure.
+ *
+ * In case the property of the row index and col_id arrays are transferred
+ * to the structure, the arrays pointers passed as arguments are set to NULL,
+ * to help ensure the caller does not use the original arrays directly after
+ * this call.
  *
  * parameters:
- *   ms <-- Associated matrix structure
- *   mv <-- Associated matrix variant
+ *   type       <-- type of matrix considered
+ *   transfer   <-- transfer property of row_index and col_id
+ *                  if true, map them otherwise
+ *   have_diag  <-- indicates if the structure includes the
+ *                  diagonal (should be the same for all rows)
+ *   n_rows     <-- local number of rows
+ *   n_cols_ext <-- local number of columns + ghosts
+ *   row_index  <-> pointer to index on rows
+ *   col_id     <-> pointer to array of colum ids related to the row index
+ *   halo       <-- halo structure for synchronization, or NULL
+ *   numbering  <-- vectorization or thread-related numbering info, or NULL
  *
  * returns:
- *   pointer to created matrix structure;
+ *   a pointer to a created CDO matrix structure
  *----------------------------------------------------------------------------*/
 
-cs_matrix_t *
-cs_matrix_create_by_variant(const cs_matrix_structure_t  *ms,
-                            const cs_matrix_variant_t    *mv);
+cs_matrix_structure_t *
+cs_matrix_structure_create_msr(cs_matrix_type_t        type,
+                               bool                    transfer,
+                               bool                    have_diag,
+                               cs_lnum_t               n_rows,
+                               cs_lnum_t               n_cols_ext,
+                               cs_lnum_t             **row_index,
+                               cs_lnum_t             **col_id,
+                               const cs_halo_t        *halo,
+                               const cs_numbering_t   *numbering);
 
 /*----------------------------------------------------------------------------
  * Destroy a matrix structure.
  *
  * parameters:
- *   ms <-> Pointer to matrix structure pointer
+ *   ms <-> pointer to matrix structure pointer
  *----------------------------------------------------------------------------*/
 
 void
@@ -184,7 +218,7 @@ cs_matrix_structure_destroy(cs_matrix_structure_t  **ms);
  * so it must be destroyed before that structure.
  *
  * parameters:
- *   ms <-- Associated matrix structure
+ *   ms <-- associated matrix structure
  *
  * returns:
  *   pointer to created matrix structure;
@@ -194,20 +228,50 @@ cs_matrix_t *
 cs_matrix_create(const cs_matrix_structure_t  *ms);
 
 /*----------------------------------------------------------------------------
- * Destroy a matrix structure.
+ * Create a matrix container using a given variant.
+ *
+ * If the matrix variant is incompatible with the structure, it is ignored,
+ * and defaults for that structure are used instead.
  *
  * parameters:
- *   matrix <-> Pointer to matrix structure pointer
+ *   ms <-- associated matrix structure
+ *   mv <-- associated matrix variant
+ *
+ * returns:
+ *   pointer to created matrix structure;
+ *----------------------------------------------------------------------------*/
+
+cs_matrix_t *
+cs_matrix_create_by_variant(const cs_matrix_structure_t  *ms,
+                            const cs_matrix_variant_t    *mv);
+
+/*----------------------------------------------------------------------------
+ * Destroy a matrix structure.
+ *
+ * In the case of a compoud matrix, sub-matrices are not destroyed.
+ *
+ * parameters:
+ *   matrix <-> pointer to matrix structure pointer
  *----------------------------------------------------------------------------*/
 
 void
 cs_matrix_destroy(cs_matrix_t **matrix);
 
+/*----------------------------------------------------------------------------
+ * Return type of matrix.
+ *
+ * parameters:
+ *   matrix --> pointer to matrix structure
+ *----------------------------------------------------------------------------*/
+
+cs_matrix_type_t
+cs_matrix_get_type(const cs_matrix_t  *matrix);
+
 /*----------------------------------------------------------------------------
  * Return number of columns in matrix.
  *
  * parameters:
- *   matrix --> Pointer to matrix structure
+ *   matrix --> pointer to matrix structure
  *----------------------------------------------------------------------------*/
 
 cs_lnum_t
@@ -217,7 +281,7 @@ cs_matrix_get_n_columns(const cs_matrix_t  *matrix);
  * Return number of rows in matrix.
  *
  * parameters:
- *   matrix --> Pointer to matrix structure
+ *   matrix --> pointer to matrix structure
  *----------------------------------------------------------------------------*/
 
 cs_lnum_t
@@ -231,7 +295,7 @@ cs_matrix_get_n_rows(const cs_matrix_t  *matrix);
  *   2: matrix line extents,  3: matrix line*column extents
  *
  * parameters:
- *   matrix <-- Pointer to matrix structure
+ *   matrix <-- pointer to matrix structure
  *
  * returns:
  *   pointer to block sizes
@@ -248,7 +312,7 @@ cs_matrix_get_diag_block_size(const cs_matrix_t  *matrix);
  *   2: matrix line extents,  3: matrix line*column extents
  *
  * parameters:
- *   matrix <-- Pointer to matrix structure
+ *   matrix <-- pointer to matrix structure
  *
  * returns:
  *   pointer to block sizes
@@ -261,7 +325,7 @@ cs_matrix_get_extra_diag_block_size(const cs_matrix_t  *matrix);
  * Return pointer to matrix halo structure.
  *
  * parameters:
- *   matrix <-- Pointer to matrix structure
+ *   matrix <-- pointer to matrix structure
  *
  * returns:
  *   pointer to halo strucuture
@@ -278,9 +342,9 @@ cs_matrix_get_halo(const cs_matrix_t  *matrix);
  *   2: matrix line extents,  3: matrix line*column extents
  *
  * parameters:
- *   symmetric              <-- Indicates if matrix coefficients are symmetric
- *   diag_block_size        <-- Block sizes for diagonal, or NULL
- *   extra_diag_block_size  <-- Block sizes for extra diagonal, or NULL
+ *   symmetric              <-- indicates if matrix coefficients are symmetric
+ *   diag_block_size        <-- block sizes for diagonal, or NULL
+ *   extra_diag_block_size  <-- block sizes for extra diagonal, or NULL
  *
  * returns:
  *   matrix fill type
@@ -292,7 +356,8 @@ cs_matrix_get_fill_type(bool        symmetric,
                         const int  *extra_diag_block_size);
 
 /*----------------------------------------------------------------------------
- * Set matrix coefficients, sharing arrays with the caller when possible.
+ * Set matrix coefficients defined relative to a "native" edge graph,
+ * sharing arrays with the caller when possible.
  *
  * With shared arrays, the matrix becomes unusable if the arrays passed as
  * arguments are not be modified (its coefficients should be unset first
@@ -306,21 +371,28 @@ cs_matrix_get_fill_type(bool        symmetric,
  *   2: matrix line extents,  3: matrix line*column extents
  *
  * parameters:
- *   matrix                 <-> Pointer to matrix structure
- *   symmetric              <-- Indicates if matrix coefficients are symmetric
- *   diag_block_size        <-- Block sizes for diagonal, or NULL
- *   extra_diag_block_size  <-- Block sizes for extra diagonal, or NULL
- *   da                     <-- Diagonal values (NULL if zero)
- *   xa                     <-- Extradiagonal values (NULL if zero)
+ *   matrix                 <-> pointer to matrix structure
+ *   symmetric              <-- indicates if matrix coefficients are symmetric
+ *   diag_block_size        <-- block sizes for diagonal, or NULL
+ *   extra_diag_block_size  <-- block sizes for extra diagonal, or NULL
+ *   n_edges                <-- local number of graph edges
+ *   edges                  <-- edges (row <-> column) connectivity
+ *   da                     <-- diagonal values (NULL if zero)
+ *   xa                     <-- extradiagonal values (NULL if zero)
+ *                              casts as:
+ *                                xa[n_edges]    if symmetric,
+ *                                xa[n_edges][2] if non symmetric
  *----------------------------------------------------------------------------*/
 
 void
-cs_matrix_set_coefficients(cs_matrix_t      *matrix,
-                           bool              symmetric,
-                           const int        *diag_block_size,
-                           const int        *extra_diag_block_size,
-                           const cs_real_t  *da,
-                           const cs_real_t  *xa);
+cs_matrix_set_coefficients(cs_matrix_t        *matrix,
+                           bool                symmetric,
+                           const int          *diag_block_size,
+                           const int          *extra_diag_block_size,
+                           const cs_lnum_t     n_edges,
+                           const cs_lnum_2_t   edges[],
+                           const cs_real_t    *da,
+                           const cs_real_t    *xa);
 
 /*----------------------------------------------------------------------------
  * Set matrix coefficients, copying values to private arrays.
@@ -333,21 +405,63 @@ cs_matrix_set_coefficients(cs_matrix_t      *matrix,
  *   2: matrix line extents,  3: matrix line*column extents
  *
  * parameters:
- *   matrix                 <-> Pointer to matrix structure
- *   symmetric              <-- Indicates if matrix coefficients are symmetric
- *   diag_block_size        <-- Block sizes for diagonal, or NULL
- *   extra_diag_block_size  <-- Block sizes for extra diagonal, or NULL
- *   da                     <-- Diagonal values (NULL if zero)
- *   xa                     <-- Extradiagonal values (NULL if zero)
+ *   matrix                 <-> pointer to matrix structure
+ *   symmetric              <-- indicates if matrix coefficients are symmetric
+ *   diag_block_size        <-- block sizes for diagonal, or NULL
+ *   extra_diag_block_size  <-- block sizes for extra diagonal, or NULL
+ *   n_edges                <-- local number of graph edges
+ *   edges                  <-- edges (row <-> column) connectivity
+ *   da                     <-- diagonal values (NULL if zero)
+ *   xa                     <-- extradiagonal values (NULL if zero)
+ *                              casts as:
+ *                                xa[n_edges]    if symmetric,
+ *                                xa[n_edges][2] if non symmetric
  *----------------------------------------------------------------------------*/
 
 void
-cs_matrix_copy_coefficients(cs_matrix_t      *matrix,
-                            bool              symmetric,
-                            const int        *diag_block_size,
-                            const int        *extra_diag_block_size,
-                            const cs_real_t  *da,
-                            const cs_real_t  *xa);
+cs_matrix_copy_coefficients(cs_matrix_t        *matrix,
+                            bool                symmetric,
+                            const int          *diag_block_size,
+                            const int          *extra_diag_block_size,
+                            const cs_lnum_t     n_edges,
+                            const cs_lnum_2_t   edges[],
+                            const cs_real_t    *da,
+                            const cs_real_t    *xa);
+
+/*----------------------------------------------------------------------------
+ * Set matrix coefficients in an MSR format, transferring the
+ * property of those arrays to the matrix.
+ *
+ * If the matrix is also in MSR format, this avoids an extra copy.
+ * If it is in a different format, values are copied to the structure,
+ * and the original arrays freed. In any case, the arrays pointers passed as
+ * arguments are set to NULL, to help ensure the caller does not use the
+ * original arrays directly after this call.
+ *
+ * Block sizes are defined by an optional array of 4 values:
+ *   0: useful block size, 1: vector block extents,
+ *   2: matrix line extents,  3: matrix line*column extents
+ *
+ * parameters:
+ *   matrix                 <-> pointer to matrix structure
+ *   symmetric              <-- indicates if matrix coefficients are symmetric
+ *   diag_block_size        <-- block sizes for diagonal, or NULL
+ *   extra_diag_block_size  <-- block sizes for extra diagonal, or NULL
+ *   row_index              <-- MSR row index (0 to n-1)
+ *   col_id                 <-- MSR column id (0 to n-1)
+ *   d_val                  <-> diagonal values (NULL if zero)
+ *   x_val                  <-> extradiagonal values (NULL if zero)
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_transfer_coefficients_msr(cs_matrix_t         *matrix,
+                                    bool                 symmetric,
+                                    const int           *diag_block_size,
+                                    const int           *extra_diag_block_size,
+                                    const cs_lnum_t      row_index[],
+                                    const cs_lnum_t      col_id[],
+                                    cs_real_t          **d_val,
+                                    cs_real_t          **x_val);
 
 /*----------------------------------------------------------------------------
  * Release shared matrix coefficients.
@@ -359,7 +473,7 @@ cs_matrix_copy_coefficients(cs_matrix_t      *matrix,
  * to nonexistant data.
  *
  * parameters:
- *   matrix <-> Pointer to matrix structure
+ *   matrix <-> pointer to matrix structure
  *----------------------------------------------------------------------------*/
 
 void
@@ -372,8 +486,8 @@ cs_matrix_release_coefficients(cs_matrix_t  *matrix);
  * diagonal values are copied.
  *
  * parameters:
- *   matrix --> Pointer to matrix structure
- *   da     --> Diagonal (pre-allocated, size: n_cells)
+ *   matrix --> pointer to matrix structure
+ *   da     --> diagonal (pre-allocated, size: n_rows*block_size
  *----------------------------------------------------------------------------*/
 
 void
@@ -384,7 +498,7 @@ cs_matrix_copy_diagonal(const cs_matrix_t  *matrix,
  * Query matrix coefficients symmetry
  *
  * parameters:
- *   matrix <-- Pointer to matrix structure
+ *   matrix <-- pointer to matrix structure
  *
  * returns:
  *   true if coefficients are symmetric, false otherwise
@@ -400,7 +514,7 @@ cs_matrix_is_symmetric(const cs_matrix_t  *matrix);
  * the complete block diagonal is returned.
  *
  * parameters:
- *   matrix --> Pointer to matrix structure
+ *   matrix --> pointer to matrix structure
  *
  * returns:
  *   pointer to matrix diagonal array
@@ -418,7 +532,7 @@ cs_matrix_get_diagonal(const cs_matrix_t  *matrix);
  * the same as the one passed to that function.
  *
  * parameters:
- *   matrix --> Pointer to matrix structure
+ *   matrix --> pointer to matrix structure
  *
  * returns:
  *   pointer to matrix diagonal array
@@ -427,6 +541,97 @@ cs_matrix_get_diagonal(const cs_matrix_t  *matrix);
 const cs_real_t *
 cs_matrix_get_extra_diagonal(const cs_matrix_t  *matrix);
 
+/*----------------------------------------------------------------------------
+ * Initialize row info for a given matrix.
+ *
+ * parameters:
+ *   row_info --> row info structure
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_row_init(cs_matrix_row_info_t  *r);
+
+/*----------------------------------------------------------------------------
+ * Finalize row info for a given matrix.
+ *
+ * parameters:
+ *   row_info <-> row info structure
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_row_finalize(cs_matrix_row_info_t  *r);
+
+/*----------------------------------------------------------------------------
+ * Get row values for a given matrix.
+ *
+ * This function may not work for all matrix types.
+ *
+ * In the case of blocked matrixes, the true (non-blocked)
+ * values are returned.
+ *
+ * The row information structure must have been previously initialized
+ * using cs_matrix_row_init(), and should be finalized using
+ * using cs_matrix_row_finalize(), so as to free buffers it may have
+ * built for certain matrix formats.
+ *
+ * parameters:
+ *   matrix    <-- pointer to matrix structure
+ *   row_id    <-- id of row to query
+ *   row_info  <-> row info structure
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_get_row(const cs_matrix_t     *matrix,
+                  const cs_lnum_t        row_id,
+                  cs_matrix_row_info_t  *r);
+
+/*----------------------------------------------------------------------------
+ * Get arrays describing a matrix in native format.
+ *
+ * This function works for matrix in native format.
+ *
+ * Matrix block sizes can be obtained by cs_matrix_get_diag_block_size()
+ * and cs_matrix_get_extra_diag_block_size().
+ *
+ * parameters:
+ *   matrix    <-- pointer to matrix structure
+ *   symmetric --> true if symmetric
+ *   n_edges   --> number of associated faces
+ *   edges     --> edges (symmetric row <-> column) connectivity
+ *   d_val     --> diagonal values
+ *   x_val     --> extra-diagonal values
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_get_native_arrays(const cs_matrix_t    *matrix,
+                            bool                *symmetric,
+                            cs_lnum_t           *n_edges,
+                            const cs_lnum_2_t  **edges,
+                            const cs_real_t    **d_val,
+                            const cs_real_t    **x_val);
+
+/*----------------------------------------------------------------------------
+ * Get arrays describing a matrix in CSR format.
+ *
+ * This function only works for an CSR matrix (i.e. there is
+ * no automatic conversion from another matrix type).
+ *
+ * Matrix block sizes can be obtained by cs_matrix_get_diag_block_size()
+ * and cs_matrix_get_extra_diag_block_size().
+ *
+ * parameters:
+ *   matrix    <-- pointer to matrix structure
+ *   row_index --> CSR row index
+ *   col_id    --> CSR column id
+ *   val       --> values
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_get_csr_arrays(const cs_matrix_t   *matrix,
+                         const cs_lnum_t    **row_index,
+                         const cs_lnum_t    **col_id,
+                         const cs_real_t    **val);
+
 /*----------------------------------------------------------------------------
  * Get arrays describing a matrix in MSR format.
  *
@@ -437,7 +642,7 @@ cs_matrix_get_extra_diagonal(const cs_matrix_t  *matrix);
  * and cs_matrix_get_extra_diag_block_size().
  *
  * parameters:
- *   matrix    <-- Pointer to matrix structure
+ *   matrix    <-- pointer to matrix structure
  *   row_index --> MSR row index
  *   col_id    --> MSR column id
  *   d_val     --> diagonal values
@@ -457,10 +662,10 @@ cs_matrix_get_msr_arrays(const cs_matrix_t   *matrix,
  * This function includes a halo update of x prior to multiplication by A.
  *
  * parameters:
- *   rotation_mode --> Halo update option for rotational periodicity
- *   matrix        --> Pointer to matrix structure
- *   x             <-> Multipliying vector values (ghost values updated)
- *   y             --> Resulting vector
+ *   rotation_mode --> halo update option for rotational periodicity
+ *   matrix        --> pointer to matrix structure
+ *   x             <-> multipliying vector values (ghost values updated)
+ *   y             --> resulting vector
  *----------------------------------------------------------------------------*/
 
 void
@@ -478,9 +683,9 @@ cs_matrix_vector_multiply(cs_halo_rotation_t   rotation_mode,
  * redundant update by using this variant of the matrix.vector product).
  *
  * parameters:
- *   matrix --> Pointer to matrix structure
- *   x      --> Multipliying vector values
- *   y      --> Resulting vector
+ *   matrix --> pointer to matrix structure
+ *   x      --> multipliying vector values
+ *   y      --> resulting vector
  *----------------------------------------------------------------------------*/
 
 void
@@ -494,10 +699,10 @@ cs_matrix_vector_multiply_nosync(const cs_matrix_t  *matrix,
  * This function includes a halo update of x prior to multiplication by A.
  *
  * parameters:
- *   rotation_mode <-- Halo update option for rotational periodicity
- *   matrix        <-- Pointer to matrix structure
- *   x             <-> Multipliying vector values (ghost values updated)
- *   y             --> Resulting vector
+ *   rotation_mode <-- halo update option for rotational periodicity
+ *   matrix        <-- pointer to matrix structure
+ *   x             <-> multipliying vector values (ghost values updated)
+ *   y             --> resulting vector
  *----------------------------------------------------------------------------*/
 
 void
@@ -534,7 +739,7 @@ cs_matrix_variant_build_list(int                      n_fill_types,
  * which can be later modified using cs_matrix_variant_set_func().
  *
  * parameters:
- *   type         <-- Type of matrix considered
+ *   type         <-- type of matrix considered
  *   numbering    <-- vectorization or thread-related numbering info,
  *                    or NULL
  *----------------------------------------------------------------------------*/
@@ -562,7 +767,6 @@ cs_matrix_variant_destroy(cs_matrix_variant_t  **mv);
  *   CS_MATRIX_NATIVE  (all fill types)
  *     standard
  *     3_3_diag        (for CS_MATRIX_33_BLOCK_D or CS_MATRIX_33_BLOCK_D_SYM)
- *     bull            (for CS_MATRIX_SCALAR or CS_MATRIX_SCALAR_SYM)
  *     omp             (for OpenMP with compatible numbering)
  *     vector          (For vector machine with compatible numbering)
  *
@@ -581,7 +785,7 @@ cs_matrix_variant_destroy(cs_matrix_variant_t  **mv);
  *     mkl             (with MKL, for CS_MATRIX_SCALAR or CS_MATRIX_SCALAR_SYM)
  *
  * parameters:
- *   mv        <-> Pointer to matrix variant
+ *   mv        <-> pointer to matrix variant
  *   numbering <-- mesh numbering info, or NULL
  *   fill type <-- matrix fill type to merge from
  *   ed_flag   <-- 0: with diagonal only, 1 exclude only; 2; both
@@ -606,8 +810,8 @@ cs_matrix_variant_set_func(cs_matrix_variant_t     *mv,
  * types, and the resulting selected structure is identical.
  *
  * parameters:
- *   mv        <-> Pointer to matrix variant
- *   mv_merge  <-- Pointer to matrix variant to merge
+ *   mv        <-> pointer to matrix variant
+ *   mv_merge  <-- pointer to matrix variant to merge
  *   fill type <-- matrix fill type to merge from
  *----------------------------------------------------------------------------*/
 
@@ -620,7 +824,7 @@ cs_matrix_variant_merge(cs_matrix_variant_t        *mv,
  * Get the type associated with a matrix variant.
  *
  * parameters:
- *   mv <-- Pointer to matrix variant structure
+ *   mv <-- pointer to matrix variant structure
  *----------------------------------------------------------------------------*/
 
 cs_matrix_type_t
@@ -630,21 +834,21 @@ cs_matrix_variant_type(const cs_matrix_variant_t  *mv);
  * Test local matrix.vector product operations.
  *
  * parameters:
- *   n_cells        <-- number of local cells
- *   n_cells_ext    <-- number of cells including ghost cells (array size)
- *   n_faces        <-- local number of internal faces
- *   cell_num       <-- Optional global cell numbers (1 to n), or NULL
- *   face_cell      <-- face -> cells connectivity
+ *   n_rows         <-- number of local rows
+ *   n_cols_ext     <-- number of columns + ghosts
+ *   n_edges        <-- local number of (undirected) graph edges
+ *   cell_num       <-- optional global cell numbers (1 to n), or NULL
+ *   edges          <-- edges (symmetric row <-> column) connectivity
  *   halo           <-- cell halo structure
  *   numbering      <-- vectorization or thread-related numbering info, or NULL
  *----------------------------------------------------------------------------*/
 
 void
-cs_matrix_variant_test(cs_lnum_t              n_cells,
-                       cs_lnum_t              n_cells_ext,
-                       cs_lnum_t              n_faces,
+cs_matrix_variant_test(cs_lnum_t              n_rows,
+                       cs_lnum_t              n_cols_ext,
+                       cs_lnum_t              n_edges,
                        const cs_gnum_t       *cell_num,
-                       const cs_lnum_2_t     *face_cell,
+                       const cs_lnum_2_t     *edges,
                        const cs_halo_t       *halo,
                        const cs_numbering_t  *numbering);
 
