@@ -54,6 +54,7 @@
 #include "cs_halo.h"
 #include "cs_halo_perio.h"
 #include "cs_log.h"
+#include "cs_mesh.h"
 #include "cs_numbering.h"
 #include "cs_prototypes.h"
 #include "cs_timer.h"
@@ -121,6 +122,10 @@ static cs_matrix_t *_matrix_msr = NULL;
 static double _t_measure = 0.5;
 static int _n_min_products = 10;
 
+/* Pointer to global (block-based) numbering, if used */
+
+static cs_gnum_t  *_global_row_num = NULL;
+
 /*============================================================================
  * Private function definitions
  *============================================================================*/
@@ -145,6 +150,47 @@ _initialize_api(void)
   }
 }
 
+/*----------------------------------------------------------------------------
+ * Build a global block row numbering.
+ *
+ * parameters:
+ *   n_rows <-- associated number of local rows
+ *   halo   <-- associated halo, or NULL
+ *----------------------------------------------------------------------------*/
+
+static void
+_build_block_row_num(cs_lnum_t         n_rows,
+                     const cs_halo_t  *halo)
+{
+  cs_lnum_t _n_rows = n_rows;
+  cs_gnum_t row_start = 1;
+
+  if (halo != NULL) {
+    assert(n_rows == halo->n_local_elts);
+    _n_rows += halo->n_elts[CS_HALO_EXTENDED];
+  }
+
+  BFT_REALLOC(_global_row_num, _n_rows, cs_gnum_t);
+
+#if defined(HAVE_MPI)
+  if (cs_glob_n_ranks > 1) {
+    cs_gnum_t loc_shift = n_rows;
+    MPI_Scan(&loc_shift, &row_start, 1, CS_MPI_GNUM, MPI_SUM, cs_glob_mpi_comm);
+    row_start = row_start + 1 - loc_shift;
+  }
+#endif
+
+# pragma omp parallel for  if(_n_rows > CS_THR_MIN)
+  for (cs_lnum_t i = 0; i < _n_rows; i++)
+    _global_row_num[i] =  (cs_gnum_t)i + row_start;
+
+  if (halo != NULL)
+    cs_halo_sync_untyped(halo,
+                         CS_HALO_EXTENDED,
+                         sizeof(cs_gnum_t),
+                         _global_row_num);
+}
+
 /*! (DOXYGEN_SHOULD_SKIP_THIS) \endcond */
 
 /*============================================================================
@@ -166,6 +212,7 @@ void CS_PROCF(promav, PROMAV)
  cs_real_t        *vy         /* <-> vy = A*vx */
 )
 {
+  const cs_mesh_t *m = cs_glob_mesh;
   cs_matrix_t *a;
 
   bool symmetric = (*isym == 1) ? true : false;
@@ -203,6 +250,8 @@ void CS_PROCF(promav, PROMAV)
                                symmetric,
                                _diag_block_size,
                                _extra_diag_block_size,
+                               m->n_i_faces,
+                               (const cs_lnum_2_t *)m->i_face_cells,
                                dam,
                                xam);
   }
@@ -210,7 +259,10 @@ void CS_PROCF(promav, PROMAV)
 
     a = cs_matrix_default(symmetric, NULL, NULL);
 
-    cs_matrix_set_coefficients(a, false, NULL, NULL, dam, xam);
+    cs_matrix_set_coefficients(a, false, NULL, NULL,
+                               m->n_i_faces,
+                               (const cs_lnum_2_t *)m->i_face_cells,
+                               dam, xam);
 
   }
 
@@ -351,6 +403,8 @@ cs_matrix_initialize(void)
 void
 cs_matrix_finalize(void)
 {
+  BFT_FREE(_global_row_num);
+
   for (cs_matrix_fill_type_t mft = 0; mft < CS_MATRIX_N_FILL_TYPES; mft++)
     _tuned_matrix_id[mft] = -1;
 
@@ -382,6 +436,9 @@ cs_matrix_update_mesh(void)
 {
   cs_mesh_t  *mesh = cs_glob_mesh;
 
+  if (_global_row_num != NULL)
+    _build_block_row_num(mesh->n_cells, mesh->halo);
+
   for (int i = 0; i < CS_MATRIX_N_FILL_TYPES; i++) {
 
     if (_matrix_tuned[i] != NULL) {
@@ -671,6 +728,36 @@ cs_matrix_get_tuning_runs(int     *n_min_products,
     *t_measure = _t_measure;
 }
 
+/*----------------------------------------------------------------------------
+ * Return a global block row numbering.
+ *
+ * The numbering is built if not previously present, and returned otherwise.
+ *
+ * Currently, the function only handles one n_rows/halo combination, and does
+ * not check for consistency.
+ *
+ * parameters:
+ *   n_rows <-- associated number of local rows
+ *   halo   <-- associated halo, or NULL
+ *
+ * returns:
+ *   pointer to requested global numbering
+ *----------------------------------------------------------------------------*/
+
+const cs_gnum_t *
+cs_matrix_get_block_row_gnum(cs_lnum_t         n_rows,
+                             const cs_halo_t  *halo)
+{
+  const cs_gnum_t  *g_row_num = _global_row_num;
+
+  if (_global_row_num == NULL) {
+    _build_block_row_num(n_rows, halo);
+    g_row_num = _global_row_num;
+  }
+
+  return g_row_num;
+}
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
