@@ -34,6 +34,7 @@
 #include "cs_base.h"
 #include "cs_sles.h"
 #include "cs_sles_it.h"
+#include "cs_time_plot.h"
 
 /*----------------------------------------------------------------------------*/
 
@@ -156,19 +157,18 @@ cs_multigrid_copy(const void  *context);
  * Set multigrid coarsening parameters.
  *
  * parameters:
- *   mg                <-> pointer to multigrid info and context
- *   aggregation_limit <-- maximum allowed fine cells per coarse cell
- *   coarsening_type   <-- coarsening type:
- *                          0: algebraic, natural face traversal;
- *                          1: algebraic, face traveral by criteria;
- *                          2: algebraic, Hilbert face traversal;
- *   n_max_levels      <-- maximum number of grid levels
- *   min_g_cells       <-- global number of cells on coarse grids
- *                         under which no coarsening occurs
- *   p0p1_relax        <-- p0/p1 relaxation_parameter
- *   verbosity         <-- verbosity level
- *   postprocess       <-- if > 0, postprocess coarsening
- *                         (using coarse cell numbers modulo this value)
+ *   mg                     <-> pointer to multigrid info and context
+ *   aggregation_limit      <-- maximum allowed fine cells per coarse cell
+ *   coarsening_type        <-- coarsening type:
+ *                              0: algebraic, natural face traversal;
+ *                              1: algebraic, face traveral by criteria;
+ *                              2: algebraic, Hilbert face traversal;
+ *   n_max_levels           <-- maximum number of grid levels
+ *   min_g_cells            <-- global number of cells on coarse grids
+ *                              under which no coarsening occurs
+ *   p0p1_relax             <-- p0/p1 relaxation_parameter
+ *   postprocess_block_size <-- if > 0, postprocess coarsening
+ *                              (using coarse cell numbers modulo this value)
  *----------------------------------------------------------------------------*/
 
 void
@@ -319,8 +319,7 @@ cs_multigrid_log(const void  *context,
  *   rotation_mode <-- halo update option for rotational periodicity
  *   rhs           <-- right hand side
  *   vx            <-> system solution
- */
-/*----------------------------------------------------------------------------*/
+ *----------------------------------------------------------------------------*/
 
 void
 cs_multigrid_error_post_and_abort(void                         *context,
@@ -331,6 +330,21 @@ cs_multigrid_error_post_and_abort(void                         *context,
                                   const cs_real_t              *rhs,
                                   cs_real_t                    *vx);
 
+/*----------------------------------------------------------------------------
+ * Set plotting options for multigrid.
+ *
+ * parameters:
+ *   mg            <-> pointer to multigrid info and context
+ *   base_name     <-- base plot name to activate, NULL otherwise
+ *   use_iteration <-- if true, use iteration as time stamp
+ *                     otherwise, use wall clock time
+ *----------------------------------------------------------------------------*/
+
+void
+cs_multigrid_set_plot_options(cs_multigrid_t  *mg,
+                              const char      *base_name,
+                              bool             use_iteration);
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
