@@ -62,6 +62,7 @@
 #include "cs_parall.h"
 #include "cs_post.h"
 #include "cs_timer.h"
+#include "cs_timer_stats.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -350,6 +351,10 @@ static int _cs_sles_n_max_systems[3] = {0, 0};
 /* Arrays of settings and status for linear systems */
 static cs_sles_t **_cs_sles_systems[3] = {NULL, NULL, NULL};
 
+/* Timer statistics */
+
+static int _sles_stat_id = -1;
+
 /*============================================================================
  * Private function definitions
  *============================================================================*/
@@ -776,6 +781,13 @@ _value_type(size_t     n_vals,
 void
 cs_sles_initialize(void)
 {
+  int stats_root = cs_timer_stats_id_by_name("operations");
+
+  if (stats_root > -1) {
+    _sles_stat_id = cs_timer_stats_create("operations",
+                                          "linear_solvers",
+                                          "linear solvers");
+  }
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1055,8 +1067,6 @@ cs_sles_find_or_add(int          f_id,
  *
  * \param[in]  f_id  associated field id, or < 0
  * \param[in]  name  associated name if f_id < 0, or NULL
- *
- * \return  pointer to associated linear system object, or NULL
  */
 /*----------------------------------------------------------------------------*/
 
@@ -1278,12 +1288,16 @@ cs_sles_setup(cs_sles_t          *sles,
   if (sles->context == NULL)
     _cs_sles_define_default(sles->f_id, sles->name, a);
 
+  int t_top_id = cs_timer_stats_switch(_sles_stat_id);
+
   sles->n_calls += 1;
 
   if (sles->setup_func != NULL) {
     const char  *sles_name = cs_sles_base_name(sles->f_id, sles->name);
     sles->setup_func(sles->context, sles_name, a, sles->verbosity);
   }
+
+  cs_timer_stats_switch(t_top_id);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1335,12 +1349,19 @@ cs_sles_solve(cs_sles_t           *sles,
   if (sles->context == NULL)
     _cs_sles_define_default(sles->f_id, sles->name, a);
 
+  int t_top_id = cs_timer_stats_switch(_sles_stat_id);
+
   sles->n_calls += 1;
 
   assert(sles->solve_func != NULL);
 
   const char  *sles_name = cs_sles_base_name(sles->f_id, sles->name);
 
+#if 0
+  /* Dump linear system to file (for experimenting with external tools) */
+  cs_matrix_dump_linear_system(a, rhs, sles_name);
+#endif
+
   cs_sles_convergence_state_t state;
 
   if (! _needs_solving(sles_name,
@@ -1380,6 +1401,8 @@ cs_sles_solve(cs_sles_t           *sles,
                      rhs,
                      vx);
 
+  cs_timer_stats_switch(t_top_id);
+
   return state;
 }
 
@@ -1411,7 +1434,7 @@ cs_sles_free(cs_sles_t  *sles)
  *
  * The intended use of this function is to allow associating different
  * solvers to related systems, so as to differentiate logging, while using
- * the same setttings by default.
+ * the same settings by default.
  *
  * If the source solver does not provide a \ref cs_sles_copy_t function,
  * No modification is done to the solver. If the copy function is available,
