@@ -34,6 +34,8 @@
 #include "cs_base.h"
 #include "cs_halo_perio.h"
 #include "cs_matrix.h"
+#include "cs_time_plot.h"
+#include "cs_sles.h"
 
 /*----------------------------------------------------------------------------*/
 
@@ -58,7 +60,8 @@ typedef enum {
   CS_SLES_BICGSTAB,        /* Bi-conjugate gradient stabilized */
   CS_SLES_BICGSTAB2,       /* Bi-conjugate gradient stabilized - 2*/
   CS_SLES_GMRES,           /* Generalized minimal residual */
-  CS_SLES_B_GAUSS_SEIDEL,  /* Block Gauss-Seidel */
+  CS_SLES_P_GAUSS_SEIDEL,  /* Process-local Gauss-Seidel */
+  CS_SLES_PCR3,            /* 3-layer conjugate residual */
   CS_SLES_N_IT_TYPES       /* Number of resolution algorithms */
 
 } cs_sles_it_type_t;
@@ -92,9 +95,8 @@ extern const char *cs_sles_it_type_name[];
  *
  * Note that this function returns a pointer directly to the iterative solver
  * management structure. This may be used to set further options,
- * for example using cs_sles_it_set_pcg_single_reduction(). If needed,
- * cs_sles_find() may be used to obtain a pointer to the matching
- * cs_sles_t container.
+ * for example using cs_sles_set_plot_options(). If needed, cs_sles_find()
+ * may be used to obtain a pointer to the matching cs_sles_t container.
  *
  * parameters:
  *   f_id         <-- associated field id, or < 0
@@ -338,6 +340,20 @@ void
 cs_sles_it_assign_order(cs_sles_it_t   *context,
                         cs_lnum_t     **order);
 
+/*----------------------------------------------------------------------------
+ * Assign symmetric option to iterative solver.
+ *
+ * This is useful only for Process-local Gauss-Seidel.
+ *
+ * parameters:
+ *   context   <-> pointer to iterative solver info and context
+ *   symmetric <-- symmetric if true
+ *----------------------------------------------------------------------------*/
+
+void
+cs_sles_it_set_symmetric(cs_sles_it_t   *context,
+                         bool            symmetric);
+
 /*----------------------------------------------------------------------------
  * Query mean number of rows under which Conjugate Gradient algorithm
  * uses the single-reduction variant.
@@ -413,6 +429,38 @@ cs_sles_it_error_post_and_abort(void                         *context,
                                 const cs_real_t              *rhs,
                                 cs_real_t                    *vx);
 
+/*----------------------------------------------------------------------------
+ * Set plotting options for an iterative sparse linear equation solver.
+ *
+ * parameters:
+ *   context       <-> pointer to iterative solver info and context
+ *   base_name     <-- base plot name to activate, NULL otherwise
+ *   use_iteration <-- if true, use iteration as time stamp
+ *                     otherwise, use wall clock time
+ *----------------------------------------------------------------------------*/
+
+void
+cs_sles_it_set_plot_options(cs_sles_it_t  *context,
+                            const char    *base_name,
+                            bool           use_iteration);
+
+/*----------------------------------------------------------------------------
+ * Assign existing time plot to iterative sparse linear equation solver.
+ *
+ * This is useful mainly when a time plot has a longer lifecycle than
+ * the linear solver context, such as inside a multigrid solver.
+ *
+ * parameters:
+ *   context    <-> pointer to iterative solver info and context
+ *   time_plot  <-- pointer to time plot structure
+ *   time_stamp <-- associated time stamp
+ *----------------------------------------------------------------------------*/
+
+void
+cs_sles_it_assign_plot(cs_sles_it_t    *context,
+                       cs_time_plot_t  *time_plot,
+                       int              time_stamp);
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
