@@ -50,8 +50,10 @@
 #include "cs_base_fortran.h"
 #include "cs_benchmark.h"
 #include "cs_calcium.h"
+#include "cs_cdo_main.h"
 #include "cs_coupling.h"
 #include "cs_ctwr.h"
+#include "cs_fan.h"
 #include "cs_field.h"
 #include "cs_field_pointer.h"
 #include "cs_file.h"
@@ -90,6 +92,7 @@
 #include "cs_system_info.h"
 #include "cs_time_moment.h"
 #include "cs_timer.h"
+#include "cs_timer_stats.h"
 #include "cs_les_inflow.h"
 #include "cs_turbomachinery.h"
 #include "cs_physical_properties.h"
@@ -171,6 +174,9 @@ cs_run(void)
   cs_system_info();
 #endif
 
+  cs_timer_stats_initialize();
+  cs_timer_stats_define_defaults();
+
   cs_gui_parallel_io();
   cs_user_parallel_io();
   cs_file_defaults_info();
@@ -203,7 +209,10 @@ cs_run(void)
 
   /* Initialize Fortran API and calculation setup */
 
-  if ((opts.preprocess | opts.verif) == false && opts.benchmark <= 0) {
+  if (opts.cdo)
+    halo_type = CS_HALO_STANDARD; // temporary
+
+  else if ((opts.preprocess | opts.verif) == false && opts.benchmark <= 0) {
 
     cs_int_t _rank_id = cs_glob_rank_id, _n_ranks = cs_glob_n_ranks;
 
@@ -299,7 +308,13 @@ cs_run(void)
     cs_gradient_initialize();
     cs_gradient_perio_initialize();
 
-    if (opts.verif == false) {
+    if (opts.cdo) { /* CDO kernel mode */
+
+      cs_cdo_main(cs_glob_mesh,
+                  cs_glob_mesh_quantities);
+
+    }
+    else if (opts.verif == false) {
 
       /* Initialize sparse linear systems resolution */
 
@@ -316,6 +331,10 @@ cs_run(void)
 
       if (cs_user_solver_set() == 0) {
 
+        /* Additional initializations required by some models */
+
+        cs_fan_build_all(cs_glob_mesh, cs_glob_mesh_quantities);
+
         /*----------------------------------------------
          * Call main calculation function (code Kernel)
          *----------------------------------------------*/
@@ -371,9 +390,10 @@ cs_run(void)
   cs_gui_usage_log();
   cs_mesh_selector_stats(cs_glob_mesh);
 
-  /* Free cooling towers related structures */
+  /* Finalizations related to some models */
 
   cs_ctwr_all_destroy();
+  cs_fan_destroy_all();
 
   /* Free thermal physical properties */
 
@@ -422,6 +442,8 @@ cs_run(void)
   cs_all_to_all_log_finalize();
   cs_io_log_finalize();
 
+  cs_timer_stats_finalize();
+
   cs_base_time_summary();
   cs_base_mem_finalize();
 }
@@ -434,6 +456,10 @@ int
 main(int    argc,
      char  *argv[])
 {
+  /* Initialize wall clock timer */
+
+  (void)cs_timer_wtime();
+
   /* First analysis of the command line to determine if MPI is required,
      and MPI initialization if it is. */
 
@@ -465,16 +491,15 @@ main(int    argc,
 
 #endif
 
-  (void)cs_timer_wtime();
-
   /* Trap floating-point exceptions on most systems */
 
+#if defined(DEBUG)
   cs_fp_exception_enable_trap();
+#endif
 
-  /* Initialize memory management and signals */
+  /* Initialize memory management */
 
   cs_base_mem_init();
-  cs_base_error_init();
 
   /* Initialize internationalization */
 
@@ -487,6 +512,10 @@ main(int    argc,
 
   cs_opts_define(argc, argv, &opts);
 
+  /* Initialize error handling */
+
+  cs_base_error_init(opts.sig_defaults);
+
   /* Open 'listing' (log) files */
 
   cs_base_fortran_bft_printf_set("listing", opts.ilisr0, opts.ilisrp);
