@@ -97,16 +97,19 @@ implicit none
 
 ! Local variables
 
-integer          iiii, iz
+integer          iiii
 
 integer          modhis, iappel, modntl, iisuit, iwarn0
 integer          ivar
+integer          iel
 
 integer          inod   , idim
 integer          itrale , ntmsav
 
 integer          nent
 
+integer          stats_id, restart_stats_id, lagr_stats_id, post_stats_id
+
 double precision titer1, titer2
 double precision tecrf1, tecrf2
 
@@ -120,6 +123,7 @@ character        ficsui*32
 integer, allocatable, dimension(:) :: isostd
 
 double precision, pointer, dimension(:)   :: dt => null()
+double precision, pointer, dimension(:)   :: porosi => null()
 double precision, pointer, dimension(:,:) :: propce => null()
 double precision, pointer, dimension(:,:) :: disale => null()
 
@@ -133,7 +137,6 @@ double precision, pointer, dimension(:)   :: prhyd => null()
 interface
 
   subroutine tridim &
-  !================
   ( itrale , nvar   , nscal  ,                                     &
     isostd ,                                                       &
     dt     , propce ,                                              &
@@ -173,10 +176,8 @@ end interface
 
 if ((iilagr.gt.0).and.(irangp.ge.0)) then
   call zufalli(irangp + 1)
-  !===========
 else
   call zufalli(1)
-  !===========
 endif
 
 !---> Stop test set to 1 if P-1 radiative module "sees" too many cells
@@ -198,26 +199,34 @@ if (idtvar.eq.1 .and. ntmsav.gt.ntmabs .and. ntmabs.eq.ntcabs) then
   if (ivoid(1).gt.0) ntmabs = ntmabs+1
 endif
 
+! Define timer stats based on options
+
+if (iilagr.gt.0) then
+  lagr_stats_id = timer_stats_create("stages", &
+                                     "lagrangian_stage", &
+                                     "Lagrangian Module")
+  stats_id = timer_stats_create("lagrangian_stage", &
+                                "particle_displacement_stage", &
+                                "particle displacement")
+endif
+
 !===============================================================================
 ! Geometry
 !===============================================================================
 
 call cregeo
-!==========
 
 !===============================================================================
 ! End of modules initialization
 !===============================================================================
 
 call initi2
-!==========
 
 if (iilagr.gt.0) then
 
   !--> Compute "lndnod" (lagran.f90)
 
   call lagini(lndnod)
-  !==========
 
 endif
 
@@ -241,7 +250,6 @@ allocate(izft1d(nfabor))
 
 if (iihmpr.eq.1) then
   call uikpdc &
-  !==========
 ( iappel ,          &
   ncelet , ncepdc , &
   ivoid  ,          &
@@ -258,7 +266,16 @@ call cs_user_head_losses &
 ncpdct = ncepdc
 if (irangp.ge.0) then
   call parcpt(ncpdct)
-  !==========
+endif
+
+if (iflow .eq. 1) then
+  if (ncpdct.eq.0) then
+    ncepdc = ncel
+    ncpdct = ncel
+  endif
+  if (irangp.ge.0) then
+    call parcpt(ncpdct)
+  endif
 endif
 
 if (ncpdct.gt.0) then
@@ -291,7 +308,6 @@ call cs_user_mass_source_terms &
 nctsmt = ncetsm
 if (irangp.ge.0) then
   call parcpt(nctsmt)
-  !==========
 endif
 
 if (nctsmt.gt.0) then
@@ -303,7 +319,6 @@ endif
 ! ------------------------------
 
 call cs_user_boundary_mass_source_terms &
-!======================================
 ( nvar   , nscal  ,                                              &
   nfbpcd , iappel ,                                              &
   ivoid  , ivoid  , izftcd ,                                     &
@@ -313,7 +328,6 @@ call cs_user_boundary_mass_source_terms &
 nftcdt = nfbpcd
 if (irangp.ge.0) then
   call parcpt(nftcdt)
-  !==========
 endif
 
 if (nftcdt.gt.0) then
@@ -326,7 +340,6 @@ endif
 ! --------------
 
 call uspt1d &
-!==========
  ( nvar   , nscal  , nfpt1d , iappel ,                            &
    ivoid  , izft1d , ivoid  , ivoid  ,                            &
    rvoid  , rvoid  , rvoid  ,                                     &
@@ -337,7 +350,6 @@ call uspt1d &
 nfpt1t = nfpt1d
 if (irangp.ge.0) then
   call parcpt(nfpt1t)
-  !==========
 endif
 
 if (nfpt1t.gt.0) then
@@ -346,7 +358,6 @@ if (nfpt1t.gt.0) then
 endif
 
 call vert1d &
-!==========
 ( nfabor , nfpt1d , iappel ,                                      &
   ivoid  , ivoid  , ivoid  ,                                      &
   rvoid  , rvoid  ,                                               &
@@ -415,15 +426,12 @@ else
 endif
 
 call init_aux_arrays(ncelet, nfabor)
-!===================
 
 call turbomachinery_init
-!=======================
 
 if (ippmod(iatmos).ge.0) then
 
   call init_meteo
-  !==============
 
   if (imbrication_flag) then
     call activate_imbrication
@@ -441,44 +449,35 @@ endif
 
 if (ippmod(icompf).ge.0) then
   call init_compf (nfabor)
-  !==============
 endif
 
 if (iale.eq.1.or.imobil.eq.1) then
   call init_ale (nfabor, nnod)
-  !============
 endif
 
 if (ippmod(ielarc).gt.0) then
   call init_elec
-  !==============
 endif
 
 if (ncpdct.gt.0) then
   call init_kpdc
-  !=============
 endif
 
 if (nctsmt.gt.0) then
   call init_tsma ( nvar )
-  !=============
 endif
 
 if (nftcdt.gt.0) then
   call init_pcond ( nvar )
-  !=============
   call init_nz_pcond
-  !=================
 endif
 
 if (icond.eq.1) then
   call init_vcond ( nvar, ncelet )
-  !=============
 endif
 
 if (nfpt1t.gt.0) then
   call init_pt1d
-  !=============
 endif
 
 ! Memory reservation for Lagrangian module
@@ -503,20 +502,29 @@ endif
 !===============================================================================
 
 call fldtri(nproce, dt, propce)
-!==========
 
 call field_allocate_or_map_all
-!=============================
 
 call iniva0(nvar, nscal, dt, propce, frcxt, prhyd)
-!==========
 
 ! Compute the porosity if needed
 if (iporos.ge.1) then
+
   if (iihmpr.eq.1) then
     call uiporo(ncelet, iporos)
   endif
   call usporo
+
+  call field_get_val_s(ipori, porosi)
+
+  do iel = 1, ncel
+    cell_f_vol(iel) = volume(iel) * porosi(iel)
+  enddo
+
+  if (irangp.ge.0.or.iperio.eq.1) then
+    call synsca(cell_f_vol)
+  endif
+
 endif
 
 !==============================================================================
@@ -532,27 +540,22 @@ if (nftcdt.gt.0) then
   iappel = 2
 
   call init_tagmr
-  !==============
 
   call init_nz_tagmr
-  !=================
 
   call cs_user_boundary_mass_source_terms &
-  !======================================
 ( nvar   , nscal  ,                                              &
   nfbpcd , iappel ,                                              &
   ifbpcd , itypcd , izftcd ,                                     &
   spcond , rvoid(1) )
 
   call init_nz_mesh_tagmr
-  !======================
 
   ! the Condensation model coupled with a 0-D thermal model
   ! to take into account the metal mass structures effects.
   if(itagms.eq.1) then
 
     call init_tagms
-    !==============
   endif
 
 endif
@@ -561,8 +564,15 @@ endif
 ! Possible restart
 !===============================================================================
 
+! Timer statistics
+
+restart_stats_id = timer_stats_id_by_name("checkpoint_restart_stage")
+post_stats_id = timer_stats_id_by_name("postprocessing_stage")
+
 if (isuite.eq.1) then
 
+  call timer_stats_start(restart_stats_id)
+
   call lecamo(frcxt, prhyd)
 
   ! Using ALE, geometric parameters must be recalculated
@@ -577,7 +587,6 @@ if (isuite.eq.1) then
     enddo
 
     call algrma(volmin, volmax, voltot)
-    !==========
 
     ! Abort at the end of the current time-step if there is a negative volume
     if (volmin.le.0.d0) ntmabs = ntcabs
@@ -590,7 +599,6 @@ if (isuite.eq.1) then
     ! Update mesh
 
     call turbomachinery_update_mesh(ttpmob, rvoid(1))
-    !==============================
 
     ! Update arrays whose size could have changed (nfac, ncelet)
 
@@ -623,6 +631,8 @@ if (isuite.eq.1) then
 
   endif
 
+  call timer_stats_stop(restart_stats_id)
+
 endif
 
 !===============================================================================
@@ -631,7 +641,6 @@ endif
 !===============================================================================
 
 call inivar(nvar, nscal, dt, propce)
-!==========
 
 !===============================================================================
 ! Radiative transfer: possible restart
@@ -639,7 +648,6 @@ call inivar(nvar, nscal, dt, propce)
 
 if (iirayo.gt.0 .and. isuird.eq.1) then
   call raylec
-  !==========
 endif
 
 !===============================================================================
@@ -649,7 +657,6 @@ endif
 if (iilagr.gt.0) then
 
   call laglec_m                                                   &
-  !============
  ( ncelet , ncel   , nfabor ,                                     &
    ntersl , nvlsta , nvisbr ,                                     &
    statis , stativ , parbor , tslagr )
@@ -674,7 +681,6 @@ if (nfpt1t.gt.0) then
 !            et de l'initialisation (IFPT1D,NPPT1D,EPPT1D,RGPT1D,TPPT1D)
   iappel = 2
   call  uspt1d &
-  !===========
  ( nvar   , nscal  , nfpt1d , iappel ,                            &
    ifpt1d , izft1d , nppt1d , iclt1d ,                            &
    tppt1d , rgpt1d , eppt1d ,                                     &
@@ -684,7 +690,6 @@ if (nfpt1t.gt.0) then
 
   iappel = 2
   call vert1d &
-  !==========
 ( nfabor , nfpt1d , iappel ,                                      &
   ifpt1d , nppt1d , iclt1d ,                                      &
   rgpt1d , eppt1d ,                                               &
@@ -696,13 +701,11 @@ if (nfpt1t.gt.0) then
     nmxt1d = max(nppt1d(iiii),nmxt1d)
   enddo
   if (irangp.ge.0) call parcmx(nmxt1d)
-                   !==========
 
   if (isuit1.eq.1) then
 
     ficsui = '1dwall_module'
     call lect1d &
-    !==========
  ( ficsui , len(ficsui), nfpt1d , nfpt1t ,           &
    nmxt1d , nfabor     , nppt1d , ifpt1d , eppt1d , &
    rgpt1d , tppt1d )
@@ -711,7 +714,6 @@ if (nfpt1t.gt.0) then
 !     Creation du maillage, initialisation de la temperature.
 
     call mait1d &
-    !==========
  ( nfpt1d, nppt1d, eppt1d, rgpt1d, tppt1d )
 
   endif
@@ -740,7 +742,6 @@ endif
 
 if (ippmod(iatmos).ge.2.and.iatsoil.eq.1) then
   call atmsol()
-  !============
 endif
 
 !===============================================================================
@@ -753,13 +754,18 @@ endif
 !     On appelle cependant cs_user_head_losses avec tous les processeurs,
 !     au cas ou l'utilisateur aurait mis en oeuvre des operations globales.
 
-if(ncpdct.gt.0) then
+if (ncpdct.gt.0) then
 
   iappel = 2
 
+  if (iflow .eq.1) then
+    do iel = 1, ncepdc
+      icepdc(iel) = iel
+    enddo
+  endif
+
   if (iihmpr.eq.1) then
     call uikpdc(iappel, ncelet, ncepdc, icepdc, ckupdc)
-    !==========
   endif
 
   call cs_user_head_losses &
@@ -790,8 +796,6 @@ if(nctsmt.gt.0) then
 endif
 
 
-
-
 ! -- Methode des vortex pour la L.E.S.
 !    (dans verini on s'est deja assure que ITYTUR=4 si IVRTEX=1)
 
@@ -800,23 +804,18 @@ if (ivrtex.eq.1) then
   allocate(irepvo(nfabor))
 
   call vorin0(nfabor)
-  !==========
 
   iappel = 1
 
   call usvort &
-  !==========
  ( nvar   , nscal  , iappel ,                                     &
    dt     )
 
   call vorver (nfabor, iappel)
-  !==========
 
   call init_vortex
-  !===============
 
   call vorpre
-  !==========
 
 endif
 
@@ -826,7 +825,6 @@ endif
 
 if (iale.eq.1) then
   call strini(dt)
-  !==========
 endif
 
 ! -- Fin de zone Structures mobiles en ALE
@@ -834,7 +832,6 @@ endif
 ! -- Couplage Code_Saturne/Code_Saturne
 
 call cscini(nvar)
-!==========
 
 !===============================================================================
 ! Start of time loop
@@ -880,15 +877,12 @@ if (itrale.gt.0) then
 
   if (idtvar.eq.0) then
     call cplsyn (ntmabs, ntcabs, dt(1))
-    !==========
   else if (idtvar.ne.1) then ! synchronization in dttvar if idtvar = 1
     call cplsyn (ntmabs, ntcabs, dtref)
-    !==========
   endif
 
   if (ntmabs .eq. ntcabs .and. inpdt0.eq.0) then
     call csexit (1)
-    !==========
   endif
 
 endif
@@ -897,12 +891,13 @@ endif
 
 if (inpdt0.eq.0 .and. itrale.gt.0) then
   ntcabs = ntcabs + 1
+  call timer_stats_increment_time_step
   if(idtvar.eq.0.or.idtvar.eq.1) then
     ttcabs = ttcabs + dt(1)
   else
     ttcabs = ttcabs + dtref
   endif
-  if(iwarn0.gt.0) then
+  if (iwarn0.gt.0) then
     write(nfecra,3001) ttcabs,ntcabs
   endif
   if (imobil.eq.1 .or. iturbo.eq.2) then
@@ -922,11 +917,14 @@ endif
 ! Test presence of control_file to modify ntmabs if required
 call cs_control_check_file
 
+if (      (idtvar.eq.0 .or. idtvar.eq.1)                          &
+    .and. (ttmabs.gt.0 .and. ttcabs.ge.ttmabs)) then
+  ntmabs = ntcabs
+endif
+
 call dmtmps(titer1)
-!==========
 
 call tridim                                                       &
-!==========
  ( itrale ,                                                       &
    nvar   , nscal  ,                                              &
    isostd ,                                                       &
@@ -948,12 +946,15 @@ endif
 
 if (iilagr.gt.0 .and. inpdt0.eq.0 .and. itrale.gt.0) then
 
+  call timer_stats_start(lagr_stats_id)
+
   call lagune                                                     &
-  !==========
  ( lndnod ,                                                       &
    nvar   , nscal  ,                                              &
    dt     , propce )
 
+  call timer_stats_stop(lagr_stats_id)
+
 endif
 
 !===============================================================================
@@ -962,23 +963,25 @@ endif
 
 if (itrale.gt.0) then
 
+  call timer_stats_start(post_stats_id)
+
   ! Sortie postprocessing de profils 1D
 
   if (iihmpr.eq.1) then
     call uiprof                                                   &
-    !==========
   ( ncelet , ncel,                                                &
     ntmabs, ntcabs, ttcabs, ttmabs, ttpabs,                       &
     xyzcen)
   endif
 
   call cs_f_user_extra_operations &
-  !==============================
  ( nvar   , nscal  ,                                              &
    dt     )
 
   call cs_user_extra_operations()
 
+  call timer_stats_stop(post_stats_id)
+
 endif
 
 !===============================================================================
@@ -990,7 +993,6 @@ if (iale.eq.1 .and. inpdt0.eq.0) then
   if (itrale.eq.0 .or. itrale.gt.nalinf) then
 
     call alemav &
-    !==========
   ( itrale ,                                               &
     impale , ialtyb ,                                      &
     dt     ,                                               &
@@ -1007,7 +1009,6 @@ endif
 ! Test for lack of remaining time
 
 call armtps(ntcabs,ntmabs)
-!==========
 
 ! Stop test from P-1 radiative model
 
@@ -1019,10 +1020,8 @@ endif
 
 if (idtvar.eq.0) then
   call cplsyn (ntmabs, ntcabs, dt(1))
-  !==========
 else if (idtvar.ne.1) then ! synchronization in dttvar if idtvar = 1
   call cplsyn (ntmabs, ntcabs, dtref)
-  !==========
 endif
 
 !===============================================================================
@@ -1030,45 +1029,39 @@ endif
 !===============================================================================
 
 call reqsui(iisuit)
-!==========
 
 if(ntcabs.lt.ntmabs .and.itrale.eq.0) iisuit = 0
 
 if (iisuit.eq.1) then
 
+  call timer_stats_start(restart_stats_id)
+
   if(ntcabs.lt.ntmabs) then
     if (iwarn0.gt.0) write(nfecra,3020) ntcabs, ttcabs
   else if(ntcabs.eq.ntmabs) then
     if(iwarn0.gt.0) write(nfecra,3021)ntcabs,ttcabs
   endif
 
-  call dmtmps(tecrf1)
-  !==========
-
   call ecrava(frcxt, prhyd)
 
   if (nfpt1t.gt.0) then
     ficsui = '1dwall_module'
     call ecrt1d                                                   &
-    !==========
  ( ficsui   , len(ficsui), nfpt1d   ,  nmxt1d  ,                  &
    nfabor   , tppt1d     , ifpt1d )
   endif
 
   if (nent.gt.0) then
     call ecrsyn('les_inflow'//c_null_char)
-    !==========
   endif
 
   if (ippmod(iaeros).ge.0) then
      call ecrctw ('cooling_towers'//c_null_char)
-     !==========
   endif
 
   if (iilagr.gt.0) then
 
     call lagout                                                      &
-    !==========
     ( ntersl , nvlsta , nvisbr ,                                     &
       propce )
 
@@ -1076,16 +1069,11 @@ if (iisuit.eq.1) then
 
   if (iirayo.gt.0) then
     call rayout
-    !==========
   endif
 
-  call dmtmps(tecrf2)
-  !==========
-
-  if(iwarn0.gt.0) write(nfecra,3022) tecrf2-tecrf1
-
   call stusui
-  !==========
+
+  call timer_stats_stop(restart_stats_id)
 
 endif ! iisuit = 1
 
@@ -1097,7 +1085,6 @@ call post_activate_by_time_step
 
 if (iihmpr.eq.1) then
   call uinpst(ntcabs, ttcabs)
-  !==========
 endif
 
 call cs_user_postprocess_activate(ntmabs, ntcabs, ttcabs)
@@ -1112,8 +1099,9 @@ if (itrale.eq.0) then
   call post_activate_writer(0, .false.)
 endif
 
+call timer_stats_start(post_stats_id)
+
 call pstvar                                                       &
-!==========
  ( ntcabs ,                                                       &
    nvar   , nscal  , nvlsta , nvisbr )
 
@@ -1137,17 +1125,14 @@ if ((nthist.gt.0 .or.frhist.gt.0.d0) .and. itrale.gt.0) then
     ttchis = ttcabs
 
     call ecrhis(modhis)
-    !==========
 
     if (iilagr.gt.0) then
       call laghis(ndim, ncelet, ncel, modhis, nvlsta,             &
-      !==========
                   xyzcen, volume, statis, stativ)
     endif
 
     if (ihistr.eq.1) then
       call strhis(modhis)
-      !==========
     endif
 
   endif
@@ -1155,7 +1140,6 @@ if ((nthist.gt.0 .or.frhist.gt.0.d0) .and. itrale.gt.0) then
 endif
 
 call ushist(nvar, nscal, dt)
-!==========
 
 !===============================================================================
 ! Write to "listing" every ntlist iterations
@@ -1171,7 +1155,6 @@ endif
 if (modntl.eq.0) then
 
   call ecrlis &
-  !==========
   ( ncelet , ncel   ,                                    &
     dt     , volume )
 
@@ -1179,38 +1162,32 @@ if (modntl.eq.0) then
 
   if (iilagr.gt.0) then
     call laglis                                                   &
-    !==========
     ( nvlsta , nvisbr ,                                           &
       statis , parbor )
   endif
 
 endif
 
+call timer_stats_stop(post_stats_id)
+
 call dmtmps(titer2)
-!==========
 
-if(iwarn0.gt.0) then
-  if (itrale.gt.0) then
-    write(nfecra,3010)ntcabs,titer2-titer1
-  else
-    write(nfecra,3012)titer2-titer1
-  endif
+if (iwarn0.gt.0 .and. itrale.le.0) then
+  write(nfecra,3012)titer2-titer1
 endif
 
-
 !===============================================================================
 ! End of time loop
 !===============================================================================
 
 itrale = itrale + 1
 
-if(ntcabs.lt.ntmabs) goto 100
+if (ntcabs.lt.ntmabs) goto 100
 
 ! Final synchronization for variable time step
 
 if (idtvar.eq.1) then
   call cplsyn (ntmabs, ntcabs, dtref)
-  !==========
 endif
 
 ! LIBERATION DES TABLEAUX INTERMEDIAIRES (PDC+TSM)
@@ -1223,31 +1200,28 @@ if(iwarn0.gt.0) then
   write(nfecra,4000)
 endif
 
-call dmtmps(tecrf1)
-!==========
-
 ! Ici on sauve les historiques (si on en a stocke)
 
+call timer_stats_start(post_stats_id)
+
 modhis = 2
 call ecrhis(modhis)
-!==========
 
 if (iilagr.gt.0) then
   call laghis(ndim, ncelet, ncel, modhis , nvlsta,                &
-  !==========
               xyzcen, volume, statis, stativ)
 endif
 if (ihistr.eq.1) then
   call strhis(modhis)
-  !==========
 endif
 
+call timer_stats_stop(post_stats_id)
+
 !     LE CAS ECHEANT, ON LIBERE LES STRUCTURES C DU MODULE THERMIQUE 1D
 !     ET/OU ON FERME LE LISTING LAGRANGIEN
 
 if (nfpt1d.gt.0) then
   call lbrt1d
-  !==========
 endif
 
 ! Free main arrays
@@ -1336,7 +1310,6 @@ if (icond.eq.1) then
   call finalize_vcond
   if (itagms.eq.1) then
     call finalize_tagms
-    !==================
   endif
 endif
 
@@ -1348,13 +1321,6 @@ if (ivrtex.eq.1) then
   call finalize_vortex
 endif
 
-call dmtmps(tecrf2)
-!==========
-
-if(iwarn0.gt.0) then
-  write(nfecra,4010)tecrf2-tecrf1
-endif
-
 !===============================================================================
 ! Memory usage
 !===============================================================================
@@ -1362,15 +1328,10 @@ endif
 !     Liberation des structures liees a la lecture du fichier xml
 
 if (iihmpr.eq.1) then
-
   call memui2
-  !==========
-
   call memui1(ncharb)
-  !==========
 endif
 
-
 write(nfecra,7000)
 
 !----
@@ -1400,9 +1361,6 @@ write(nfecra,7000)
  3002 format(/,' INSTANT ',E18.9,        '   INITIALISATION ALE ',/,    &
 ' ============================================================= ',&
  /,/)
- 3010 format(/,' TEMPS POUR L''ITERATION ',I15,' :    ',E14.5,/,/,      &
-'===============================================================',&
- /)
  3012 format(/,' TEMPS POUR L''INITIALISATION ALE :    ',E14.5,/,/,     &
 '===============================================================',&
  /)
@@ -1412,8 +1370,6 @@ write(nfecra,7000)
  3021 format(/,/,                                                 &
  ' Sortie finale de fichiers suite',/,                     &
  '   Sauvegarde a l''iteration ', I10, ', Temps physique ',E14.5,/,/)
- 3022 format(/,/,                                                 &
- ' Temps pour les fichiers suite : ',E14.5,/,/)
 
  4000 format(/,/,                                                 &
 '===============================================================',&
@@ -1427,9 +1383,6 @@ write(nfecra,7000)
 ' =========================================================== ',/,&
                                                                 /,&
                                                                 /)
- 4010 format(                                                   /,&
- 3X,'** TEMPS POUR LES SORTIES FINALES : ',E14.5               ,/,&
- 3X,'   ------------------------------                        ',/)
  7000 format(/,/,                                                 &
 ' =========================================================== ',/,&
                                                               /,/,&
@@ -1464,9 +1417,6 @@ write(nfecra,7000)
  3002 format(/,' INSTANT ',E18.9,        '   ALE INITIALIZATION ',/,    &
 ' ============================================================= ',&
  /,/)
- 3010 format(/,' TIME FOR THE TIME STEP  ',I15,':     ',E14.5,/,/,  &
-'===============================================================',&
- /)
  3012 format(/,' TIME FOR ALE INITIALIZATION:        ',E14.5,/,/, &
 '===============================================================',&
  /)
@@ -1476,8 +1426,6 @@ write(nfecra,7000)
  3021 format(/,/,                                                 &
  ' Write final restart files',/,                                  &
  '   checkpoint at iteration ',    I10,  ', Physical time ',E14.5,/,/)
- 3022 format(/,/,                                                 &
- ' Time for restart files: ',E14.5,/,/)
 
  4000 format(/,/,                                                 &
 '===============================================================',&
@@ -1491,9 +1439,6 @@ write(nfecra,7000)
 ' =========================================================== ',/,&
                                                                 /,&
                                                                 /)
- 4010 format(                                                   /,&
- 3X,'** TIME FOR FINAL WRITING: ',E14.5                        ,/,&
- 3X,'   -----------------------                                ',/)
  7000 format(/,/,                                                 &
 ' =========================================================== ',/,&
                                                               /,/,&
