@@ -61,6 +61,7 @@
 #include "bft_printf.h"
 
 #include "cs_prototypes.h"
+#include "cs_log.h"
 #include "cs_timer.h"
 
 /*----------------------------------------------------------------------------
@@ -261,7 +262,7 @@ _cs_base_err_vprintf(const char  *format,
                                                             is unusable. */
 #endif
       for (i = cs_glob_n_ranks; i >= 10; i /= 10, n_dec += 1);
-      sprintf(err_file_name, "error_n%0*d", n_dec, cs_glob_rank_id + 1);
+      sprintf(err_file_name, "error_r%0*d", n_dec, cs_glob_rank_id);
     }
 
     freopen(err_file_name, "w", stderr);
@@ -390,9 +391,12 @@ _error_mem_summary(void)
     (_("Theoretical current allocated memory:   %llu kB\n"),
      (unsigned long long)(bft_mem_size_current()));
 
-  _cs_base_err_printf
-    (_("Theoretical maximum allocated memory:   %llu kB\n"),
-     (unsigned long long)(bft_mem_size_max()));
+  mem_usage = bft_mem_size_max();
+
+  if (mem_usage > 0)
+    _cs_base_err_printf
+      (_("Theoretical maximum allocated memory:   %llu kB\n"),
+       (unsigned long long)(bft_mem_size_max()));
 
   if (bft_mem_usage_initialized() == 1) {
 
@@ -1296,10 +1300,13 @@ cs_exit(int  status)
 
 /*----------------------------------------------------------------------------
  * Initialize error and signal handlers.
+ *
+ * parameters:
+ *   signal_defaults <-- leave default signal handlers in place if true
  *----------------------------------------------------------------------------*/
 
 void
-cs_base_error_init(void)
+cs_base_error_init(bool  signal_defaults)
 {
   /* Error handler */
 
@@ -1309,30 +1316,34 @@ cs_base_error_init(void)
 
   /* Signal handlers */
 
-  bft_backtrace_print_set(_cs_base_backtrace_print);
+  if (signal_defaults == false) {
+
+    bft_backtrace_print_set(_cs_base_backtrace_print);
 
 #if defined(SIGHUP)
-  if (cs_glob_rank_id <= 0)
-    cs_glob_base_sighup_save  = signal(SIGHUP, _cs_base_sig_fatal);
+    if (cs_glob_rank_id <= 0)
+      cs_glob_base_sighup_save  = signal(SIGHUP, _cs_base_sig_fatal);
 #endif
 
-  if (cs_glob_rank_id <= 0) {
-    cs_glob_base_sigint_save  = signal(SIGINT, _cs_base_sig_fatal);
-    cs_glob_base_sigterm_save = signal(SIGTERM, _cs_base_sig_fatal);
-  }
+    if (cs_glob_rank_id <= 0) {
+      cs_glob_base_sigint_save  = signal(SIGINT, _cs_base_sig_fatal);
+      cs_glob_base_sigterm_save = signal(SIGTERM, _cs_base_sig_fatal);
+    }
 
-  cs_glob_base_sigfpe_save  = signal(SIGFPE, _cs_base_sig_fatal);
-  cs_glob_base_sigsegv_save = signal(SIGSEGV, _cs_base_sig_fatal);
+    cs_glob_base_sigfpe_save  = signal(SIGFPE, _cs_base_sig_fatal);
+    cs_glob_base_sigsegv_save = signal(SIGSEGV, _cs_base_sig_fatal);
 
 #if defined(__bgq__)
-  cs_glob_base_sigabrt_save  = signal(SIGABRT, _cs_base_sig_fatal);
-  cs_glob_base_sigtrap_save  = signal(SIGTRAP, _cs_base_sig_fatal);
+    cs_glob_base_sigabrt_save  = signal(SIGABRT, _cs_base_sig_fatal);
+    cs_glob_base_sigtrap_save  = signal(SIGTRAP, _cs_base_sig_fatal);
 #endif
 
 #if defined(SIGXCPU)
-  if (cs_glob_rank_id <= 0)
-    cs_glob_base_sigcpu_save = signal(SIGXCPU, _cs_base_sig_fatal);
+    if (cs_glob_rank_id <= 0)
+      cs_glob_base_sigcpu_save = signal(SIGXCPU, _cs_base_sig_fatal);
 #endif
+
+  }
 }
 
 /*----------------------------------------------------------------------------
@@ -1361,39 +1372,45 @@ cs_base_mem_init(void)
 
   /* Memory management initialization */
 
-  if ((base_name = getenv("CS_MEM_LOG")) != NULL) {
-
-    /* We may not use BFT_MALLOC here as memory management has
-       not yet been initialized using bft_mem_init() */
-
-    if (base_name != NULL) {
-
-      /* In parallel, we will have one trace file per MPI process */
-      if (cs_glob_rank_id >= 0) {
-        int i;
-        int n_dec = 1;
-        for (i = cs_glob_n_ranks; i >= 10; i /= 10, n_dec += 1);
-        file_name = malloc((strlen(base_name) + n_dec + 2) * sizeof (char));
-        sprintf(file_name, "%s.%0*d", base_name, n_dec, cs_glob_rank_id + 1);
-      }
-      else {
-        file_name = malloc((strlen(base_name) + 1) * sizeof (char));
-        strcpy(file_name, base_name);
-      }
-    }
-
-  }
-
   if (bft_mem_initialized())
     cs_glob_base_bft_mem_init = false;
 
   else {
-    cs_glob_base_bft_mem_init = true;
-    bft_mem_init(file_name);
-  }
 
-  if (file_name != NULL)
-    free (file_name);
+    if ((base_name = getenv("CS_MEM_LOG")) != NULL) {
+
+      /* We may not use BFT_MALLOC here as memory management has
+         not yet been initialized using bft_mem_init() */
+
+      if (base_name != NULL) {
+
+        /* In parallel, we will have one trace file per MPI process */
+        if (cs_glob_rank_id >= 0) {
+          int i;
+          int n_dec = 1;
+          for (i = cs_glob_n_ranks; i >= 10; i /= 10, n_dec += 1);
+          file_name = malloc((strlen(base_name) + n_dec + 2) * sizeof (char));
+          sprintf(file_name, "%s.%0*d", base_name, n_dec, cs_glob_rank_id);
+        }
+        else {
+          file_name = malloc((strlen(base_name) + 1) * sizeof (char));
+          strcpy(file_name, base_name);
+        }
+
+        /* Actually initialize bft_mem instrumentation only when
+           CS_MEM_LOG is defined (for better performance) */
+
+        bft_mem_init(file_name);
+
+        free (file_name);
+
+      }
+
+    }
+
+    cs_glob_base_bft_mem_init = true;
+
+  }
 }
 
 /*----------------------------------------------------------------------------
@@ -1423,7 +1440,8 @@ cs_base_mem_finalize(void)
 
   /* Memory summary */
 
-  bft_printf(_("\nMemory use summary:\n\n"));
+  cs_log_printf(CS_LOG_PERFORMANCE,
+                _("\nMemory use summary:\n\n"));
 
   valreal[0] = (double)bft_mem_usage_max_pr_size();
   valreal[1] = (double)bft_mem_size_max();
@@ -1486,23 +1504,29 @@ cs_base_mem_finalize(void)
 
       /* Print to log file */
 
-      bft_printf(_("  %s %12.3f %ciB\n"),
-                 _(type_bil[ind_bil]), valreal[ind_bil], unit[itot]);
+      cs_log_printf(CS_LOG_PERFORMANCE,
+                    _("  %s %12.3f %ciB\n"),
+                    _(type_bil[ind_bil]), valreal[ind_bil], unit[itot]);
 
 #if defined(HAVE_MPI)
       if (cs_glob_n_ranks > 1 && cs_glob_rank_id == 0) {
-        bft_printf(_("                             "
-                     "local minimum: %12.3f %ciB  (rank %d)\n"),
-                   val_min[ind_bil].val, unit[imin], val_min[ind_bil].rank);
-        bft_printf(_("                             "
-                     "local maximum: %12.3f %ciB  (rank %d)\n"),
-                   val_max[ind_bil].val, unit[imax], val_max[ind_bil].rank);
+        cs_log_printf(CS_LOG_PERFORMANCE,
+                      _("                             "
+                        "local minimum: %12.3f %ciB  (rank %d)\n"),
+                      val_min[ind_bil].val, unit[imin], val_min[ind_bil].rank);
+        cs_log_printf(CS_LOG_PERFORMANCE,
+                      _("                             "
+                        "local maximum: %12.3f %ciB  (rank %d)\n"),
+                      val_max[ind_bil].val, unit[imax], val_max[ind_bil].rank);
       }
 #endif
     }
 
   }
 
+  cs_log_printf(CS_LOG_PERFORMANCE, "\n");
+  cs_log_separator(CS_LOG_PERFORMANCE);
+
   /* Finalize memory handling */
 
   if (cs_glob_base_bft_mem_init == true) {
@@ -1535,7 +1559,8 @@ cs_base_time_summary(void)
 
   /*xxxxxxxxxxxxxxxxxxxxxxxxxxx Instructions xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx*/
 
-  bft_printf(_("\nCalculation time summary:\n"));
+  cs_log_printf(CS_LOG_PERFORMANCE,
+                _("\nCalculation time summary:\n"));
 
   cs_timer_cpu_times(&utime, &stime);
 
@@ -1548,15 +1573,18 @@ cs_base_time_summary(void)
   /* CPU time */
 
   if (utime > 0. || stime > 0.) {
-    bft_printf (_("\n  User CPU time:       %12.3f s\n"),
-                (float)utime);
-    bft_printf (_("  System CPU time:     %12.3f s\n"),
-                (float)stime);
+    cs_log_printf(CS_LOG_PERFORMANCE,
+                  _("\n  User CPU time:       %12.3f s\n"),
+                  (float)utime);
+    cs_log_printf(CS_LOG_PERFORMANCE,
+                  _("  System CPU time:     %12.3f s\n"),
+                  (float)stime);
   }
 
   else if (time_cpu > 0.)
-    bft_printf (_("\n  CPU time:            %12.3f s\n"),
-                (float)time_cpu);
+    cs_log_printf(CS_LOG_PERFORMANCE,
+                  _("\n  CPU time:            %12.3f s\n"),
+                  (float)time_cpu);
 
 #if defined(HAVE_MPI)
   if (cs_glob_n_ranks > 1) {
@@ -1564,8 +1592,9 @@ cs_base_time_summary(void)
     MPI_Reduce (&time_cpu, &time_cumul, 1, MPI_DOUBLE, MPI_SUM,
                 0, cs_glob_mpi_comm);
     if (cs_glob_rank_id == 0)
-      bft_printf (_("  Total CPU time:      %12.3f s\n"),
-                  time_cumul);
+      cs_log_printf(CS_LOG_PERFORMANCE,
+                    _("  Total CPU time:      %12.3f s\n"),
+                    time_cumul);
   }
 #endif
 
@@ -1575,14 +1604,18 @@ cs_base_time_summary(void)
 
   if (time_tot > 0.) {
 
-    bft_printf (_("\n  Elapsed time:        %12.3f s\n"),
-                time_tot);
+    cs_log_printf(CS_LOG_PERFORMANCE,
+                  _("\n  Elapsed time:        %12.3f s\n"),
+                  time_tot);
 
-    bft_printf (_("  CPU / elapsed time   %12.3f\n"),
-                (float)(time_cpu/time_tot));
+    cs_log_printf(CS_LOG_PERFORMANCE,
+                  _("  CPU / elapsed time   %12.3f\n"),
+                  (float)(time_cpu/time_tot));
 
   }
 
+  cs_log_printf(CS_LOG_PERFORMANCE, "\n");
+  cs_log_separator(CS_LOG_PERFORMANCE);
 }
 
 /*----------------------------------------------------------------------------
@@ -1627,10 +1660,10 @@ cs_base_bft_printf_init(const char  *log_name,
       for (i = cs_glob_n_ranks; i >= 10; i /= 10, n_dec += 1);
       BFT_MALLOC(_bft_printf_file_name, strlen(log_name) + n_dec + 3, char);
       sprintf(_bft_printf_file_name,
-              "%s_n%0*d",
+              "%s_r%0*d",
               log_name,
               n_dec,
-              cs_glob_rank_id+1);
+              cs_glob_rank_id);
 
     }
 
