@@ -79,7 +79,7 @@ implicit none
 ! Local variables
 
 integer          iel   , iscal, ifcvsl, iesp, jesp, ierror
-integer          f_id  , ii
+integer          f_id
 
 character(len=80) :: name_i, name_j, name_d
 
@@ -242,32 +242,32 @@ do iel = 1, ncel
   cpro_cp(iel) = cpro_cp(iel) + y_d(iel)*s_d%cp
 enddo
 
-!===========================================================
+!==================================================================
 ! gas mixture density function of the temperature, pressure
 ! and the species scalars with taking into account the
 ! dilatable effects, as below:
 !             ----------------------
 ! - with inlet/outlet conditions:
-!   [idilat=2]: rho= p0/(rr. temp(1/sum[y_i/M_i]))
+!   [idilat=2]: rho= p0/(R. temp(1/sum[y_i/M_i]))
 ! - with only wall conditions:
-!   [idilat=3]: rho= pther/(rr. temp(1/sum[y_i/M_i]))
+!   [idilat=3]: rho= pther/(R. temp(1/sum[y_i/M_i]))
 !             ----------------------
-!         i ={1, .. ,N} species scalar number
-!         y_i  : mass fraction of each species
-!         M_i  : molar fraction [kg/mole]
-!         rr   : prefect gas constant [J/mole/K]
-!         p0   : atmos. pressure (Pa)
-!         pther: pressure (Pa) integrated on the
-!                fluid domain
-!===========================================================
+!         i ={1, .. ,N} : species scalar number
+!         y_i           : mass fraction of each species
+!         M_i           : molar fraction [kg/mole]
+!         R             : ideal gas constant [J/mole/K]
+!         p0            : atmos. pressure (Pa)
+!         pther         : pressure (Pa) integrated on the
+!                         fluid domain
+!==================================================================
 
 do iel = 1, ncel
   ! Evaluate the temperature thanks to the enthalpy
   tk = cvar_enth(iel)/ cpro_cp(iel)
   if (idilat.eq.3) then
-    cpro_rho(iel) = pther*mix_mol_mas(iel)/(rr*tk)
+    cpro_rho(iel) = pther*mix_mol_mas(iel)/(cs_physical_constants_r*tk)
   else
-    cpro_rho(iel) = p0*mix_mol_mas(iel)/(rr*tk)
+    cpro_rho(iel) = p0*mix_mol_mas(iel)/(cs_physical_constants_r*tk)
   endif
 enddo
 
@@ -359,20 +359,16 @@ enddo
 ! the physical properties filled for the gas mixture
 !=====================================================
 ! Same diffusivity for all the scalars except the enthalpy
-do ii = 1, nscapp
+do iesp = 1, nscasp
 
-  iscal = iscapp(ii)
+  iscal = iscasp(iesp)
 
-  if (iscal.ne.iscalt) then
+  call field_get_key_int (ivarfl(isca(iscal)), kivisl, ifcvsl)
+  call field_get_val_s(ifcvsl, cpro_vyk)
 
-    call field_get_key_int (ivarfl(isca(iscal)), kivisl, ifcvsl)
-    call field_get_val_s(ifcvsl, cpro_vyk)
-
-    do iel = 1, ncel
-      cpro_vyk(iel)= cpro_viscl(iel)
-    enddo
-
-  endif
+  do iel = 1, ncel
+    cpro_vyk(iel)= cpro_viscl(iel)
+  enddo
 
 enddo
 
