@@ -36,6 +36,9 @@
 #include "cs_mesh_quantities.h"
 #include "cs_mesh_bad_cells.h"
 
+#include "cs_cdo_connect.h"
+#include "cs_cdo_quantities.h"
+
 /*----------------------------------------------------------------------------*/
 
 BEGIN_C_DECLS
@@ -375,6 +378,17 @@ cs_user_partition(void);
 void
 cs_user_matrix_tuning(void);
 
+/*----------------------------------------------------------------------------
+ * Define or modify general numerical and physical user parameters.
+ *
+ * At the calling point of this function, most model-related most varibles
+ * and other fields have been defined, so speciic settings related to those
+ * fields may be set here.
+ *----------------------------------------------------------------------------*/
+
+void
+cs_user_parameters(void);
+
 /*----------------------------------------------------------------------------
  * Define periodic faces.
  *----------------------------------------------------------------------------*/
@@ -471,6 +485,80 @@ cs_user_turbomachinery(void);
 void
 cs_user_turbomachinery_rotor(void);
 
+
+/*============================================================================
+ *  CDO User function prototypes
+ *============================================================================*/
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Initialize the specifications for the current simulation
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_user_cdo_setup(void);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Setup advanced features concerning the way geometric quantities
+ *         are built
+ *
+ * \return the type of computation to evaluate the cell center
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_cdo_cc_algo_t
+cs_user_cdo_geometric_settings(void);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Setup advanced features concerning the numerical parameters
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_user_cdo_numeric_settings(void);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Setup advanced features concerning the discrete Hodge operators
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_user_cdo_hodge_settings(void);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Setup advanced features concerning the resolution of linear systems
+ *         within the CDO framework
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_user_cdo_itsol_settings(void);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Additional operations on results produced by CDO schemes.
+ *         Define advanced post-processing and/or analysis for instance.
+ *
+ * \param[in]  m        pointer to a cs_mesh_t struct.
+ * \param[in]  mq       pointer to a cs_quantities_t struct.
+ * \param[in]  connect  pointer to a cs_cdo_connect_t structure
+ * \param[in]  quant    pointer to a cs_cdo_quantities_t structure
+ * \param[in]  tcur     current physical time of the simulation
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_user_cdo_extra_op(const cs_mesh_t             *m,
+                     const cs_mesh_quantities_t  *mq,
+                     const cs_cdo_connect_t      *connect,
+                     const cs_cdo_quantities_t   *quant,
+                     double                       tcur);
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
