@@ -532,72 +532,6 @@ _write_ent_values(const cs_restart_t     *r,
 
 #endif /* #if defined(HAVE_MPI) */
 
-/*----------------------------------------------------------------------------
- * Convert read/write arguments from the Fortran API to the C API.
- *
- * parameters:
- *   itysup   <-- location type code
- *   irtype   <-- integer or real
- *   location  <-- location id
- *   val_type <-- integer of real
- *----------------------------------------------------------------------------*/
-
-static void
-_section_f77_to_c(const cs_int_t          *itysup,
-                  const cs_int_t          *irtype,
-                  int                     *location,
-                  cs_restart_val_type_t   *val_type)
-{
-  /* Location associated with section */
-
-  switch (*itysup) {
-
-  case 0:
-    *location = CS_MESH_LOCATION_NONE;
-    break;
-
-  case 1:
-    *location = CS_MESH_LOCATION_CELLS;
-    break;
-
-  case 2:
-    *location = CS_MESH_LOCATION_INTERIOR_FACES;
-    break;
-
-  case 3:
-    *location = CS_MESH_LOCATION_BOUNDARY_FACES;
-    break;
-
-  case 4:
-    *location = CS_MESH_LOCATION_VERTICES;
-    break;
-
-  default:
-    *location = *itysup;
-
-  }
-
-  /* Val_Type associated with section */
-
-  switch (*irtype) {
-
-  case 1:
-    *val_type = CS_TYPE_cs_int_t;
-    break;
-
-  case 2:
-    *val_type = CS_TYPE_cs_real_t;
-    break;
-
-  default:
-    bft_error(__FILE__, __LINE__, 0,
-              _("Value type <%d> given for a restart file section\n"
-                "is invalid using the Fortran API."), (int)(*irtype));
-    return;
-
-  }
-}
-
 /*----------------------------------------------------------------------------
  * Swap values of a renumbered array when reading
  *
