@@ -70,6 +70,7 @@
 #include "cs_rotation.h"
 #include "cs_time_step.h"
 #include "cs_timer.h"
+#include "cs_timer_stats.h"
 
 /*----------------------------------------------------------------------------
  * Header for the current file
@@ -583,8 +584,6 @@ _check_geometry(cs_mesh_t  *mesh)
 {
   cs_turbomachinery_t *tbm = cs_glob_turbomachinery;
 
-  cs_lnum_t  f_id;
-
   cs_gnum_t n_errors = 0;
 
   const int  *cell_flag = tbm->cell_rotor_num;
@@ -830,6 +829,9 @@ cs_turbomachinery_update_mesh(double   t_cur_mob,
   cs_halo_type_t halo_type = cs_glob_mesh->halo_type;
   cs_turbomachinery_t *tbm = cs_glob_turbomachinery;
 
+  int t_stat_id = cs_timer_stats_id_by_name("mesh_processing");
+  int t_top_id = cs_timer_stats_switch(t_stat_id);
+
   t_start = cs_timer_wtime();
 
   /* Indicates we are in the framework of turbomachinery */
@@ -1010,6 +1012,8 @@ cs_turbomachinery_update_mesh(double   t_cur_mob,
   t_end = cs_timer_wtime();
 
   *t_elapsed = t_end - t_start;
+
+  cs_timer_stats_switch(t_top_id);
 }
 
 /*----------------------------------------------------------------------------*/
