@@ -61,6 +61,9 @@ module cstphy
   double precision :: rair
   parameter(rair = 287.d0)
 
+  !> Perfect gas constant in \f$J/mol/K\f$
+  real(c_double), pointer, save :: cs_physical_constants_r
+
   !> Gravity
   real(c_double), pointer, save :: gx, gy, gz
 
@@ -69,7 +72,19 @@ module cstphy
 
   !> Physical constants of the fluid
   !> filling \ref xyzp0 indicator
-  integer(c_int), pointer, save ::          ixyzp0
+  integer(c_int), pointer, save :: ixyzp0
+
+  !> indicates the equation of state for compressible module. Only perfect gas
+  !> with a constant adiabatic coefficient, \ref ieos=1 is available, but the
+  !> user can complete the file \ref cs_cf_thermo.h, which is not a user
+  !> source, to add new equations of state.
+  integer(c_int), pointer, save :: ieos
+
+  !> isobaric specific heat \f$ C_p \f$
+  integer(c_int), pointer, save :: icp
+
+  !> isochoric specific heat \f$ C_v \f$
+  integer(c_int), pointer, save :: icv
 
   !> reference density.
   !> Negative value: not initialized.
@@ -166,7 +181,7 @@ module cstphy
   !> so that \ref optcal::iscalt "iscalt" = n and \ref optcal::itherm "itherm" = 1
   !> (there is a "temperature" scalar),
   !> unless the user specifies the specific heat in the user subroutine
-  !> \ref usphyv (\ref numvar::icp "icp" > 0) with the compressible module or
+  !> \ref usphyv (\ref cstphy::icp "icp" > 0) with the compressible module or
   !>  coal combustion, \ref cp0 is also needed even when there is no user scalar.
   !> \note None of the scalars from the specific physics is a temperature.
   !> \note When using the Graphical Interface, \ref cp0 is also used to
@@ -175,7 +190,20 @@ module cstphy
   !> diffusivity is also specified in \ref usphyv.
   real(c_double), pointer, save :: cp0
 
-  !> molar mass of the perfect gas in \f$ kg/mol \f$ (if \ref ppincl::ieos "ieos"=1)
+  !> Reference isochoric specific heat.
+  !>
+  !> Useful for the compressible module (J/kg/K)
+  real(c_double), pointer, save :: cv0
+
+  !> Stiffened gas (ieos=2) limit pressure (Pa)
+  !> Equal to zero in perfect gas
+  real(c_double), pointer, save :: psginf
+
+  !> Stiffened gas (ieos=2) polytropic coefficient (dimensionless)
+  real(c_double), pointer, save :: gammasg
+
+  !> Molar mass of the perfect gas in \f$ kg/mol \f$
+  !> (if \ref cstphy::ieos "ieos"=1)
   !>
   !> Always useful
   real(c_double), pointer, save :: xmasmr
@@ -213,9 +241,8 @@ module cstphy
 
   !> limit value of \f$y^+\f$ for the viscous sublayer.
   !> \ref ypluli depends on the chosen wall function: it is
-  !> initialized to 10.88 for the scalable wall function
-  !> (\ref optcal::ideuch "ideuch"=2),
-  !> otherwise it is initialised to \f$1/\kappa\approx 2,38\f$.
+  !> initialized to 10.88 for the scalable wall function (\ref optcal::iwallf "iwallf"=4),
+  !> otherwise it is initialized to \f$1/\kappa\approx 2,38\f$.
   !> In LES, \ref ypluli is taken by default to be 10.88.
   !>
   !> Always useful
@@ -666,25 +693,29 @@ module cstphy
     ! Interface to C function retrieving pointers to members of the
     ! global physical constants structure
 
-    subroutine cs_f_physical_constants_get_pointers(gx, gy, gz, icorio) &
+    subroutine cs_f_physical_constants_get_pointers(cs_physical_constants_r, &
+                                                    gx, gy, gz,              &
+                                                    icorio)                  &
       bind(C, name='cs_f_physical_constants_get_pointers')
       use, intrinsic :: iso_c_binding
       implicit none
-      type(c_ptr), intent(out) :: gx, gy, gz, icorio
+      type(c_ptr), intent(out) :: cs_physical_constants_r, gx, gy, gz, icorio
     end subroutine cs_f_physical_constants_get_pointers
 
     ! Interface to C function retrieving pointers to members of the
     ! global fluid properties structure
 
-    subroutine cs_f_fluid_properties_get_pointers(ixyzp0, ro0, viscl0, p0, &
-                                                  pred0, xyzp0, t0, cp0,   &
-                                                  xmasmr, pther, pthera,   &
-                                                  pthermax)                &
+    subroutine cs_f_fluid_properties_get_pointers(ixyzp0, ieos, icp, icv, ro0, &
+                                                  viscl0, p0, pred0, xyzp0, t0,&
+                                                  cp0, cv0, xmasmr, psginf,    &
+                                                  gammasg, pther, pthera,      &
+                                                  pthermax)                    &
       bind(C, name='cs_f_fluid_properties_get_pointers')
       use, intrinsic :: iso_c_binding
       implicit none
-      type(c_ptr), intent(out) :: ixyzp0, ro0, viscl0, p0, pred0, xyzp0, t0, cp0
-      type(c_ptr), intent(out) :: xmasmr, pther, pthera, pthermax
+      type(c_ptr), intent(out) :: ixyzp0, ieos, icp, icv, ro0, viscl0, p0, pred0
+      type(c_ptr), intent(out) :: xyzp0, t0, cp0, cv0, xmasmr, psginf, gammasg
+      type(c_ptr), intent(out) :: pther, pthera, pthermax
     end subroutine cs_f_fluid_properties_get_pointers
 
     ! Interface to C function retrieving pointers to members of the
@@ -741,10 +772,12 @@ contains
 
     ! Local variables
 
-    type(c_ptr) :: c_gx, c_gy, c_gz, c_icorio
+    type(c_ptr) :: c_cs_physical_constants_r, c_gx, c_gy, c_gz, c_icorio
 
-    call cs_f_physical_constants_get_pointers(c_gx, c_gy, c_gz, c_icorio)
+    call cs_f_physical_constants_get_pointers(c_cs_physical_constants_r, c_gx, &
+                                              c_gy, c_gz, c_icorio)
 
+    call c_f_pointer(c_cs_physical_constants_r, cs_physical_constants_r)
     call c_f_pointer(c_gx, gx)
     call c_f_pointer(c_gy, gy)
     call c_f_pointer(c_gz, gz)
@@ -762,15 +795,21 @@ contains
 
     ! Local variables
 
-    type(c_ptr) :: c_ixyzp0, c_ro0, c_viscl0, c_p0, c_pred0, c_xyzp0, c_t0
-    type(c_ptr) :: c_cp0, c_xmasmr, c_pther, c_pthera, c_pthermax
+    type(c_ptr) :: c_ixyzp0, c_ieos, c_icp, c_icv, c_ro0, c_viscl0, c_p0
+    type(c_ptr) :: c_pred0, c_xyzp0, c_t0, c_cp0, c_cv0, c_xmasmr, c_psginf
+    type(c_ptr) :: c_gammasg, c_pther, c_pthera, c_pthermax
+
+    call cs_f_fluid_properties_get_pointers(c_ixyzp0, c_ieos, c_icp, c_icv, &
+                                            c_ro0, c_viscl0, c_p0, c_pred0, &
+                                            c_xyzp0, c_t0, c_cp0, c_cv0,    &
+                                            c_xmasmr, c_psginf, c_gammasg,  &
+                                            c_pther, c_pthera, c_pthermax)
 
-    call cs_f_fluid_properties_get_pointers(c_ixyzp0, c_ro0, c_viscl0, c_p0, &
-                                            c_pred0, c_xyzp0, c_t0, c_cp0,   &
-                                            c_xmasmr, c_pther, c_pthera,     &
-                                            c_pthermax)
 
     call c_f_pointer(c_ixyzp0, ixyzp0)
+    call c_f_pointer(c_ieos, ieos)
+    call c_f_pointer(c_icp, icp)
+    call c_f_pointer(c_icv, icv)
     call c_f_pointer(c_ro0, ro0)
     call c_f_pointer(c_viscl0, viscl0)
     call c_f_pointer(c_p0, p0)
@@ -778,7 +817,10 @@ contains
     call c_f_pointer(c_xyzp0, xyzp0, [3])
     call c_f_pointer(c_t0, t0)
     call c_f_pointer(c_cp0, cp0)
+    call c_f_pointer(c_cv0, cv0)
     call c_f_pointer(c_xmasmr, xmasmr)
+    call c_f_pointer(c_psginf, psginf)
+    call c_f_pointer(c_gammasg, gammasg)
     call c_f_pointer(c_pther, pther)
     call c_f_pointer(c_pthera, pthera)
     call c_f_pointer(c_pthermax, pthermax)
@@ -797,7 +839,7 @@ contains
 
     type(c_ptr) :: c_almax , c_uref  , c_xlomlg
 
-    call cs_f_turb_reference_values( c_almax, c_uref, c_xlomlg)
+    call cs_f_turb_reference_values(c_almax, c_uref, c_xlomlg)
 
     call c_f_pointer(c_almax , almax )
     call c_f_pointer(c_uref  , uref  )
@@ -805,24 +847,6 @@ contains
 
   end subroutine turb_reference_values_init
 
-  !> \brief Initialize Fortran wall functions API.
-  !> This maps Fortran pointers to global C structure members.
-
-  subroutine wall_reference_values_init
-
-    use, intrinsic :: iso_c_binding
-    implicit none
-
-    ! Local variables
-
-    type(c_ptr) :: c_ypluli
-
-    call cs_f_wall_reference_values( c_ypluli)
-
-    call c_f_pointer(c_ypluli , ypluli )
-
-  end subroutine wall_reference_values_init
-
   !=============================================================================
 
 end module cstphy
