@@ -65,6 +65,7 @@ use radiat
 use ihmpre
 use mesh
 use field
+use cs_c_bindings
 
 !===============================================================================
 
@@ -204,8 +205,8 @@ else if (itytur.eq.3) then
   call add_variable_field('r22', 'R22', 1, ir22)
   call add_variable_field('r33', 'R33', 1, ir33)
   call add_variable_field('r12', 'R12', 1, ir12)
-  call add_variable_field('r13', 'R13', 1, ir13)
   call add_variable_field('r23', 'R23', 1, ir23)
+  call add_variable_field('r13', 'R13', 1, ir13)
   call add_variable_field('epsilon', 'Turb Dissipation', 1, iep)
   if (iturb.eq.32) then
     call add_variable_field('alpha', 'Alphap', 1, ial)
@@ -290,7 +291,7 @@ if (nmodpp.eq.0) then
 endif
 
 if (iihmpr.eq.1) then
-  call uiscsc
+  call cs_gui_user_scalar_labels
 endif
 
 call add_user_scalar_fields
