@@ -144,7 +144,6 @@ call physical_constants_init
 call fluid_properties_init
 call space_disc_options_init
 call piso_options_init
-call wall_reference_values_init
 call turb_reference_values_init
 
 !===============================================================================
@@ -458,6 +457,9 @@ iprtot = 0
 
 ibeta  = 0
 
+iforbr = -1
+iyplbr = -1
+
 ! --- Ici tout numvar est initialise.
 
 !===============================================================================
@@ -771,9 +773,9 @@ itytur =-999
 !        IGRHOK = 1
 igrhok = 0
 igrake = 1
-ideuch =-999
+iwallf =-999
+iwalfs = -999
 iwallt = 0
-ilogpo = 1
 iclkep = 0
 ikecou =-999
 irijnu = 0
@@ -977,9 +979,6 @@ yplmxy = 200.d0
 ! --- Methode des vortex
 ivrtex = 0
 
-! --- Calcul des efforts aux parois
-ineedf = 0
-
 ! --- Ici tout optcal.f90 est initialise
 
 !===============================================================================
