@@ -67,6 +67,7 @@ use cplsat
 use field
 use mesh
 use cavitation
+use cs_cf_bindings
 
 !===============================================================================
 
@@ -109,7 +110,7 @@ double precision, dimension(:), pointer :: cvar_phi, cvar_fb, cvar_omg, cvar_nus
 double precision, dimension(:), pointer :: cvar_r11, cvar_r22, cvar_r33
 double precision, dimension(:), pointer :: cvar_r12, cvar_r13, cvar_r23
 double precision, dimension(:), pointer :: viscl, visct, cpro_cp, cpro_prtot
-double precision, dimension(:), pointer :: cpro_viscls, cproa_viscls
+double precision, dimension(:), pointer :: cpro_viscls, cproa_viscls, cvar_tempk
 
 !===============================================================================
 
@@ -233,16 +234,6 @@ if(iviext.gt.0) then
     propce(iel,iivisa) = viscl(iel)
   enddo
 endif
-!     Viscosite turbulente aux cellules (et au pdt precedent si ordre2)
-do iel = 1, ncel
-  visct(iel) = 0.d0
-enddo
-if(iviext.gt.0) then
-  iivisa = ipproc(ivista)
-  do iel = 1, ncel
-    propce(iel,iivisa) = visct(iel)
-  enddo
-endif
 
 !     Chaleur massique aux cellules (et au pdt precedent si ordre2)
 if(icp.gt.0) then
@@ -268,6 +259,23 @@ if (ippmod(icompf).lt.0) then
   enddo
 endif
 
+! Default initialisations for the compressible model
+if (ippmod(icompf).ge.0) then
+  ! In compressible, for now, the temperature is not solved but is a field of
+  ! type variable anyway. The reference value has to be taken into account.
+  call field_get_val_s(ivarfl(isca(itempk)), cvar_tempk)
+  do iel = 1, ncel
+    cvar_tempk(iel) = t0
+  enddo
+
+  ! Default isochoric specific heat (cv0),
+  ! total energy and density
+  call cs_cf_thermo_default_init(isuite)
+
+  ! Default diffusivity for total energy
+  visls0(ienerg) = visls0(itempk)/cv0
+endif
+
 ! Diffusivite des scalaires
 do iscal = 1, nscal
   call field_get_key_int (ivarfl(isca(iscal)), kivisl, ifcvsl)
@@ -287,27 +295,6 @@ do iscal = 1, nscal
   endif
 enddo
 
-if (iscalt.gt.0.and.irovar.eq.1) then
-  if (iturt(iscalt).gt.0) then
-    do iel = 1, ncelet
-      propce(iel,ipproc(ibeta)) = 0.d0
-    enddo
-  endif
-endif
-
-! Initialisation of source terms for weakly compressible algorithm
-if (idilat.ge.4) then
-  do iel = 1, ncel
-    propce(iel,ipproc(iustdy(itsrho))) = 0.d0
-  enddo
-  do iscal = 1, nscal
-    do iel = 1, ncel
-      propce(iel,ipproc(iustdy(iscal))) = 0.d0
-    enddo
-  enddo
-endif
-
-
 !     Viscosite de maillage en ALE
 if (iale.eq.1) then
   nn = 1
@@ -325,6 +312,8 @@ if (iporos.ge.1) then
   call field_get_val_s(ipori, porosi)
   do iel = 1, ncelet
     porosi(iel) = 1.d0
+    ! No solid cells
+    isolid_0(iel) = 0
   enddo
 
   ! Tensorial porosity
@@ -339,6 +328,9 @@ if (iporos.ge.1) then
       porosf(6, iel) = 0.d0
     enddo
   endif
+
+else
+  isolid_0(1) = 0
 endif
 
 !===============================================================================
@@ -428,8 +420,8 @@ elseif(itytur.eq.3) then
   call field_get_val_s(ivarfl(ir22), cvar_r22)
   call field_get_val_s(ivarfl(ir33), cvar_r33)
   call field_get_val_s(ivarfl(ir12), cvar_r12)
-  call field_get_val_s(ivarfl(ir13), cvar_r13)
   call field_get_val_s(ivarfl(ir23), cvar_r23)
+  call field_get_val_s(ivarfl(ir13), cvar_r13)
 
   if (uref.ge.0.d0) then
 
@@ -613,16 +605,6 @@ do ii = 1, nfld
 
 enddo
 
-!===============================================================================
-! 8.  INITIALISATION CONSTANTE DE SMAGORINSKY EN MODELE DYNAMIQUE
-!===============================================================================
-
-if(iturb.eq.41) then
-  do iel = 1, ncel
-    propce(iel,ipproc(ismago)) = 0.d0
-  enddo
-endif
-
 !===============================================================================
 ! 9.  INITIALISATION DU NUMERO DE LA FACE DE PAROI 5 LA PLUS PROCHE
 !===============================================================================
@@ -630,7 +612,7 @@ endif
 !     Si IFAPAT existe,
 !     on suppose qu'il faut le (re)calculer : on init le tab a -1.
 
-if(abs(icdpar).eq.2) then
+if (ineedy.gt.0 .and. abs(icdpar).eq.2) then
   do iel = 1, ncel
     ifapat(iel) = -1
   enddo
