@@ -63,6 +63,7 @@ use mesh
 use field
 use cfpoin, only:ithvar
 use cs_c_bindings
+use cs_cf_bindings
 
 !===============================================================================
 
@@ -80,11 +81,12 @@ character(len=80) :: chaine
 integer          ivar  , iscal
 integer          iel
 integer          iclip , iok   , ii
-integer          imodif, ifcven, ifclam
+integer          ifcven, ifclam
 integer          kscmin, kscmax, keyvar, n_fields
 integer          f_id, f_id_prv, c_id, f_dim
 integer          iflid, iflidp
 integer          idimf
+integer          ivoid
 
 logical          interleaved
 
@@ -98,7 +100,7 @@ double precision xalmin, xalmax
 double precision scmaxp, scminp
 
 double precision rvoid(1)
-double precision, allocatable, dimension(:) :: w1, w2
+double precision vvoid(3)
 
 double precision, dimension(:), pointer :: field_s_v
 double precision, dimension(:,:), pointer :: field_v_v
@@ -138,48 +140,6 @@ ithvar = 0
 
 iusini = 1
 
-if  (ippmod(icompf).ge.0) then
-
-  call field_get_val_s(ivarfl(isca(itempk)), cvar_tempk)
-
-  do iel = 1, ncel
-    cvar_tempk(iel) = t0
-  enddo
-
-  call cf_thermo_default_init(ncel, ncelet)
-  !==========================
-
-  ! On initialise la diffusivite thermique
-  visls0(ienerg) = visls0(itempk)/cv0
-
-  call field_get_key_int (ivarfl(isca(ienerg)), kivisl, ifcven)
-  if (ifcven.ge.0) then
-
-    call field_get_val_s(ifcven, cpro_venerg)
-
-    call field_get_key_int (ivarfl(isca(ienerg)), kivisl, ifclam)
-    if (ifclam.ge.0) then
-
-      call field_get_val_s(ifclam, cpro_lambda)
-
-      if(icv.gt.0) then
-        do iel = 1, ncel
-          cpro_venerg(iel) = cpro_lambda(iel) / propce(iel,ipproc(icv))
-        enddo
-      else
-        do iel = 1, ncel
-          cpro_venerg(iel) = cpro_lambda(iel) / cv0
-        enddo
-      endif
-    else
-      do iel = 1, ncel
-        cpro_venerg(iel) =  visls0(itempk) / propce(iel,ipproc(icv))
-      enddo
-    endif
-  endif
-
-endif
-
 iflidp = -1
 
 do ivar = 1, nvar
@@ -259,16 +219,9 @@ else
   if (ippmod(icompf).ge.0.and.(    isuite.eq.0                 &
                                .or.isuite.eq.1.and.ileaux.eq.0)) then
 
-    allocate(w1(ncelet), w2(ncelet))
-    imodif = 1
-
-    call cfther                                                                 &
-    !==========
-   ( nvar   ,                                                                   &
-     ithvar , imodif ,                                                          &
-     w1     , w2     , rvoid )
-
-    deallocate(w1, w2)
+    ivoid = -1
+    call cs_cf_thermo(ithvar, ivoid,  rvoid, rvoid, rvoid, vvoid)
+    !================
 
   endif
 
