@@ -321,17 +321,12 @@ do iscal = 1, nscal
   endif
 enddo
 
-!     Ici on interdit que l'utilisateur fixe lui meme THETAV, par securite
-!       mais on pourrait le laisser faire
-!       (enlever le IOK, modifier le message et les tests dans verini)
-
-!     Vitesse pression (la pression est prise sans interp)
+! Velocity and Pressure (thetav for the pressure is taken without worring)
 if (abs(thetav(iu)+999.d0).gt.epzero.or.                 &
-     abs(thetav(iv)+999.d0).gt.epzero.or.                 &
-     abs(thetav(iw)+999.d0).gt.epzero.or.                 &
-     abs(thetav(ipr)+999.d0).gt.epzero) then
-  write(nfecra,1031) 'VITESSE-PRESSION ','THETAV'
-  iok = iok + 1
+    abs(thetav(iv)+999.d0).gt.epzero.or.                 &
+    abs(thetav(iw)+999.d0).gt.epzero.or.                 &
+    abs(thetav(ipr)+999.d0).gt.epzero) then
+  write(nfecra,1131) 'VITESSE-PRESSION ','THETAV'
 elseif (ischtp.eq.1) then
   thetav(iu) = 1.d0
   thetav(iv) = 1.d0
@@ -495,12 +490,11 @@ elseif (iturb.eq.70) then
   endif
 endif
 
-!     Scalaires
+! Scalares
 do iscal = 1, nscal
   ivar  = isca(iscal)
   if (abs(thetav(ivar)+999.d0).gt.epzero) then
     write(nfecra,1041) 'SCALAIRE',ISCAL,'THETAV'
-    iok = iok + 1
   elseif (ischtp.eq.1) then
     thetav(ivar) = 1.d0
   elseif (ischtp.eq.2) then
@@ -508,7 +502,7 @@ do iscal = 1, nscal
   endif
 enddo
 
-!     Vitesse de maillage en ALE
+! Mesh velocity for ALE
 if (iale.eq.1) then
   if (abs(thetav(iuma)+999.d0).gt.epzero.or.                       &
       abs(thetav(ivma)+999.d0).gt.epzero.or.                       &
@@ -722,26 +716,41 @@ elseif (iturb.eq.70) then
   cdtvar(inusa)= cdtvar(inusa)
 endif
 
-! ---> IDEUCH, YPLULI
-!      En laminaire, longueur de melange, Spalar-Allmaras et LES,
-!      une echelle de vitesse.
-!      Sinon, 2 echelles, sauf si l'utilisateur choisit 1 echelle.
-!      On a initialise IDEUCH a -999 pour voir si l'utilisateur essaye
-!        de choisir deux echelles quand ce n'est pas possible et le
-!        prevenir dans la section verification.
+! ---> IWALLF
+! For laminar cases or when using low Reynolds model: no wall function.
+! When using mixing length, Spalart-Allmaras or LES: one scale log law.
+! In all other cases: 2 scales log law.
+! Here iwallf is set automatically only if it wasn't set in the gui or
+! in a user subroutine.
 
-if (ideuch.eq.-999) then
-  if (iturb.eq. 0.or.                                     &
-      iturb.eq.10.or.                                     &
-      itytur.eq.4.or.itytur.eq.5.or.iturb.eq.32.or.       &
-      iturb.eq.70) then
-    ideuch = 0
+if (iwallf.eq.-999) then
+  if (    iturb.eq.10.or.iturb.eq.70 &
+      .or.itytur.eq.4) then
+    iwallf = 2
+  elseif (    iturb.eq. 0.or.iturb.eq.32 &
+          .or.itytur.eq.5) then
+    iwallf = 0
   else
-    ideuch = 1
+    iwallf = 3
   endif
 endif
 
-! Pour YPLULI, 1/XKAPPA est la valeur qui assure la continuite de la derivee
+! ---> IWALFS
+! If the wall function for the velocity is the two scales wall function using
+! Van Driest mixing length (iwallf=5), then the corresponding wall function for
+! scalar should be used (iwalfs=1).
+! Here iwalfs is set automatically only if it wasn't set in a user subroutine.
+
+if (iwalfs.eq.-999) then
+  if (iwallf.eq.5) then
+    iwalfs = 1
+  else
+    iwalfs = 0
+  endif
+endif
+
+! ---> YPLULI
+! 1/XKAPPA est la valeur qui assure la continuite de la derivee
 ! entre la zone lineaire et la zone logarithmique.
 
 ! Dans le cas des lois de paroi invariantes, on utilise la valeur de
@@ -753,7 +762,7 @@ endif
 ! Idem en Spalart-Allmaras.
 
 if (ypluli.lt.-grand) then
-  if (ideuch.eq.2 .or. itytur.eq.4 .or. iturb.eq.70) then
+  if (iwallf.eq.4 .or. itytur.eq.4 .or. iturb.eq.70) then
     ypluli = 10.88d0
   else
     ypluli = 1.d0/xkappa
@@ -970,29 +979,6 @@ if (idtvar.lt.0) then
   arak = arak/max(relaxv(iu),epzero)
 endif
 
-! ---> INEEDF
-!     Si on a demande un posttraitement des efforts aux bords, on
-!     les calcule !
-if (ipstdv(ipstfo).ne.0) then
-  ineedf = 1
-endif
-!     Si on est en ALE, par defaut on calcule les efforts aux bords
-!     (un test eventuel sur la presence de structures viendrait trop
-!     tard)
-if (iale.eq.1) ineedf = 1
-
-! If no thermal variable is present, do not try to
-! postprocess boundary temperature or Nusselt
-if (iscalt.le.0) then
-  ipstdv(ipsttb) = 0
-  ipstdv(ipstnu) = 0
-endif
-
-! If condensation, yplus is needed
-if (icond.ge.0) then
-  ipstdv(ipstyp) = 1
-endif
-
 !===============================================================================
 ! 4. TABLEAUX DE cstphy
 !===============================================================================
@@ -1274,6 +1260,17 @@ endif
 '@  Verifier cs_user_parameters.f90,'                           /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /)
+ 1131 format( &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ ATTENTION : MODIFICATION AVANCEE POUR',                   /,&
+'@    =========,'                                               /,&
+'@    ',a17,' DE LA VARIABLE'                                   /,&
+'@    ',a6,'.'                                                  /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
  1032 format(                                                     &
 '@',                                                            /,&
@@ -1295,15 +1292,10 @@ endif
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /,&
-'@ @@ ATTENTION : ARRET A L''ENTREE DES DONNEES',               /,&
+'@ @@ ATTENTION : MODIFICATION AVANCEE DE ',                    /,&
 '@    =========,'                                               /,&
 '@    ',a8,' ',i10,                                             /,&
-'@    ',a6,' SERA INITIALISE AUTOMATIQUEMENT.,'                 /,&
-'@    NE PAS LE MODIFIER.,'                                     /,&
-'@',                                                            /,&
-'@  Le calcul ne sera pas execute.',                            /,&
-'@',                                                            /,&
-'@  Verifier cs_user_parameters.f90,'                           /,&
+'@    ',a6,'.'                                                  /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
@@ -1480,6 +1472,18 @@ endif
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
+ 1131 format( &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ WARNING: ADVANCED MODIFICATION FOR',                      /,&
+'@    ========,'                                                /,&
+'@    ',a17,' OF THE VARIABLE'                                  /,&
+'@    ',a6,'.'                                                  /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /)
+
  1032 format(                                                     &
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
@@ -1500,15 +1504,10 @@ endif
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /,&
-'@ @@ WARNING: ABORT IN THE DATA SPECIFICATION',                /,&
+'@ @@ WARNING: ADVANCED MODIFICATION OF',                       /,&
 '@    ========',                                                /,&
 '@    ',a8,' ',i10,                                             /,&
-'@    ',a6,' WILL BE INITIALIZED AUTOMATICALLY',                /,&
-'@    DO NOT MODIFY IT.,'                                       /,&
-'@',                                                            /,&
-'@  The calculation will not be run.',                          /,&
-'@',                                                            /,&
-'@  Check cs_user_parameters.f90',                              /,&
+'@    ',a6,'.',                                                 /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
