@@ -91,6 +91,7 @@ use turbomachinery
 use ptrglo
 use field
 use cavitation
+use cs_c_bindings
 
 !===============================================================================
 
@@ -123,13 +124,12 @@ integer          ndircp, icpt
 integer          numcpl
 integer          iflvoi, iflvob
 double precision rnorm , rnormt, rnorma, rnormi, vitnor
-double precision dtsrom, unsrom, surf  , rhom, rovolsdt
+double precision dtsrom, unsrom, rhom, rovolsdt
 double precision epsrgp, climgp, extrap, xyzmax(3)
 double precision thetap, xdu, xdv, xdw
 double precision xxp0 , xyp0 , xzp0
 double precision rhofac, dtfac, ddepx , ddepy, ddepz
 double precision xnrdis, xnrtmp
-double precision vitbox, vitboy, vitboz
 double precision t1, t2, t3, t4
 double precision visclc, visctc
 double precision distbf, srfbnf, hint
@@ -143,7 +143,6 @@ double precision, allocatable, dimension(:), target :: wvisbi
 double precision, allocatable, dimension(:) :: dpvar
 double precision, allocatable, dimension(:) :: w1
 double precision, allocatable, dimension(:) :: w7, w8, w9
-double precision, allocatable, dimension(:) :: w10
 double precision, allocatable, dimension(:) :: esflum, esflub
 double precision, allocatable, dimension(:) :: intflx, bouflx
 double precision, allocatable, dimension(:) :: secvif, secvib
@@ -249,7 +248,7 @@ allocate(coefa_dp(ndimfb), coefb_dp(ndimfb))
 
 allocate(dfrcxt(3,ncelet))
 if (iphydr.eq.2) then
-  allocate(grdphd(ncelet,ndim))
+  allocate(grdphd(ndim, ncelet))
 else
   grdphd => rvoid2
 endif
@@ -299,7 +298,6 @@ endif
 ! Allocate work arrays
 allocate(w1(ncelet))
 allocate(w7(ncelet), w8(ncelet), w9(ncelet))
-if (irnpnw.eq.1) allocate(w10(ncelet))
 
 if (iwarni(iu).ge.1) then
   write(nfecra,1000)
@@ -332,12 +330,11 @@ if (nterup.gt.1) then
       xnrtmp = xnrtmp +(vela(1,iel)**2        &
                       + vela(2,iel)**2        &
                       + vela(3,iel)**2)       &
-                      * volume(iel)
+                      * cell_f_vol(iel)
     enddo
     xnrmu0 = xnrtmp
     if (irangp.ge.0) then
       call parsom (xnrmu0)
-      !==========
     endif
     ! En cas de couplage entre deux instances de Code_Saturne, on calcule
     ! la norme totale de la vitesse
@@ -345,7 +342,6 @@ if (nterup.gt.1) then
     ! (il faudrait quand meme verifier les options numeriques, ...)
     do numcpl = 1, nbrcpl
       call tbrcpl ( numcpl, 1, 1, xnrmu0, xnrdis )
-      !==========
       xnrmu0 = xnrmu0 + xnrdis
     enddo
     xnrmu0 = sqrt(xnrmu0)
@@ -356,9 +352,7 @@ if (nterup.gt.1) then
   if (iterns.gt.1) then
     if (irangp.ge.0.or.iperio.eq.1) then
       call synvin(uvwk(1,1))
-      !==========
       call synsca(cvara_pr)
-      !==========
     endif
   endif
 
@@ -382,7 +376,6 @@ if ((idilat.eq.2.or.idilat.eq.3).and. &
     (ntcabs.gt.1.or.isuite.gt.0)) then
 
   call predfl(nvar, ncetsm, icetsm, dt, smacel)
-  !==========
 
 endif
 
@@ -393,7 +386,6 @@ endif
 if (iphydr.eq.2) then
 
   call prehyd(prhyd, grdphd)
-  !==========
 
 endif
 
@@ -408,7 +400,6 @@ if ( ippmod(icompf).ge.0 ) then
   endif
 
   call cfmspr &
-  !==========
   ( nvar   , nscal  , iterns ,                                     &
     ncepdc , ncetsm , icepdc , icetsm , itypsm ,                   &
     dt     , propce , vela   ,                                     &
@@ -425,7 +416,6 @@ if (icavit.ge.0) then
   call field_get_val_s(iprpfl(iprtot), cpro_prtot)
 
   call cavitation_compute_source_term (cpro_prtot, cvara_voidf)
-  !==================================
 
 endif
 
@@ -454,12 +444,11 @@ call field_get_coefaf_v(ivarfl(iu), cofafu)
 call field_get_coefbf_v(ivarfl(iu), cofbfu)
 
 call predvv &
-!==========
 ( iappel ,                                                       &
   nvar   , nscal  , iterns ,                                     &
   ncepdc , ncetsm , nfbpcd , ncmast ,                            &
   icepdc , icetsm , ifbpcd , ltmast ,                            &
-  itypsm , itypcd ,                                              &
+  itypsm ,                                                       &
   dt     , vel    , vela   ,                                     &
   propce ,                                                       &
   imasfl , bmasfl ,                                              &
@@ -467,7 +456,7 @@ call predvv &
   ckupdc , smacel , spcond , svcond , frcxt  , grdphd ,          &
   trava  , ximpa  , uvwk   , dfrcxt , dttens ,  trav  ,          &
   viscf  , viscb  , viscfi , viscbi , secvif , secvib ,          &
-  w1     , w7     , w8     , w9     , w10    )
+  w1     , w7     , w8     , w9     )
 
 ! --- Sortie si pas de pression continuite
 !       on met a jour les flux de masse, et on sort
@@ -486,7 +475,6 @@ if (iprco.le.0) then
   climgp = climgr(iu)
 
   call inimav                                                     &
-  !==========
  ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
    iwarnp ,                                                       &
@@ -521,7 +509,6 @@ if (iprco.le.0) then
     call field_get_coefb_v(ivarfl(iuma), clbale)
 
     call inimav &
-    !==========
   ( ivarfl(iuma)    , itypfl ,                                     &
     iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
     iwarnp ,                                                       &
@@ -577,7 +564,7 @@ if (iprco.le.0) then
   ! si le maillage est mobile (solide rigide)
   ! En turbomachine, on connait exactement la vitesse de maillage a ajouter
   if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
-    !$omp parallel do private(iel1, iel2, dtfac, rhofac, vitbox, vitboy, vitboz)
+    !$omp parallel do private(iel1, iel2, dtfac, rhofac )
     do ifac = 1, nfac
       iel1 = ifacel(1,ifac)
       iel2 = ifacel(2,ifac)
@@ -593,7 +580,7 @@ if (iprco.le.0) then
                         + surfac(3,ifac)*(vr1(3) + vr2(3)) )
       endif
     enddo
-    !$omp parallel do private(iel, dtfac, rhofac, vitbox, vitboy, vitboz) &
+    !$omp parallel do private(iel, dtfac, rhofac) &
     !$omp          if(nfabor > thr_n_min)
     do ifac = 1, nfabor
       iel = ifabor(ifac)
@@ -626,10 +613,8 @@ if (iturbo.eq.2 .and. iterns.eq.1) then
   ! Update mesh
 
   call turbomachinery_update_mesh (ttcmob, rs_ell(1))
-  !==============================
 
   call dmtmps(t1)
-  !==========
 
   do ifac = 1, nfabor
     isympa(ifac) = 1
@@ -684,30 +669,22 @@ if (iturbo.eq.2 .and. iterns.eq.1) then
 
     deallocate(w1, w7, w8, w9)
     allocate(w1(ncelet), w7(ncelet), w8(ncelet), w9(ncelet))
-    if (allocated(w10)) then
-      deallocate(w10)
-      allocate(w10(ncelet))
-    endif
 
     ! Resize auxiliary arrays (pointe module)
 
     call resize_aux_arrays
-    !=====================
 
     ! Resize main real array
 
     call resize_main_real_array ( dt , propce )
-    !==========================
 
     ! Update turbomachinery module
 
     call turbomachinery_update
-    !=========================
 
     ! Update field mappings ("owner" fields handled by turbomachinery_update)
 
     call fldtri(nproce, dt, propce)
-    !==========
 
     ! Resize other arrays related to the velocity-pressure resolution
 
@@ -723,15 +700,18 @@ if (iturbo.eq.2 .and. iterns.eq.1) then
       call resize_vec_real_array(frcxt)
     elseif (iphydr.eq.2) then
       call resize_sca_real_array(prhyd)
-      call resize_vec_real_array_ni(grdphd)
+      call resize_vec_real_array(grdphd)
     endif
 
     if (nterup.gt.1) then
-      call resize_vec_real_array(trava)
       call resize_vec_real_array(uvwk)
       call resize_tens_real_array(ximpa)
     endif
 
+    if (nterup.gt.1.or.isno2t.gt.0) then
+      call resize_vec_real_array(trava)
+    endif
+
     ! Update local pointers on "cells" fields
 
     call field_get_val_s(icrom, crom)
@@ -801,7 +781,6 @@ if (iturbo.eq.2 .and. iterns.eq.1) then
   enddo
 
   call dmtmps(t2)
-  !==========
 
   rs_ell(2) = t2-t1
 
@@ -821,7 +800,6 @@ allocate(dpvar(ncelet))
 if (ippmod(icompf).lt.0) then
 
   call resopv &
-  !==========
 ( nvar   , ncetsm , nfbpcd , ncmast ,                            &
   icetsm , ifbpcd , ltmast , isostd ,                            &
   dt     , vel    ,                                              &
@@ -889,7 +867,6 @@ if (ippmod(icompf).lt.0) then
 
     if (irangp.ge.0.or.iperio.eq.1) then
       call synsca(dpvar)
-      !==========
     endif
 
     iccocg = 1
@@ -903,13 +880,12 @@ if (ippmod(icompf).lt.0) then
     extrap = extrag(ipr)
 
     !Allocation
-    allocate(gradp(ncelet,3))
+    allocate(gradp(3, ncelet))
 
     if (icavit.lt.0) then
-      call grdpot &
-      !==========
-      ( ipr    , imrgra , inc    , iccocg , nswrgp , imligp , iphydr , &
-        iwarnp , epsrgp , climgp , extrap ,                            &
+      call gradient_potential_s &
+       (ivarfl(ipr)     , imrgra , inc    , iccocg , nswrgp , imligp , &
+        iphydr , iwarnp , epsrgp , climgp , extrap ,                   &
         dfrcxt ,                                                       &
         dpvar  , coefa_dp        , coefb_dp        ,                   &
         gradp  )
@@ -919,9 +895,8 @@ if (ippmod(icompf).lt.0) then
         xinvro(iel) = 1.d0/crom(iel)
       enddo
 
-      call grdpre &
-      !==========
-      ( ipr    , imrgra , inc    , iccocg , nswrgp , imligp ,          &
+      call gradient_weighted_s &
+      ( ivarfl(ipr)     , imrgra , inc    , iccocg , nswrgp , imligp , &
         iwarnp , epsrgp , climgp , extrap ,                            &
         dpvar  , xinvro , coefa_dp , coefb_dp ,                        &
         gradp  )
@@ -933,7 +908,7 @@ if (ippmod(icompf).lt.0) then
     !$omp parallel do private(isou)
     do iel = 1, ncelet
       do isou = 1, 3
-        trav(isou,iel) = gradp(iel,isou)
+        trav(isou,iel) = gradp(isou, iel)
       enddo
     enddo
 
@@ -965,24 +940,24 @@ if (ippmod(icompf).lt.0) then
         do iel = 1, ncel
           unsrom = thetap/crom(iel)
 
-            vel(1, iel) = vel(1, iel)                                             &
-                 + unsrom*(                                                &
-                   dttens(1,iel)*(dfrcxt(1, iel)-trav(1,iel))     &
-                 + dttens(4,iel)*(dfrcxt(2, iel)-trav(2,iel))     &
-                 + dttens(6,iel)*(dfrcxt(3, iel)-trav(3,iel))     &
-                 )
-            vel(2, iel) = vel(2, iel)                                             &
-                 + unsrom*(                                                &
-                   dttens(4,iel)*(dfrcxt(1, iel)-trav(1,iel))     &
-                 + dttens(2,iel)*(dfrcxt(2, iel)-trav(2,iel))     &
-                 + dttens(5,iel)*(dfrcxt(3, iel)-trav(3,iel))     &
-                 )
-            vel(3, iel) = vel(3, iel)                                             &
-                 + unsrom*(                                                &
-                   dttens(6,iel)*(dfrcxt(1 ,iel)-trav(1,iel))     &
-                 + dttens(5,iel)*(dfrcxt(2 ,iel)-trav(2,iel))     &
-                 + dttens(3,iel)*(dfrcxt(3 ,iel)-trav(3,iel))     &
-                 )
+          vel(1, iel) = vel(1, iel)                                             &
+               + unsrom*(                                                &
+                 dttens(1,iel)*(dfrcxt(1, iel)-trav(1,iel))     &
+               + dttens(4,iel)*(dfrcxt(2, iel)-trav(2,iel))     &
+               + dttens(6,iel)*(dfrcxt(3, iel)-trav(3,iel))     &
+               )
+          vel(2, iel) = vel(2, iel)                                             &
+               + unsrom*(                                                &
+                 dttens(4,iel)*(dfrcxt(1, iel)-trav(1,iel))     &
+               + dttens(2,iel)*(dfrcxt(2, iel)-trav(2,iel))     &
+               + dttens(5,iel)*(dfrcxt(3, iel)-trav(3,iel))     &
+               )
+          vel(3, iel) = vel(3, iel)                                             &
+               + unsrom*(                                                &
+                 dttens(6,iel)*(dfrcxt(1 ,iel)-trav(1,iel))     &
+               + dttens(5,iel)*(dfrcxt(2 ,iel)-trav(2,iel))     &
+               + dttens(3,iel)*(dfrcxt(3 ,iel)-trav(3,iel))     &
+               )
         enddo
       endif
 
@@ -995,7 +970,6 @@ if (ippmod(icompf).lt.0) then
       enddo
       if (irangp.ge.0.or.iperio.eq.1) then
         call synvin(frcxt)
-        !==========
       endif
       ! Update of the Dirichlet boundary conditions on the
       ! pressure for the outlet
@@ -1026,9 +1000,9 @@ if (ippmod(icompf).lt.0) then
       ! Tensorial diffusion for the pressure
       else if (idften(ipr).eq.6) then
 
-      !$omp parallel do private(unsrom)
-      do iel = 1, ncel
-        unsrom = thetap/crom(iel)
+        !$omp parallel do private(unsrom)
+        do iel = 1, ncel
+          unsrom = thetap/crom(iel)
 
           vel(1, iel) = vel(1, iel)                              &
                       - unsrom*(                                 &
@@ -1081,7 +1055,6 @@ if (iale.eq.1) then
   call field_get_coefb_v(ivarfl(iuma), clbale)
 
   call inimav &
-  !==========
 ( ivarfl(iuma)    , itypfl ,                                     &
   iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
   iwarnp ,                                                       &
@@ -1140,9 +1113,8 @@ endif
 if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
 
   if (iturbo.eq.1.or.iturbo.eq.2) call dmtmps(t3)
-                                  !==========
 
-  !$omp parallel do private(iel1, iel2, dtfac, rhofac, vitbox, vitboy, vitboz)
+  !$omp parallel do private(iel1, iel2, dtfac, rhofac)
   do ifac = 1, nfac
     iel1 = ifacel(1,ifac)
     iel2 = ifacel(2,ifac)
@@ -1158,8 +1130,7 @@ if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
                         + surfac(3,ifac)*(vr1(3) + vr2(3)) )
     endif
   enddo
-  !$omp parallel do private(iel, dtfac, rhofac, vitbox, vitboy, vitboz) &
-  !$omp          if(nfabor > thr_n_min)
+  !$omp parallel do private(iel, dtfac, rhofac) if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     iel = ifabor(ifac)
     if (irotce(iel).ne.0) then
@@ -1174,7 +1145,6 @@ if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
   enddo
 
   if (iturbo.eq.1.or.iturbo.eq.2) call dmtmps(t4)
-                                  !==========
 
   rs_ell(2) = rs_ell(2) + t4-t3
 
@@ -1190,12 +1160,10 @@ if (icavit.ge.0) then
   ! Void fraction solving
 
   call resvoi(dt)
-  !==========
 
   ! Halo synchronization
 
   call synsca(cvar_voidf)
-  !==========
 
   ! Get the void fraction boundary conditions
 
@@ -1212,7 +1180,6 @@ if (icavit.ge.0) then
   ! Update mixture density/viscosity and mass flux
 
   call cavitation_update_phys_prop &
-  !===============================
  ( cvar_voidf, coavoi, cobvoi, ivoifl, bvoifl, &
    crom, brom, propce(:,ipproc(iviscl)), imasfl, bmasfl )
 
@@ -1223,7 +1190,6 @@ if (icavit.ge.0) then
     call field_get_val_prev_s(icrom, croma)
 
     call cavitation_print_mass_budget &
-    !================================
    ( crom, croma, dt, imasfl, bmasfl )
 
   endif
@@ -1253,7 +1219,6 @@ if (iestim(iescor).ge.0.or.iestim(iestot).ge.0) then
 
   if (irangp.ge.0.or.iperio.eq.1) then
     call synvin(vel)
-    !==========
   endif
 
   !  -- Pression
@@ -1262,7 +1227,6 @@ if (iestim(iescor).ge.0.or.iestim(iestot).ge.0) then
 
     if (irangp.ge.0.or.iperio.eq.1) then
       call synsca(cvar_pr)
-      !==========
     endif
 
   endif
@@ -1281,7 +1245,6 @@ if (iestim(iescor).ge.0.or.iestim(iestot).ge.0) then
   climgp = climgr(iu)
 
   call inimav                                                     &
-  !==========
  ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
    iwarnp ,                                                       &
@@ -1305,7 +1268,7 @@ if (iestim(iescor).ge.0.or.iestim(iestot).ge.0) then
       !$omp parallel do private(iel) if(ncetsm > thr_n_min)
       do iitsm = 1, ncetsm
         iel = icetsm(iitsm)
-        w1(iel) = w1(iel)-volume(iel)*smacel(iitsm,ipr)
+        w1(iel) = w1(iel)-cell_f_vol(iel)*smacel(iitsm,ipr)
       enddo
     endif
 
@@ -1330,7 +1293,7 @@ if (iestim(iescor).ge.0.or.iestim(iestot).ge.0) then
 
     !$omp parallel do private(rovolsdt, isou)
     do iel = 1, ncel
-      rovolsdt = crom(iel)*volume(iel)/dt(iel)
+      rovolsdt = crom(iel)*cell_f_vol(iel)/dt(iel)
       do isou = 1, 3
         trav(isou,iel) = rovolsdt * (vela(isou,iel) - vel(isou,iel))
       enddo
@@ -1340,12 +1303,11 @@ if (iestim(iescor).ge.0.or.iestim(iestot).ge.0) then
     !                  AVEC LE FLUX DE MASSE RECALCULE
     iappel = 2
     call predvv &
-    !==========
  ( iappel ,                                                       &
    nvar   , nscal  , iterns ,                                     &
    ncepdc , ncetsm , nfbpcd , ncmast ,                            &
    icepdc , icetsm , ifbpcd , ltmast ,                            &
-   itypsm , itypcd ,                                              &
+   itypsm ,                                                       &
    dt     , vel    , vel    ,                                     &
    propce ,                                                       &
    esflum , esflub ,                                              &
@@ -1353,7 +1315,7 @@ if (iestim(iescor).ge.0.or.iestim(iestot).ge.0) then
    ckupdc , smacel , spcond , svcond , frcxt  , grdphd ,          &
    trava  , ximpa  , uvwk   , dfrcxt , dttens , trav   ,          &
    viscf  , viscb  , viscfi , viscbi , secvif , secvib ,          &
-   w1     , w7     , w8     , w9     , w10    )
+   w1     , w7     , w8     , w9     )
 
   endif
 
@@ -1376,17 +1338,16 @@ if (nterup.gt.1) then
     xdu = vel(1,iel) - uvwk(1,iel)
     xdv = vel(2,iel) - uvwk(2,iel)
     xdw = vel(3,iel) - uvwk(3,iel)
-    xnrtmp = xnrtmp +(xdu**2 + xdv**2 + xdw**2) * volume(iel)
+    xnrtmp = xnrtmp +(xdu**2 + xdv**2 + xdw**2) * cell_f_vol(iel)
   enddo
   xnrmu = xnrtmp
   ! --->    TRAITEMENT DU PARALLELISME
 
   if (irangp.ge.0) call parsom (xnrmu)
-                   !==========
+
   ! -- >    TRAITEMENT DU COUPLAGE ENTRE DEUX INSTANCES DE CODE_SATURNE
   do numcpl = 1, nbrcpl
     call tbrcpl ( numcpl, 1, 1, xnrmu, xnrdis )
-    !==========
     xnrmu = xnrmu + xnrdis
   enddo
   xnrmu = sqrt(xnrmu)
@@ -1408,8 +1369,7 @@ else
 endif
 if (ndircp.le.0) then
   call prmoy0 &
-  !==========
-( ncelet , ncel   , volume , cvar_pr )
+( ncelet , ncel   , cell_f_vol , cvar_pr )
 endif
 
 ! Calcul de la pression totale IPRTOT : (definie comme propriete )
@@ -1442,7 +1402,7 @@ if (iwarni(iu).ge.1) then
     rnorm  = max(rnorm,abs(cvar_pr(iel)))
   enddo
   if (irangp.ge.0) call parmax (rnorm)
-                   !==========
+
   write(nfecra,2100)rnorm
 
   rnorm = -1.d0
@@ -1467,7 +1427,6 @@ if (iwarni(iu).ge.1) then
   if (irangp.ge.0) then
     nbrval = 3
     call parmxl (nbrval, rnorm, xyzmax)
-    !==========
   endif
 
   write(nfecra,2200) rnorm,xyzmax(1),xyzmax(2),xyzmax(3)
@@ -1487,13 +1446,17 @@ if (iwarni(iu).ge.1) then
   do ifac = 1, nfac
     iel1 = ifacel(1,ifac)
     iel2 = ifacel(2,ifac)
-    surf = surfan(ifac)
-    if (iporos.ge.1) then
+    if (iporos.eq.1.or.iporos.eq.2) then
       rhom = (porosi(iel1)*crom(iel1)+porosi(iel2)*crom(iel2))*0.5d0
     else
       rhom = (crom(iel1)+crom(iel2))*0.5d0
     endif
-    rnorm = abs(imasfl(ifac))/(surf*rhom)
+    ! Deal with null fluid section
+    if (suffan(ifac)/surfan(ifac).gt.epzero) then
+      rnorm = abs(imasfl(ifac))/(suffan(ifac)*rhom)
+    else
+      rnorm = 0.d0
+    endif
     rnorma = max(rnorma,rnorm)
     rnormi = min(rnormi,rnorm)
   enddo
@@ -1506,19 +1469,22 @@ if (iwarni(iu).ge.1) then
   rnorma = -grand
   rnormi =  grand
   do ifac = 1, nfabor
-    if (iporos.ge.1) then
+    if (iporos.eq.1.or.iporos.eq.2) then
       rnorm = bmasfl(ifac)/(surfbn(ifac)*brom(ifac)*porosi(ifabor(ifac)))
     else
-      rnorm = bmasfl(ifac)/(surfbn(ifac)*brom(ifac))
+      ! Deal with null fluid section
+      if (suffbn(ifac)/surfbn(ifac).gt.epzero) then
+        rnorm = bmasfl(ifac)/(suffbn(ifac)*brom(ifac))
+      else
+        rnorm = 0.d0
+      endif
     endif
     rnorma = max(rnorma,rnorm)
     rnormi = min(rnormi,rnorm)
   enddo
   if (irangp.ge.0) then
     call parmax (rnorma)
-    !==========
     call parmin (rnormi)
-    !==========
   endif
   write(nfecra,2400)rnorma, rnormi
 
@@ -1529,7 +1495,6 @@ if (iwarni(iu).ge.1) then
   enddo
 
   if (irangp.ge.0) call parsom (rnorm)
-                   !==========
 
   write(nfecra,2500)rnorm
 
@@ -1568,7 +1533,6 @@ deallocate(trav)
 deallocate(dfrcxt)
 deallocate(w1)
 deallocate(w7, w8, w9)
-if (allocated(w10)) deallocate(w10)
 if (allocated(wvisfi)) deallocate(wvisfi, wvisbi)
 if (allocated(secvif)) deallocate(secvif, secvib)
 if (iphydr.eq.2) deallocate(grdphd)
