@@ -531,12 +531,12 @@ module optcal
   !> Class of turbulence model (integer value iturb/10)
   integer(c_int), pointer, save :: itytur
 
-  !> Activation of rotation/curvature correction for an eddy viscosity turbulence models
+  !> Activation of rotation/curvature correction for eddy viscosity turbulence models
   !>    - 0: false
   !>    - 1: true
   integer(c_int), pointer, save :: irccor
 
-  !> Type of rotation/curvature correction for an eddy viscosity turbulence models
+  !> Type of rotation/curvature correction for eddy viscosity turbulence models
   !>    - 1 Cazalbou correction (default when irccor=1 and itytur=2 or 5)
   !>    - 2 Spalart-Shur correction (default when irccor=1 and iturb=60 or 70)
   integer(c_int), pointer, save :: itycor
@@ -547,21 +547,25 @@ module optcal
   integer(c_int), pointer, save :: idirsm
 
   !>  Wall functions
-  !>    - 0: one scale of friction velocities
-  !>    - 1: two scale of friction velocities
-  !>    - 2: scalable wall functions
-  integer(c_int), pointer, save :: ideuch
+  !>    - 0: no wall functions
+  !>    - 1: one scale of friction velocities (power law)
+  !>    - 2: one scale of friction velocities (log law)
+  !>    - 3: two scales of friction velocities (log law)
+  !>    - 4: two scales of friction velocities (log law) - scalable wall functions
+  !>    - 5: two scales of friction velocities (mixing
+  !>          length based on V. Driest analysis)
+  integer(c_int), pointer, save :: iwallf
+
+  !>  Wall functions for scalar
+  !>    - 0: three layer wall function of Arpaci and Larsen
+  !>    - 1: Van Driest wall function
+  integer(c_int), pointer, save :: iwalfs
 
   !> exchange coefficient correlation
   !>    - 0: not use by default
   !>    - 1: exchange coefficient computed with a correlation
   integer(c_int), pointer, save :: iwallt
 
-  !> wall function with
-  !>    - 0 a power lay (deprecated)
-  !>    - 1 a log lay
-  integer(c_int), pointer, save :: ilogpo
-
   !> clipping of k and epsilon
   !>    - 0 absolute value clipping
   !>    - 1 coupled clipping based on physical relationships
@@ -757,6 +761,12 @@ module optcal
   !>    - 0: false (default)
   integer(c_int), pointer, save :: icalhy
 
+  !> use interpolated face diffusion coefficient instead of cell diffusion coefficient
+  !> for the mass flux reconstruction for the non-orthogonalities
+  !>    - 1: true
+  !>    - 0: false (default)
+  integer(c_int), pointer, save :: irecmf
+
   !> choice the way to compute the exchange coefficient of the
   !> condensation source term used by the copain model
   !>    - 1: the turbulent exchange coefficient of the flow
@@ -931,13 +941,6 @@ module optcal
   !          yplus moins precis est suffisant
   double precision, save :: yplmxy
 
-  !TODO move it elsewhere?
-  ! Parametres numeriques pour le calcul des efforts aux bords
-
-  !> ineedf : = 1 on calcule les efforts aux parois
-  !>          = 0 on ne calcule pas les efforts aux parois
-  integer, save :: ineedf
-
   !> \}
 
   !----------------------------------------------------------------------------
@@ -1081,11 +1084,12 @@ module optcal
     ! Interface to C function retrieving pointers to members of the
     ! global wall functions structure
 
-    subroutine cs_f_wall_functions_get_pointers(ideuch, iwallt, ilogpo) &
+    subroutine cs_f_wall_functions_get_pointers(iwallf, iwalfs, iwallt, &
+                                                ypluli)                  &
       bind(C, name='cs_f_wall_functions_get_pointers')
       use, intrinsic :: iso_c_binding
       implicit none
-      type(c_ptr), intent(out) :: ideuch, iwallt, ilogpo
+      type(c_ptr), intent(out) :: iwallf, iwalfs, iwallt, ypluli
     end subroutine cs_f_wall_functions_get_pointers
 
     ! Interface to C function retrieving pointers to members of the
@@ -1121,13 +1125,13 @@ module optcal
                                                 rnormp, arak  ,ipucou, iccvfg, &
                                                 idilat, epsdp ,itbrrb, iphydr, &
                                                 igprij, igpust,                &
-                                                iifren, icalhy)        &
+                                                iifren, icalhy, irecmf)        &
       bind(C, name='cs_f_stokes_options_get_pointers')
       use, intrinsic :: iso_c_binding
       implicit none
       type(c_ptr), intent(out) :: ivisse, irevmc, iprco, irnpnw, rnormp, arak
       type(c_ptr), intent(out) :: ipucou, iccvfg, idilat, epsdp, itbrrb, iphydr
-      type(c_ptr), intent(out) :: igprij, igpust, iifren, icalhy
+      type(c_ptr), intent(out) :: igprij, igpust, iifren, icalhy, irecmf
     end subroutine cs_f_stokes_options_get_pointers
 
     ! Interface to C function retrieving pointers to members of the
@@ -1308,17 +1312,20 @@ contains
   subroutine wall_functions_init
 
     use, intrinsic :: iso_c_binding
+    use cstphy, only: ypluli
     implicit none
 
     ! Local variables
 
-    type(c_ptr) :: c_ideuch, c_iwallt, c_ilogpo
+    type(c_ptr) :: c_iwallf, c_iwalfs, c_iwallt, c_ypluli
 
-    call cs_f_wall_functions_get_pointers( c_ideuch, c_iwallt, c_ilogpo)
+    call cs_f_wall_functions_get_pointers(c_iwallf, c_iwalfs, c_iwallt, &
+                                          c_ypluli)
 
-    call c_f_pointer(c_ideuch, ideuch)
+    call c_f_pointer(c_iwallf, iwallf)
+    call c_f_pointer(c_iwalfs, iwalfs)
     call c_f_pointer(c_iwallt, iwallt)
-    call c_f_pointer(c_ilogpo, ilogpo)
+    call c_f_pointer(c_ypluli, ypluli)
 
   end subroutine wall_functions_init
 
@@ -1390,13 +1397,13 @@ contains
 
     type(c_ptr) :: c_ivisse, c_irevmc, c_iprco, c_irnpnw, c_rnormp, c_arak
     type(c_ptr) :: c_ipucou, c_iccvfg, c_idilat, c_epsdp, c_itbrrb, c_iphydr
-    type(c_ptr) :: c_igprij, c_igpust, c_iifren, c_icalhy
+    type(c_ptr) :: c_igprij, c_igpust, c_iifren, c_icalhy, c_irecmf
 
 
     call cs_f_stokes_options_get_pointers(c_ivisse, c_irevmc, c_iprco ,  &
                                           c_irnpnw, c_rnormp, c_arak  , c_ipucou, c_iccvfg, &
                                           c_idilat, c_epsdp , c_itbrrb, c_iphydr, c_igprij, &
-                                          c_igpust, c_iifren, c_icalhy)
+                                          c_igpust, c_iifren, c_icalhy, c_irecmf)
 
     call c_f_pointer(c_ivisse, ivisse)
     call c_f_pointer(c_irevmc, irevmc)
@@ -1414,6 +1421,7 @@ contains
     call c_f_pointer(c_igpust, igpust)
     call c_f_pointer(c_iifren, iifren)
     call c_f_pointer(c_icalhy, icalhy)
+    call c_f_pointer(c_irecmf, irecmf)
 
   end subroutine stokes_options_init
 
