@@ -136,6 +136,7 @@ use cavitation
 use cs_f_interfaces
 use cs_c_bindings
 use cs_tagms, only:s_metal
+
 !===============================================================================
 
 implicit none
@@ -170,7 +171,7 @@ double precision coefb_dp(ndimfb)
 
 character(len=80) :: chaine
 integer          lchain
-integer          iccocg, inc   , iprev, init  , isym  , isqrt
+integer          iccocg, inc   , iprev, init  , isym
 integer          ii, jj, iel   , ifac  , ifac0 , iel0
 integer          nswmpr
 integer          isweep, niterf
@@ -185,7 +186,6 @@ integer          isou  , ibsize, iesize
 integer          imucpp, idftnp, iswdyp
 integer          iescap, ircflp, ischcp, isstpp, ivar
 integer          nswrsp
-integer          insqrt
 integer          imvisp
 integer          iflid, iflwgr, f_dim
 
@@ -231,19 +231,15 @@ double precision, allocatable, dimension(:) :: iflux, bflux
 double precision, allocatable, dimension(:) :: xunsro
 double precision, allocatable, dimension(:), target :: xdtsro
 double precision, allocatable, dimension(:,:), target :: tpusro
-double precision, allocatable, dimension(:), target :: xvolf
 double precision, dimension(:), pointer :: viscap
-double precision, dimension(:), pointer :: volf
-double precision, dimension(:), pointer :: porosi
 double precision, dimension(:,:), pointer :: vitenp
-double precision, allocatable, dimension(:,:) :: gradni
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: brom, crom, croma
 double precision, dimension(:), pointer :: cvar_pr, cvara_pr
 double precision, dimension(:,:), pointer :: cpro_wgrec_v
 double precision, dimension(:), pointer :: cpro_wgrec_s
-
 double precision, allocatable, dimension(:) :: surfbm
+
 !===============================================================================
 
 !===============================================================================
@@ -272,30 +268,6 @@ allocate(coefaf_dp(ndimfb), coefbf_dp(ndimfb))
 viscap => dt(:)
 if (idften(ipr).eq.6)  vitenp => tpucou(:,:)
 
-
-! Compute the Volume of fluid (in case of porosity)
-if (iporos.eq.0)  then
-  volf => volume(:)
-
-! With porosity
-else
-
-  call field_get_val_s(ipori, porosi)
-
-  allocate(xvolf(ncelet))
-
-  do iel = 1, ncel
-    xvolf(iel) = volume(iel) * porosi(iel)
-  enddo
-
-  if (irangp.ge.0.or.iperio.eq.1) then
-    call synsca(xvolf)
-  endif
-
-  volf => xvolf(:)
-
-endif
-
 ! Index of the field
 iflid = ivarfl(ipr)
 call field_get_key_struct_solving_info(iflid, sinfo)
@@ -349,8 +321,6 @@ endif
 ibsize = 1
 iesize = 1
 
-isqrt = 1
-
 ! Initialization dedicated to cavitation module
 if (icavit.ge.0) then
 
@@ -480,7 +450,7 @@ if (irnpnw.ne.1) then
   if (ncesmp.gt.0) then
     do ii = 1, ncesmp
       iel = icetsm(ii)
-      res(iel) = res(iel) - volf(iel)*smacel(ii,ipr)
+      res(iel) = res(iel) - cell_f_vol(iel)*smacel(ii,ipr)
     enddo
   endif
 
@@ -511,7 +481,7 @@ if (irnpnw.ne.1) then
   ! Cavitation source term
   if (icavit.gt.0) then
     do iel = 1, ncel
-      res(iel) = res(iel) -volf(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
+      res(iel) = res(iel) -cell_f_vol(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
     enddo
   endif
 
@@ -525,7 +495,7 @@ if (irnpnw.ne.1) then
 
   endif
 
-  call prodsc(ncel,isqrt,res,res,rnormp)
+  rnormp = sqrt(cs_gdot(ncel,res,res))
 
   if(iwarni(ipr).ge.2) then
     write(nfecra,1300)chaine(1:16) ,rnormp
@@ -833,13 +803,13 @@ enddo
 ! Implicit part of the cavitation source
 if (icavit.gt.0.and.itscvi.eq.1) then
   do iel = 1, ncel
-    rovsdt(iel) = rovsdt(iel) - volf(iel)*dgdpca(iel)*(1.d0/rov - 1.d0/rol)
+    rovsdt(iel) = rovsdt(iel) - cell_f_vol(iel)*dgdpca(iel)*(1.d0/rov - 1.d0/rol)
   enddo
 endif
 ! Strengthen the diagonal for Low Mach Algorithme
 if (idilat.eq.3) then
   do iel = 1, ncel
-    rovsdt(iel) = rovsdt(iel) + epsdp*volf(iel)/dt(iel)
+    rovsdt(iel) = rovsdt(iel) + epsdp*cell_f_vol(iel)/dt(iel)
   enddo
 endif
 
@@ -942,7 +912,6 @@ if (icavit.lt.0) then
                                 frcxt, gradp)
 else
   ! Cavitating flows: continuity of the diffusive flux across internal faces
-  allocate(gradni(ncelet,3))
 
   nswrgp = nswrgr(ipr)
   imligp = imligr(ipr)
@@ -951,18 +920,11 @@ else
   climgp = climgr(ipr)
   extrap = extrag(ipr)
 
-  call grdpre (ipr, imrgra, inc, iccocg, nswrgp, imligp,  &
-               iwarnp, epsrgp, climgp, extrap,            &
-               cvar_pr, xunsro, coefa_p , coefb_p,        &
-               gradni )
+  call gradient_weighted_s(ivarfl(ipr), imrgra, inc, iccocg, nswrgp, imligp,  &
+                           iwarnp, epsrgp, climgp, extrap,                    &
+                           cvar_pr, xunsro, coefa_p , coefb_p,                &
+                           gradp )
 
-  do iel = 1, ncelet
-    do isou = 1, 3
-      gradp(isou,iel) = gradni(iel,isou)
-    enddo
-  enddo
-
-  deallocate(gradni)
 endif
 
 do iel = 1, ncelet
@@ -1125,6 +1087,9 @@ init   = 0
 inc    = 1
 iccocg = 1
 
+!----------------------
+! Rhie and Choow filter
+!----------------------
 if (arak.gt.0.d0) then
 
 ! --- Prise en compte de Arak : la viscosite face est multipliee
@@ -1454,7 +1419,7 @@ endif
 if (ncesmp.gt.0) then
   do ii = 1, ncesmp
     iel = icetsm(ii)
-    divu(iel) = divu(iel) -volf(iel)*smacel(ii,ipr)
+    divu(iel) = divu(iel) -cell_f_vol(iel)*smacel(ii,ipr)
   enddo
 endif
 
@@ -1487,7 +1452,7 @@ endif
 if (idilat.eq.2.or.idilat.eq.3) then
   do iel = 1, ncel
     drom = crom(iel) - croma(iel)
-    divu(iel) = divu(iel) + drom*volf(iel)/dt(iel)
+    divu(iel) = divu(iel) + drom*cell_f_vol(iel)/dt(iel)
   enddo
 endif
 
@@ -1501,7 +1466,7 @@ endif
 ! --- Cavitation source term
 if (icavit.gt.0) then
   do iel = 1, ncel
-    divu(iel) = divu(iel) - volf(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
+    divu(iel) = divu(iel) - cell_f_vol(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
   enddo
 endif
 
@@ -1512,7 +1477,7 @@ enddo
 
 
 ! --- Right hand side residual
-call prodsc(ncel,isqrt,rhs,rhs,residu)
+residu = sqrt(cs_gdot(ncel,rhs,rhs))
 
 sinfo%rnsmbr = residu
 
@@ -1684,25 +1649,23 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
       adxk(iel) = - adxk(iel)
     enddo
 
-    insqrt = 0
-
     ! ||E.dx^(k-1)-E.0||^2
     nadxkm1 = nadxk
 
     ! ||E.dx^k-E.0||^2
-    call prodsc(ncel , insqrt , adxk , adxk , nadxk)
+    nadxk = cs_gdot(ncel, adxk, adxk)
 
     ! < E.dx^k-E.0; r^k >
-    call prodsc(ncel , insqrt , rhs , adxk , paxkrk)
+    paxkrk = cs_gdot(ncel, rhs, adxk)
 
     ! Relaxation with respect to dx^k and dx^(k-1)
     if (iswdyp.ge.2) then
 
       ! < E.dx^(k-1)-E.0; r^k >
-      call prodsc(ncel , insqrt , rhs , adxkm1 , paxm1rk)
+      paxm1rk = cs_gdot(ncel, rhs, adxkm1)
 
       ! < E.dx^(k-1)-E.0; E.dx^k -E.0 >
-      call prodsc(ncel , insqrt , adxk, adxkm1 , paxm1ax)
+      paxm1ax = cs_gdot(ncel, adxk, adxkm1)
 
       if (nadxkm1.gt.1.d-30*rnorm2.and.                    &
          (nadxk*nadxkm1-paxm1ax**2).gt.1.d-30*rnorm2) then
@@ -1818,7 +1781,7 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
   enddo
 
   ! --- Convergence test
-  call prodsc(ncel,isqrt,rhs,rhs,residu)
+  residu = sqrt(cs_gdot(ncel,rhs,rhs))
 
   ! Writing
   sinfo%nbivar = sinfo%nbivar + niterf
@@ -1983,9 +1946,6 @@ call sles_free_native(ivarfl(ipr), '')
 
 if (idilat.eq.5) then
 
-  deallocate(gradp)
-  allocate(gradp(ncelet,3))
-
   ! Allocate temporary arrays
   allocate(ddpvar(ncelet))
   allocate(coefar(3,ndimfb), cofafr(3,ndimfb))
@@ -1994,7 +1954,6 @@ if (idilat.eq.5) then
   ! --- Convective flux: dt/rho grad(rho)
   inc = 1
   iccocg = 1
-  ivar   = 0
   nswrgp = nswrgr(iu)
   imligp = imligr(iu)
   iwarnp = iwarni(ipr)
@@ -2012,10 +1971,8 @@ if (idilat.eq.5) then
     coefb_rho(ifac) = 0.d0
   enddo
 
-  call grdcel &
-  !==========
-  (ivar   , imrgra , inc    , iccocg , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+  call gradient_s                                                 &
+  (f_id0  , imrgra , inc    , iccocg , nswrgp , imligp , iwarnp , &
    epsrgp , climgp , extrap ,                                     &
    crom   ,                                                       &
    coefa_rho       , coefb_rho       ,                            &
@@ -2026,7 +1983,7 @@ if (idilat.eq.5) then
   ! --- dt/rho * grad rho
   do iel = 1, ncel
     do isou = 1, 3
-      trav(isou,iel) = gradp(iel,isou) * dt(iel) / crom(iel)
+      trav(isou,iel) = gradp(isou,iel) * dt(iel) / crom(iel)
     enddo
   enddo
 
@@ -2181,7 +2138,7 @@ if (idilat.eq.5) then
 
   ! --- Initialization of the variable to solve
   do iel = 1, ncel
-    rovsdt(iel) = 340.d0/dt(iel) * volf(iel)
+    rovsdt(iel) = 340.d0/dt(iel) * cell_f_vol(iel)
     dpvar(iel)   = 0.d0
     ddpvar(iel)  = 0.d0
     rhs(iel)    = - rhs(iel)
@@ -2377,7 +2334,6 @@ if (icavit.ge.0.or.idilat.eq.4) then
   if (allocated(xunsro)) deallocate(xunsro)
   if (allocated(tpusro)) deallocate(tpusro)
 endif
-if (allocated(xvolf)) deallocate(xvolf)
 
 !--------
 ! Formats
