@@ -151,7 +151,7 @@ double precision , dimension ( : , : ) , allocatable :: af1    , af2
 double precision , dimension ( : )     , allocatable :: fs3no  , fs4no
 double precision , dimension ( : , : ) , allocatable :: yfs4no
 double precision, allocatable, dimension(:) :: tpdf
-double precision, dimension(:), pointer :: x1
+double precision, dimension(:), pointer :: cpro_x1
 double precision, dimension(:), pointer :: cvar_xchcl, cvar_xckcl, cvar_xnpcl
 double precision, dimension(:), pointer :: cvar_xwtcl
 type(pmapper_double_r1), dimension(:), allocatable :: cvar_f1m, cvar_f2m
@@ -164,7 +164,7 @@ data ipass / 0 /
 !===============================================================================
 
 ! Massic fraction of gas
-call field_get_val_s_by_name("x_c", x1)
+call field_get_val_s_by_name("x_c", cpro_x1)
 
 allocate(intpdf(1:ncel)                                 ,stat=iok1)
 allocate(fmini(1:ncel)      ,fmaxi(1:ncel),ffuel(1:ncel),stat=iok2)
@@ -183,16 +183,16 @@ endif
 if ( ieqnox .eq. 1 ) then
   allocate(fs3no(1:ncel) , fs4no(1:ncel),stat=iok1)
   if ( iok1 > 0 ) then
-    write(nfecra,*) ' Memory allocation error inside : '
-    write(nfecra,*) '     cs_coal_physprop1            '
-    write(nfecra,*) ' for the fs3no and fs4no arrays   '
+    write(nfecra,*) ' Memory allocation error inside: '
+    write(nfecra,*) '     cs_coal_physprop1           '
+    write(nfecra,*) ' for fs3no and fs4no arrays      '
     call csexit(1)
   endif
   allocate(yfs4no(1:ncel,1:ngazg),stat=iok2)
   if ( iok2 > 0 ) then
-    write(nfecra,*) ' Memory allocation error inside : '
-    write(nfecra,*) '     cs_coal_physprop1            '
-    write(nfecra,*) ' for the fs4 concentrations array '
+    write(nfecra,*) ' Memory allocation error inside: '
+    write(nfecra,*) '     cs_coal_physprop1           '
+    write(nfecra,*) ' for fs4 concentrations array    '
     call csexit(1)
   endif
 endif
@@ -230,7 +230,7 @@ ipass = ipass + 1
 !===============================================================================
 
 do iel = 1, ncel
-  !  min and max boundary of the pdf
+  !  min et max boundary of the pdf
   fmini(iel) = 0
   fmaxi(iel) = 1.d0
   ! Sum F1+F2
@@ -274,8 +274,8 @@ do iel = 1, ncel
 
   do icha = 1, ncharb
 
-    f1mc = cvar_f1m(icha)%p(iel) / x1(iel)
-    f2mc = cvar_f2m(icha)%p(iel) / x1(iel)
+    f1mc = cvar_f1m(icha)%p(iel) / cpro_x1(iel)
+    f2mc = cvar_f2m(icha)%p(iel) / cpro_x1(iel)
 
     den1 = 1.d0                                                    &
           / ( a1(icha)*wmole(ichx1c(icha))+b1(icha)*wmole(ico)     &
@@ -421,7 +421,7 @@ do iel = 1, ncel
   ! ---- We do not include the mecanical pressure IPR
   !      but P0
 
-  rom1(iel) = p0 / (wmolme*rr*propce(iel,ipcte1))
+  rom1(iel) = p0 / (wmolme*cs_physical_constants_r*propce(iel,ipcte1))
 enddo
 
 !===============================================================================
@@ -473,21 +473,21 @@ endif
 !===============================================================================
 
 do iel=1,ncel
-  propce(iel,ipproc(ibcarbone )) = x1(iel)                        &
-            *( propce(iel,ipcyf1)*wmolat(iatc)/wmchx1(iel)        &
-              +propce(iel,ipcyf2)*wmolat(iatc)/wmchx2(iel)        &
-              +propce(iel,ipcyf3)*wmolat(iatc)/wmole(ico )        &
-              +propce(iel,ipcyf6)*wmolat(iatc)/wmole(ihcn)        &
+  propce(iel,ipproc(ibcarbone )) = cpro_x1(iel)                        &
+            *( propce(iel,ipcyf1)*wmolat(iatc)/wmchx1(iel)             &
+              +propce(iel,ipcyf2)*wmolat(iatc)/wmchx2(iel)             &
+              +propce(iel,ipcyf3)*wmolat(iatc)/wmole(ico )             &
+              +propce(iel,ipcyf6)*wmolat(iatc)/wmole(ihcn)             &
               +propce(iel,ipcyp1)*wmolat(iatc)/wmole(ico2) )
 
-  propce(iel,ipproc(iboxygen  )) = x1(iel)                        &
-            *( propce(iel,ipcyf3)*     wmolat(iato)/wmole(ico )   &
-              +propce(iel,ipcyox)*2.d0*wmolat(iato)/wmole(io2 )   &
-              +propce(iel,ipcyp1)*2.d0*wmolat(iato)/wmole(ico2)   &
-              +propce(iel,ipcyp2)*     wmolat(iato)/wmole(ih2o)   &
+  propce(iel,ipproc(iboxygen  )) = cpro_x1(iel)                        &
+            *( propce(iel,ipcyf3)*     wmolat(iato)/wmole(ico )        &
+              +propce(iel,ipcyox)*2.d0*wmolat(iato)/wmole(io2 )        &
+              +propce(iel,ipcyp1)*2.d0*wmolat(iato)/wmole(ico2)        &
+              +propce(iel,ipcyp2)*     wmolat(iato)/wmole(ih2o)        &
               +propce(iel,ipcyp3)*2.d0*wmolat(iato)/wmole(iso2) )
 
-  propce(iel,ipproc(ibhydrogen)) = x1(iel)                             &
+  propce(iel,ipproc(ibhydrogen)) = cpro_x1(iel)                        &
             *( propce(iel,ipcyf1)*cx1m(iel)*wmolat(iath)/wmchx1(iel)   &
               +propce(iel,ipcyf2)*cx2m(iel)*wmolat(iath)/wmchx2(iel)   &
               +propce(iel,ipcyf4)*2.d0     *wmolat(iath)/wmole(ih2s)   &
