@@ -102,16 +102,21 @@ struct _cs_mesh_location_t {
 
   char                       *select_str;   /* String */
   cs_mesh_location_select_t  *select_fp;    /* Function pointer */
+  int                         n_sub_ids;    /* Number of mesh location ids
+                                               used to build a new mesh location
+                                            */
+  int                        *sub_ids;      /* List of mesh location ids */
+  bool                        complement;   /* Take the complement ? */
 
-  cs_lnum_t                 n_elts[3];    /* Number of associated elements:
-                                             0: local,
-                                             1: with standard ghost elements,
-                                             2: with extended ghost elements */
-
-  cs_lnum_t                *elt_list;     /* List of associated elements,
-                                             (0 to n-1 numbering) if non
-                                             trivial (i.e. a subset) */
+  cs_lnum_t                   n_elts[3];    /* Number of associated elements:
+                                               0: local,
+                                               1: with standard ghost elements,
+                                               2: with extended ghost elements
+                                            */
 
+  cs_lnum_t                  *elt_list;     /* List of associated elements,
+                                               (0 to n-1 numbering) if non
+                                               trivial (i.e. a subset) */
 };
 
 /*============================================================================
@@ -129,6 +134,8 @@ const char  *cs_mesh_location_type_name[] = {N_("none"),
                                              N_("interior faces"),
                                              N_("boundary faces"),
                                              N_("vertices"),
+                                             N_("faces"),
+                                             N_("edges"),
                                              N_("particles"),
                                              N_("other")};
 
@@ -138,24 +145,25 @@ static int                  _n_mesh_locations_max = 0;
 static int                  _n_mesh_locations = 0;
 static cs_mesh_location_t  *_mesh_location = NULL;
 
+/*! (DOXYGEN_SHOULD_SKIP_THIS) \endcond */
+
 /*============================================================================
  * Private function definitions
  *============================================================================*/
 
 /*----------------------------------------------------------------------------
- * Get a a pointer to a mesh location by its id.
+ * \brief Get a pointer to a mesh location by its id.
  *
- * parameters:
- *   id            <-- id of mesh location
+ * \param[in]  id         id of mesh location
  *
- * returns:
- *   pointer to associated mesh location
- *----------------------------------------------------------------------------*/
+ * \return  a pointer to the associated mesh location
+ */
+/*----------------------------------------------------------------------------*/
 
 static const cs_mesh_location_t *
-_const_mesh_location_by_id(int id)
+_const_mesh_location_by_id(int  id)
 {
-  const cs_mesh_location_t *retval = NULL;
+  const cs_mesh_location_t  *retval = NULL;
 
   if (id < 0 || id > _n_mesh_locations)
     bft_error(__FILE__, __LINE__, 0,
@@ -167,33 +175,76 @@ _const_mesh_location_by_id(int id)
   return retval;
 }
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Find the related location id from the location name
+ *
+ * \param[in]  ref_name    name of the location to find
+ *
+ * \return -1 if not found otherwise the associated id
+ */
+/*----------------------------------------------------------------------------*/
+
+static int
+_find_id_by_name(const char  *ref_name)
+{
+  int  ml_id = -1, reflen = strlen(ref_name);
+
+  for (int i = 0; i < _n_mesh_locations; i++) {
+
+    cs_mesh_location_t  *ml = _mesh_location + i;
+    int len = strlen(ml->name);
+
+    if (reflen == len) {
+      if (strcmp(ref_name, ml->name) == 0) {
+        ml_id = i;
+        break;
+      }
+    }
+
+  } /* Loops on mesh locations */
+
+  return ml_id;
+}
+
 /*----------------------------------------------------------------------------
- * Define a new mesh location.
+ * \brief Define a new mesh location.
  *
  * If a list of associated elements is given (defining a subset of a main
  * location), its ownership is transferred to the mesh location.
  *
- * parameters:
- *   name      name of location to define
- *   type      type of location to define
+ * \param[in]  name      name of location to define
+ * \param[in]  type      type of location to define
  *
- * returns:
- *   id of newly defined created mesh location
- *----------------------------------------------------------------------------*/
+ * \return   id of the newly defined mesh location
+ */
+/*----------------------------------------------------------------------------*/
 
 static int
 _mesh_location_define(const char               *name,
                       cs_mesh_location_type_t   type)
 {
-  /* local variables */
+  int  i;
 
-  int    i;
-  cs_mesh_location_t  *ml;
+  cs_mesh_location_t  *ml = NULL;
 
-  int id = _n_mesh_locations;
+  /* Check if there is already a mesh location with the same name */
+  int id = _find_id_by_name(name);
+
+  if (id == -1) /* Not found in the current list */
+    id = _n_mesh_locations;
+
+  else { /* A mesh location shares the same name */
+    ml = _mesh_location + id;
+    if (ml->type != type)
+      bft_error(__FILE__, __LINE__, 0,
+                _(" The mesh location %s is already defined as a mesh location"
+                  " but with a different type.\n"
+                  " Please check your settings."), name);
+    return id;
+  }
 
   /* Allocate new locations if necessary */
-
   if (_n_mesh_locations >= _n_mesh_locations_max) {
     if (_n_mesh_locations_max == 0)
       _n_mesh_locations_max = 4;
@@ -203,11 +254,9 @@ _mesh_location_define(const char               *name,
                 _n_mesh_locations_max,
                 cs_mesh_location_t);
   }
-
   _n_mesh_locations++;
 
   /* Define mesh location */
-
   ml = _mesh_location + id;
 
   ml->mesh = NULL;
@@ -219,16 +268,122 @@ _mesh_location_define(const char               *name,
 
   ml->select_str = NULL;
   ml->select_fp = NULL;
+  ml->n_sub_ids = 0;
+  ml->sub_ids = NULL;
+  ml->complement = false;
 
   for (i = 0; i < 3; i++)
     ml->n_elts[i] = 0;
-
   ml->elt_list = NULL;
 
   return id;
 }
 
-/*! (DOXYGEN_SHOULD_SKIP_THIS) \endcond */
+/*----------------------------------------------------------------------------
+ * \brief Build a list of element ids from a list of existing mesh location
+ *        ids
+ *
+ * \param[in]  name      name of location to define
+ * \param[in]  type      type of location to define
+ */
+/*----------------------------------------------------------------------------*/
+
+static void
+_build_by_ml_ids(cs_mesh_location_t  *ml)
+{
+  int  i, count;
+
+  cs_lnum_t  n_elts_max = 0;
+
+  switch(ml->type) {
+  case CS_MESH_LOCATION_CELLS:
+    n_elts_max = ml->mesh->n_cells;
+    break;
+  case CS_MESH_LOCATION_FACES:
+    n_elts_max = ml->mesh->n_b_faces + ml->mesh->n_i_faces;
+    break;
+  case CS_MESH_LOCATION_INTERIOR_FACES:
+    n_elts_max = ml->mesh->n_i_faces;
+    break;
+  case CS_MESH_LOCATION_BOUNDARY_FACES:
+    n_elts_max = ml->mesh->n_b_faces;
+    break;
+  case CS_MESH_LOCATION_VERTICES:
+    n_elts_max = ml->mesh->n_vertices;
+    break;
+  default:
+    assert(0);
+    break;
+  }
+
+  if (ml->n_sub_ids == 1 && ml->complement == false) {
+
+    int  sub_id = ml->sub_ids[0];
+    assert(sub_id < _n_mesh_locations);
+    cs_mesh_location_t  *sub_ml = _mesh_location + sub_id;
+    assert(sub_ml->type == ml->type);
+
+    ml->n_elts[0] = sub_ml->n_elts[0];
+    if (sub_ml->elt_list != NULL) { /* Copy */
+      BFT_MALLOC(ml->elt_list, ml->n_elts[0], cs_lnum_t);
+      memcpy(ml->elt_list, sub_ml->elt_list, ml->n_elts[0]*sizeof(cs_lnum_t));
+    }
+
+  }
+  else {
+
+    bool  *flag = NULL;
+
+    /* Initialize flag */
+    BFT_MALLOC(flag, n_elts_max, bool);
+    for (i = 0; i < n_elts_max; i++)
+      flag[i] = false;
+
+    /* Build flag */
+    for (int ii = 0; ii < ml->n_sub_ids; ii++) {
+
+      int  sub_id = ml->sub_ids[ii];
+      assert(sub_id < _n_mesh_locations);
+      cs_mesh_location_t  *sub_ml = _mesh_location + sub_id;
+      assert(sub_ml->type == ml->type);
+
+      if (sub_ml->elt_list == NULL)
+        for (i = 0; i < n_elts_max; i++)
+          flag[i] = true;
+      else
+        for (i = 0; i < sub_ml->n_elts[0]; i++)
+          flag[sub_ml->elt_list[i]] = true;
+
+    } /* Loop on (sub) mesh locations */
+
+    if (ml->complement) {
+      for (i = 0; i < n_elts_max; i++) {
+        if (flag[i])
+          flag[i] = false;
+        else 
+          flag[i] = true;
+      }
+    }
+
+    /* Compute n_elts[0] */
+    count = 0;
+    for (i = 0; i < n_elts_max; i++)
+      if (flag[i]) count++;
+    ml->n_elts[0] = count;
+
+    /* Build elt_list */
+    if (ml->n_elts[0] != 0 && ml->n_elts[0] != n_elts_max) {
+      BFT_MALLOC(ml->elt_list, ml->n_elts[0], cs_lnum_t);
+      count = 0;
+      for (i = 0; i < n_elts_max; i++)
+        if (flag[i]) ml->elt_list[count++] = i;
+    }
+
+    BFT_FREE(flag);
+
+  } /* If simple case (n_sub_ids = 1 and no complement) or not */
+
+}
 
 /*=============================================================================
  * Public function definitions
@@ -252,11 +407,13 @@ cs_mesh_location_n_locations(void)
 /*!
  * \brief Initialize mesh location API.
  *
- * By default, 5 mesh locations are built, matching the 5 first values of
+ * By default, 7 mesh locations are built, matching the 7 first values of
  * the cs_mesh_location_type_t enum: CS_MESH_LOCATION_NONE for global
  * values, CS_MESH_LOCATION_CELLS for the cells of the (default) global mesh,
  * CS_MESH_LOCATION_INTERIOR_FACES and CS_MESH_LOCATION_BOUNDARY_FACES for
  * its faces, and CS_MESH_LOCATION_VERTICES for its vertices.
+ * CS_MESH_LOCATION_FACES and a placeholder for CS_MESH_LOCATION_EDGES are
+ * also added for CDO discretizations.
  *
  * Locations should then be built once the global mesh is complete, and
  * its halo structures completed.
@@ -266,21 +423,27 @@ cs_mesh_location_n_locations(void)
 void
 cs_mesh_location_initialize(void)
 {
-  cs_mesh_location_define(N_("global"),
-                          CS_MESH_LOCATION_NONE,
-                          NULL);
-  cs_mesh_location_define(N_("cells"),
-                          CS_MESH_LOCATION_CELLS,
-                          NULL);
-  cs_mesh_location_define(N_("interior_faces"),
-                          CS_MESH_LOCATION_INTERIOR_FACES,
-                          NULL);
-  cs_mesh_location_define(N_("boundary_faces"),
-                          CS_MESH_LOCATION_BOUNDARY_FACES,
-                          NULL);
-  cs_mesh_location_define(N_("vertices"),
-                          CS_MESH_LOCATION_VERTICES,
-                          NULL);
+  cs_mesh_location_add(N_("global"),
+                       CS_MESH_LOCATION_NONE,
+                       NULL);
+  cs_mesh_location_add(N_("cells"),
+                       CS_MESH_LOCATION_CELLS,
+                       NULL);
+  cs_mesh_location_add(N_("interior_faces"),
+                       CS_MESH_LOCATION_INTERIOR_FACES,
+                       NULL);
+  cs_mesh_location_add(N_("boundary_faces"),
+                       CS_MESH_LOCATION_BOUNDARY_FACES,
+                       NULL);
+  cs_mesh_location_add(N_("vertices"),
+                       CS_MESH_LOCATION_VERTICES,
+                       NULL);
+  cs_mesh_location_add(N_("faces"),
+                       CS_MESH_LOCATION_FACES,
+                       NULL);
+  cs_mesh_location_add(N_("edges (type)"),
+                       CS_MESH_LOCATION_EDGES,
+                       NULL);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -295,9 +458,10 @@ cs_mesh_location_finalize(void)
   int  i;
 
   for (i = 0; i < _n_mesh_locations; i++) {
-    cs_mesh_location_t  *ml = _mesh_location;
+    cs_mesh_location_t  *ml = _mesh_location + i;
     BFT_FREE(ml->elt_list);
     BFT_FREE(ml->select_str);
+    BFT_FREE(ml->sub_ids);
   }
 
   _n_mesh_locations = 0;
@@ -327,7 +491,7 @@ void
 cs_mesh_location_build(cs_mesh_t  *mesh,
                        int         id)
 {
-  int  i;
+  int  ml_id;
   int id_start = 0, id_end = _n_mesh_locations;
 
   assert(mesh != NULL);
@@ -340,11 +504,11 @@ cs_mesh_location_build(cs_mesh_t  *mesh,
       id_end = id + 1;
   }
 
-  for (i = id_start; i < id_end; i++) {
+  for (ml_id = id_start; ml_id < id_end; ml_id++) {
 
     int n_elts_max = 0;
     fvm_selector_t *selector = NULL;
-    cs_mesh_location_t  *ml = _mesh_location + i;
+    cs_mesh_location_t  *ml = _mesh_location + ml_id;
 
     ml->mesh = mesh;
 
@@ -356,6 +520,9 @@ cs_mesh_location_build(cs_mesh_t  *mesh,
       selector = mesh->select_cells;
       n_elts_max = ml->mesh->n_cells;
       break;
+    case CS_MESH_LOCATION_FACES:
+      n_elts_max = ml->mesh->n_b_faces + ml->mesh->n_i_faces;
+      break;
     case CS_MESH_LOCATION_INTERIOR_FACES:
       selector = mesh->select_i_faces;
       n_elts_max = ml->mesh->n_i_faces;
@@ -394,17 +561,18 @@ cs_mesh_location_build(cs_mesh_t  *mesh,
         }
       }
       else
-        bft_error
-          (__FILE__, __LINE__, 0,
-           _("A selection criteria is given but no associated selector\n"
-             "is available for mesh location %d of type %d."),
-           i, (int)ml->type);
+        bft_error(__FILE__, __LINE__, 0,
+                  _("A selection criteria is given but no associated selector\n"
+                    "is available for mesh location %d of type %d."),
+                  ml_id, (int)ml->type);
     }
     else if (ml->select_fp != NULL)
       ml->select_fp(ml->mesh,
-                    i,
+                    ml_id,
                     ml->n_elts,
                     &(ml->elt_list));
+    else if (ml->n_sub_ids > 0 && ml->sub_ids != NULL)
+      _build_by_ml_ids(ml);
     else
       ml->n_elts[0] = n_elts_max;
 
@@ -419,7 +587,7 @@ cs_mesh_location_build(cs_mesh_t  *mesh,
       }
     }
 
-  }
+  } /* Loop on mesh locations */
 
 }
 
@@ -440,25 +608,24 @@ cs_mesh_location_build(cs_mesh_t  *mesh,
 /*----------------------------------------------------------------------------*/
 
 int
-cs_mesh_location_define(const char               *name,
-                        cs_mesh_location_type_t   type,
-                        const char               *criteria)
+cs_mesh_location_add(const char                *name,
+                     cs_mesh_location_type_t    type,
+                     const char                *criteria)
 {
-  int m_id = _mesh_location_define(name, type);
-
-  cs_mesh_location_t *ml = _mesh_location + m_id;
+  int  ml_id = _mesh_location_define(name, type);
+  cs_mesh_location_t  *ml = _mesh_location + ml_id;
 
   if (criteria != NULL) {
     BFT_MALLOC(ml->select_str, strlen(criteria) + 1, char);
     strcpy(ml->select_str, criteria);
   }
 
-  return m_id;
+  return ml_id;
 }
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief Define a new mesh location with a associated selection function.
+ * \brief Define a new mesh location with an associated selection function.
  *
  * So as to define a subset of mesh entities of a given type, a pointer
  * to a selection function may be given.
@@ -476,17 +643,90 @@ cs_mesh_location_define(const char               *name,
 /*----------------------------------------------------------------------------*/
 
 int
-cs_mesh_location_define_by_func(const char                 *name,
-                                cs_mesh_location_type_t     type,
-                                cs_mesh_location_select_t  *func)
+cs_mesh_location_add_by_func(const char                 *name,
+                             cs_mesh_location_type_t     type,
+                             cs_mesh_location_select_t  *func)
 {
-  int m_id = _mesh_location_define(name, type);
-
-  cs_mesh_location_t *ml = _mesh_location + m_id;
+  int  ml_id = _mesh_location_define(name, type);
+  cs_mesh_location_t  *ml = _mesh_location + ml_id;
 
   ml->select_fp = func;
 
-  return m_id;
+  return ml_id;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Define a new mesh location.
+ *
+ * So as to define a subset of mesh entities of a given type, a list of ids
+ * related to existing mesh locations may be given
+ *
+ * \param[in]  name        name of location to define
+ * \param[in]  type        type of location to define
+ * \param[in]  n_ml_ids    number of mesh location ids
+ * \param[in]  ml_ids      list of mesh location ids
+ * \param[in]  complement  take the complement of the selected entities if true
+ *
+ * \return  id of newly created mesh location
+ */
+/*----------------------------------------------------------------------------*/
+
+int
+cs_mesh_location_add_by_union(const char               *name,
+                              cs_mesh_location_type_t   type,
+                              int                       n_ml_ids,
+                              const int                *ml_ids,
+                              bool                      complement)
+{
+  int  ml_id = _mesh_location_define(name, type);
+  cs_mesh_location_t  *ml = _mesh_location + ml_id;
+
+  ml->complement = complement;
+  ml->n_sub_ids = n_ml_ids;
+  if (ml->n_sub_ids > 0) {
+    BFT_MALLOC(ml->sub_ids, ml->n_sub_ids, int);
+    for (int i = 0; i < ml->n_sub_ids; i++)
+      ml->sub_ids[i] = ml_ids[i];
+  }
+
+  return ml_id;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Find the related location id from the location name
+ *
+ * \param[in]  ref_name    name of the location to find
+ *
+ * \return -1 if not found otherwise the associated id
+ */
+/*----------------------------------------------------------------------------*/
+
+int
+cs_mesh_location_get_id_by_name(const char  *ref_name)
+{
+  int  i, ml_id = -1;
+
+  return _find_id_by_name(ref_name);
+
+  int  reflen = strlen(ref_name);
+
+  for (i = 0; i < _n_mesh_locations; i++) {
+
+    cs_mesh_location_t  *ml = _mesh_location + i;
+    int len = strlen(ml->name);
+
+    if (reflen == len) {
+      if (strcmp(ref_name, ml->name) == 0) {
+        ml_id = i;
+        break;
+      }
+    }
+
+  } /* Loops on mesh locations */
+
+  return ml_id;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -500,7 +740,7 @@ cs_mesh_location_define_by_func(const char                 *name,
 /*----------------------------------------------------------------------------*/
 
 const char *
-cs_mesh_location_get_name(int id)
+cs_mesh_location_get_name(int  id)
 {
   const cs_mesh_location_t  *ml = _const_mesh_location_by_id(id);
 
@@ -518,7 +758,7 @@ cs_mesh_location_get_name(int id)
 /*----------------------------------------------------------------------------*/
 
 cs_mesh_location_type_t
-cs_mesh_location_get_type(int id)
+cs_mesh_location_get_type(int  id)
 {
   const cs_mesh_location_t  *ml = _const_mesh_location_by_id(id);
 
