@@ -106,6 +106,9 @@ static bool _compute_cocg_s_lsq = false;
 static bool _compute_cocg_it = false;
 static bool _compute_cocg_lsq = false;
 
+/* Choice of the porous model */
+int cs_glob_porous_model = 0;
+
 /* Number of computation updates */
 
 static int _n_computations = 0;
@@ -1363,7 +1366,8 @@ _compute_cell_cen_face(const cs_mesh_t  *mesh,
   const  cs_lnum_t  n_b_faces = mesh->n_b_faces;
   const  cs_lnum_t  n_cells = mesh->n_cells;
   const  cs_lnum_t  n_cells_with_ghosts = mesh->n_cells_with_ghosts;
-  const  cs_lnum_2_t  *i_face_cells = mesh->i_face_cells;
+  const  cs_lnum_2_t  *i_face_cells
+    = (const cs_lnum_2_t *)(mesh->i_face_cells);
   const  cs_lnum_t  *b_face_cells = mesh->b_face_cells;
 
   /* Return if ther is not enough data (Solcom case except rediative module
@@ -1955,6 +1959,23 @@ CS_PROCF (comcoc, COMCOC) (const cs_int_t  *const imrgra)
   cs_mesh_quantities_set_cocg_options(*imrgra);
 }
 
+/*----------------------------------------------------------------------------
+ * Set porous model
+ *
+ * Fortran interface :
+ *
+ * subroutine compor (iporos)
+ * *****************
+ *
+ * integer          iporos        : <-- : porous model
+ *----------------------------------------------------------------------------*/
+
+void
+CS_PROCF (compor, COMPOR) (const cs_int_t  *const iporos)
+{
+  cs_mesh_quantities_set_porous_model(*iporos);
+}
+
 /*=============================================================================
  * Public function definitions
  *============================================================================*/
@@ -2046,6 +2067,19 @@ cs_mesh_quantities_set_cocg_options(int  gradient_option)
   _compute_cocg_lsq = _compute_cocg_s_lsq;
 }
 
+/*----------------------------------------------------------------------------
+ * Compute Fluid volumes and fluid surface in addition to cell volume and surfaces.
+ *
+ * parameters:
+ *   porous_model <-- gradient option (Fortran iporos)
+ *----------------------------------------------------------------------------*/
+
+void
+cs_mesh_quantities_set_porous_model(int  porous_model)
+{
+  cs_glob_porous_model = porous_model;
+}
+
 /*----------------------------------------------------------------------------
  * Create a mesh quantities structure.
  *
@@ -2064,10 +2098,14 @@ cs_mesh_quantities_create(void)
   mesh_quantities->cell_vol = NULL;
   mesh_quantities->i_face_normal = NULL;
   mesh_quantities->b_face_normal = NULL;
+  mesh_quantities->i_f_face_normal = NULL;
+  mesh_quantities->b_f_face_normal = NULL;
   mesh_quantities->i_face_cog = NULL;
   mesh_quantities->b_face_cog = NULL;
   mesh_quantities->i_face_surf = NULL;
   mesh_quantities->b_face_surf = NULL;
+  mesh_quantities->i_f_face_surf = NULL;
+  mesh_quantities->b_f_face_surf = NULL;
   mesh_quantities->i_dist = NULL;
   mesh_quantities->b_dist = NULL;
   mesh_quantities->weight = NULL;
@@ -2083,6 +2121,7 @@ cs_mesh_quantities_create(void)
   mesh_quantities->cocg_it = NULL;
   mesh_quantities->cocg_lsq = NULL;
   mesh_quantities->b_sym_flag = NULL;
+  mesh_quantities->c_solid_flag = NULL;
   mesh_quantities->bad_cell_flag = NULL;
 
   return (mesh_quantities);
@@ -2103,12 +2142,22 @@ cs_mesh_quantities_destroy(cs_mesh_quantities_t  *mesh_quantities)
 
   BFT_FREE(mesh_quantities->cell_cen);
   BFT_FREE(mesh_quantities->cell_vol);
+  if (cs_glob_porous_model > 0)
+    BFT_FREE(mesh_quantities->cell_f_vol);
   BFT_FREE(mesh_quantities->i_face_normal);
   BFT_FREE(mesh_quantities->b_face_normal);
+  if (cs_glob_porous_model == 3) {
+    BFT_FREE(mesh_quantities->i_f_face_normal);
+    BFT_FREE(mesh_quantities->b_f_face_normal);
+  }
   BFT_FREE(mesh_quantities->i_face_cog);
   BFT_FREE(mesh_quantities->b_face_cog);
   BFT_FREE(mesh_quantities->i_face_surf);
   BFT_FREE(mesh_quantities->b_face_surf);
+  if (cs_glob_porous_model == 3) {
+    BFT_FREE(mesh_quantities->i_f_face_surf);
+    BFT_FREE(mesh_quantities->b_f_face_surf);
+  }
   BFT_FREE(mesh_quantities->i_dist);
   BFT_FREE(mesh_quantities->b_dist);
   BFT_FREE(mesh_quantities->weight);
@@ -2124,6 +2173,7 @@ cs_mesh_quantities_destroy(cs_mesh_quantities_t  *mesh_quantities)
   BFT_FREE(mesh_quantities->cocg_it);
   BFT_FREE(mesh_quantities->cocg_lsq);
   BFT_FREE(mesh_quantities->b_sym_flag);
+  BFT_FREE(mesh_quantities->c_solid_flag);
   BFT_FREE(mesh_quantities->bad_cell_flag);
 
   BFT_FREE(mesh_quantities);
@@ -2163,6 +2213,21 @@ cs_mesh_quantities_compute(const cs_mesh_t       *mesh,
   if (mesh_quantities->b_face_normal == NULL)
     BFT_MALLOC(mesh_quantities->b_face_normal, n_b_faces*dim, cs_real_t);
 
+  /* Balance porous model */
+  if (cs_glob_porous_model == 3) {
+
+    if (mesh_quantities->i_f_face_normal == NULL)
+      BFT_MALLOC(mesh_quantities->i_f_face_normal, n_i_faces*dim, cs_real_t);
+
+    if (mesh_quantities->b_f_face_normal == NULL)
+      BFT_MALLOC(mesh_quantities->b_f_face_normal, n_b_faces*dim, cs_real_t);
+
+  }
+  else {
+    mesh_quantities->i_f_face_normal = mesh_quantities->i_face_normal;
+    mesh_quantities->b_f_face_normal = mesh_quantities->b_face_normal;
+  }
+
   if (mesh_quantities->b_face_cog == NULL)
     BFT_MALLOC(mesh_quantities->b_face_cog, n_b_faces*dim, cs_real_t);
 
@@ -2172,12 +2237,47 @@ cs_mesh_quantities_compute(const cs_mesh_t       *mesh,
   if (mesh_quantities->cell_vol == NULL)
     BFT_MALLOC(mesh_quantities->cell_vol, n_cells_with_ghosts, cs_real_t);
 
+  /* Porous models */
+  if (cs_glob_porous_model > 0) {
+    if (mesh_quantities->cell_f_vol == NULL)
+      BFT_MALLOC(mesh_quantities->cell_f_vol, n_cells_with_ghosts, cs_real_t);
+
+    if (mesh_quantities->c_solid_flag == NULL) {
+      BFT_MALLOC(mesh_quantities->c_solid_flag, n_cells_with_ghosts, cs_int_t);
+      for (cs_lnum_t cell_id = 0; cell_id < n_cells_with_ghosts; cell_id++)
+        mesh_quantities->c_solid_flag[cell_id] = 0;
+    }
+
+  }
+  else {
+    mesh_quantities->cell_f_vol = mesh_quantities->cell_vol;
+
+    if (mesh_quantities->c_solid_flag == NULL) {
+      BFT_MALLOC(mesh_quantities->c_solid_flag, 1, cs_int_t);
+      mesh_quantities->c_solid_flag[0] = 0;
+    }
+  }
+
   if (mesh_quantities->i_face_surf == NULL)
     BFT_MALLOC(mesh_quantities->i_face_surf, n_i_faces, cs_real_t);
 
   if (mesh_quantities->b_face_surf == NULL)
     BFT_MALLOC(mesh_quantities->b_face_surf, n_b_faces, cs_real_t);
 
+  /* Balance porous model */
+  if (cs_glob_porous_model == 3) {
+
+    if (mesh_quantities->i_f_face_surf == NULL)
+      BFT_MALLOC(mesh_quantities->i_f_face_surf, n_i_faces, cs_real_t);
+
+    if (mesh_quantities->b_f_face_surf == NULL)
+      BFT_MALLOC(mesh_quantities->b_f_face_surf, n_b_faces, cs_real_t);
+  }
+  else {
+    mesh_quantities->i_f_face_surf = mesh_quantities->i_face_surf;
+    mesh_quantities->b_f_face_surf = mesh_quantities->b_face_surf;
+  }
+
   if (mesh_quantities->i_dist == NULL)
     BFT_MALLOC(mesh_quantities->i_dist, n_i_faces, cs_real_t);
 
