@@ -103,6 +103,7 @@ use radiat
 use dimens, only: ndimfb
 use mesh
 use field
+use cs_c_bindings
 
 !===============================================================================
 
@@ -253,7 +254,6 @@ if (ipacli.eq.1 .and. isuird.eq.0) then
     !---> NUMERO DU SCALAIRE ET DE LA VARIABLE THERMIQUE
 
     call uiray2 &
-    !==========
    ( itypfb, iparoi, iparug, ivart , izfrad,                  &
      isothm, itpimp, ipgrno, iprefl, ifgrno, ifrefl,          &
      nozppm, nfabor, nvar,                                    &
@@ -264,7 +264,6 @@ if (ipacli.eq.1 .and. isuird.eq.0) then
   endif
 
   call cs_user_radiative_transfer_bcs &
-  !==========
 ( nvar   , nscal  ,                                              &
   itypfb ,                                                       &
   icodcl , izfrad , isothm ,                                     &
@@ -310,7 +309,6 @@ enddo
 if (iihmpr.eq.1) then
 
   call uiray2 &
-  !==========
 ( itypfb, iparoi, iparug, ivart , izfrad,                       &
   isothm, itpimp, ipgrno, iprefl, ifgrno, ifrefl,               &
   nozppm, nfabor, nvar,                                         &
@@ -320,7 +318,6 @@ if (iihmpr.eq.1) then
 endif
 
 call cs_user_radiative_transfer_bcs &
-!==========
 ( nvar   , nscal  ,                                              &
   itypfb ,                                                       &
   icodcl , izfrad , isothm ,                                     &
@@ -611,7 +608,7 @@ if (iok.ne.0) then
                        rvferr(24), rvferr(25)
   endif
 
-  call bcderr(itypfb)
+  call cs_boundary_conditions_error(itypfb)
 
 endif
 
@@ -671,7 +668,6 @@ elseif (itherm.eq.2) then
   if (ippmod(iphpar).le.1) then
 
     call usray4 &
-    !==========
  ( nvar   , nscal  ,                                              &
    mode   ,                                                       &
    itypfb ,                                                       &
@@ -682,7 +678,6 @@ elseif (itherm.eq.2) then
   else
 
     call ppray4 &
-    !==========
  ( mode   ,                                                       &
    itypfb ,                                                       &
    propce ,                                                       &
@@ -738,7 +733,6 @@ endif
 if (ideb.eq.0) then
 
   call raypar &
-  !==========
  ( isothm , izfrad ,                                              &
    tmin   , tmax   , tx     ,                                     &
    rcodcl ,                                                       &
@@ -812,7 +806,6 @@ elseif (itherm.eq.2) then
     if (ippmod(iphpar).le.1) then
 
       call usray4 &
-      !==========
     ( nvar   , nscal  ,                                              &
       mode   ,                                                       &
       itypfb ,                                                       &
@@ -824,7 +817,6 @@ elseif (itherm.eq.2) then
     else
 
       call ppray4 &
-      !==========
     ( mode   ,                                                       &
       itypfb ,                                                       &
       propce ,                                                       &
@@ -849,7 +841,6 @@ elseif (itherm.eq.2) then
     if (ippmod(iphpar).le.1) then
 
       call usray4 &
-      !==========
     ( nvar   , nscal  ,                                              &
       mode   ,                                                       &
       itypfb ,                                                       &
@@ -860,7 +851,6 @@ elseif (itherm.eq.2) then
     else
 
       call ppray4 &
-      !==========
     ( mode   ,                                                       &
       itypfb ,                                                       &
       propce ,                                                       &
