@@ -21,7 +21,6 @@
 !-------------------------------------------------------------------------------
 
 subroutine rayopt
-!================
 
 !===============================================================================
 !  FONCTION  :
@@ -109,6 +108,12 @@ enddo
 
 imodak = 0
 
+!-->  IMOADF = 0 on n'utilise pas les model ADF
+!            = 1 Model ADF a 8 intervalle de longueur d'onde
+!            = 2 Model ADF a 50 intervalle de longueur d'onde
+
+imoadf = 0
+
 !-->  INDICATEUR SUITE DE CALCUL (LECTURE DU FICHIER SUITE)
 
 isuird = isuite
@@ -143,6 +148,11 @@ iimpar = 1
 
 iimlum = 0
 
+!--> Number of iterations used to solve the ETR. Must at least be one to make
+!    the stanard models work.
+
+nwsgg  = 1
+
 !   - Interface Code_Saturne
 !     ======================
 
@@ -155,6 +165,12 @@ endif
 ! User paramters
 call cs_user_radiative_transfer_param
 
+if (imoadf.eq.1) then
+  nwsgg = 8
+elseif (imoadf.eq.2) then
+  nwsgg = 50
+endif
+
 !===============================================================================
 ! 2. VERIFICATION LA COHERENCE D'UTILISATION DU MODULE DE RAYONNEMENT
 !    AVEC LA THERMIQUE OU LES PHYSIQUES PARTICULIERES (COMBUSTION)
@@ -241,7 +257,6 @@ if (iirayo.gt.0) then
 ! Positionnement des pointeurs
 
   call rayprp
-  !==========
 
 ! --> ISUIRD
 
@@ -323,16 +338,13 @@ call raydir
 if (iihmpr.eq.1) then
 
   call uiray4(iirayo)
-  !==========
 
   call csenso                                                     &
-  !==========
      ( nvppmx, ncapt,  nthist, frhist, ntlist, iecaux,            &
        ihisvr, tplfmt, xyzcap )
 
   ! take into acount user modifications
   call usipes(nmodpp)
-  !==========
 
 endif
 
