@@ -96,8 +96,8 @@ double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 
 character(len=80) :: chaine
 integer          iel   , ifac  , inc   , iprev,  iccocg, ivar
-integer          ii, iivar , iiun  , ifacpt
-integer          iclipk, iclipw, isqrt
+integer          ii, f_id , iiun  , ifacpt
+integer          iclipk, iclipw
 integer          nswrgp, imligp
 integer          iconvp, idiffp, ndircp
 integer          nswrsp, ircflp, ischcp, isstpp, iescap
@@ -345,7 +345,6 @@ if (irccor.eq.1) then
 
   ! Compute the rotation function (gdkgdw array not used)
   call rotcor(dt, rotfct, gdkgdw)
-  !==========
 
   do iel = 1, ncel
     prodk(iel) = prodk(iel)*rotfct(iel)
@@ -365,7 +364,7 @@ endif
 if (igrake.eq.1) then
 
   ! Allocate a temporary array for the gradient calculation
-  allocate(grad(ncelet,3))
+  allocate(grad(3,ncelet))
 
   ! --- Buoyant term:     G = Beta*g*GRAD(T)/PrT/rho
   !     Here is computed: G =-g*GRAD(rho)/PrT/rho
@@ -387,12 +386,11 @@ if (igrake.eq.1) then
     viscb(ifac) = 0.d0
   enddo
 
-  iivar = 0
+  f_id = -1
 
-  call grdcel &
-  !==========
- ( iivar  , imrgra , inc    , iccocg , nswrgp , imligp ,          &
-   iwarnp , nfecra , epsrgp , climgp , extrap ,                   &
+  call gradient_s                                                 &
+ ( f_id   , imrgra , inc    , iccocg , nswrgp , imligp ,          &
+   iwarnp , epsrgp , climgp , extrap ,                            &
    cromo  , bromo  , viscb  ,                                     &
    grad   )
 
@@ -410,7 +408,7 @@ if (igrake.eq.1) then
     rho = cromo(iel)
     visct = cpro_pcvto(iel)
 
-    w2(iel) = -(grad(iel,1)*gx + grad(iel,2)*gy + grad(iel,3)*gz) / &
+    w2(iel) = -(grad(1,iel)*gx + grad(2,iel)*gy + grad(3,iel)*gz) / &
                (rho*prdtur)
 
     prodw(iel) = prodw(iel)+visct*max(w2(iel),zero)
@@ -442,7 +440,6 @@ do iel = 1, ncel
 enddo
 
 call cs_user_turbulence_source_terms &
-!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivarfl(ik)      ,                                              &
    icepdc , icetsm , itypsm ,                                     &
@@ -450,7 +447,6 @@ call cs_user_turbulence_source_terms &
    smbrk  , usimpk )
 
 call cs_user_turbulence_source_terms &
-!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivarfl(iomg)    ,                                              &
    icepdc , icetsm , itypsm ,                                     &
@@ -591,7 +587,6 @@ if (ncesmp.gt.0) then
   ivar = ik
 
   call catsma &
-  !==========
  ( ncelet , ncel   , ncesmp , iiun   ,                            &
    isto2t , thetav(ivar) ,                                        &
    icetsm , itypsm(1,ivar) ,                                      &
@@ -601,7 +596,6 @@ if (ncesmp.gt.0) then
   ivar = iomg
 
   call catsma &
-  !==========
  ( ncelet , ncel   , ncesmp , iiun   ,                            &
    isto2t , thetav(ivar) ,                                        &
    icetsm , itypsm(1,ivar) ,                                      &
@@ -705,7 +699,6 @@ if (ikecou.eq.1) then
               + idifft(ivar)*cvisct(iel)/sigma
     enddo
     call viscfa &
-    !==========
  ( imvisf ,                                                       &
    w7     ,                                                       &
    viscf  , viscb  )
@@ -743,7 +736,6 @@ if (ikecou.eq.1) then
   icvflb = 0
 
   call bilsca &
-  !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
    iwarnp , imucpp , idftnp ,                                     &
@@ -757,8 +749,7 @@ if (ikecou.eq.1) then
    w5     )
 
   if (iwarni(ivar).ge.2) then
-    isqrt = 1
-    call prodsc(ncel,isqrt,smbrk,smbrk,rnorm)
+    rnorm = sqrt(cs_gdot(ncel,smbrk,smbrk))
     write(nfecra,1100) chaine(1:8) ,rnorm
   endif
 
@@ -775,7 +766,6 @@ if (ikecou.eq.1) then
               + idifft(ivar)*cvisct(iel)/sigma
     enddo
     call viscfa &
-    !==========
  ( imvisf ,                                                       &
    w7     ,                                                       &
    viscf  , viscb  )
@@ -813,7 +803,6 @@ if (ikecou.eq.1) then
   icvflb = 0
 
   call bilsca &
-  !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
    iwarnp , imucpp , idftnp ,                                     &
@@ -827,8 +816,7 @@ if (ikecou.eq.1) then
    w6     )
 
   if (iwarni(ivar).ge.2) then
-    isqrt = 1
-    call prodsc(ncel,isqrt,smbrw,smbrw,rnorm)
+    rnorm = sqrt(cs_gdot(ncel,smbrw,smbrw))
     write(nfecra,1100) chaine(1:8) ,rnorm
   endif
 
@@ -927,7 +915,6 @@ if (idiff(ivar).ge. 1) then
              + idifft(ivar)*cvisct(iel)/sigma
   enddo
   call viscfa &
-  !==========
  ( imvisf ,                                                       &
    w1     ,                                                       &
    viscf  , viscb  )
@@ -970,7 +957,6 @@ thetap = thetav(ivar)
 icvflb = 0
 
 call codits &
-!==========
  ( idtvar , ivar   , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
    ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
@@ -998,7 +984,6 @@ if (idiff(ivar).ge. 1) then
                         + idifft(ivar)*cvisct(iel)/sigma
   enddo
   call viscfa &
-  !==========
  ( imvisf ,                                                       &
    w1     ,                                                       &
    viscf  , viscb  )
@@ -1041,7 +1026,6 @@ thetap = thetav(ivar)
 icvflb = 0
 
 call codits &
-!==========
  ( idtvar , ivar   , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
    ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
