@@ -147,7 +147,7 @@ double precision crvexp(3,ncelet), crvimp(3,3,ncelet)
 
 ! Local variables
 
-character*80     chaine
+character(len=80) :: chaine
 integer          iel
 double precision ckp, qdm
 
@@ -197,8 +197,8 @@ call field_get_val_s(icrom, cpro_rom)
 !  MMT = 100.d0 [kg/m2/s2] (momentum production by volume and time unit)
 !
 !which yields:
-!     crvimp(1, 1, iel) = volume(iel)* A = - volume(iel)*(rho*CKP )
-!     crvexp(1, iel) = volume(iel)* B = volume(iel)*(XMMT)
+!     crvimp(1, 1, iel) = cell_f_vol(iel)* A = - cell_f_vol(iel)*(rho*CKP )
+!     crvexp(1, iel) = cell_f_vol(iel)* B = cell_f_vol(iel)*(XMMT)
 
 ! ----------------------------------------------
 
@@ -214,11 +214,11 @@ ckp  = 10.d0
 qdm  = 100.d0
 
 do iel = 1, ncel
-  crvimp(1, 1, iel) = - volume(iel)*cpro_rom(iel)*ckp
+  crvimp(1, 1, iel) = - cell_f_vol(iel)*cpro_rom(iel)*ckp
 enddo
 
 do iel = 1, ncel
-  crvexp(1, iel) = volume(iel)*qdm
+  crvexp(1, iel) = cell_f_vol(iel)*qdm
 enddo
 
 !--------
@@ -293,7 +293,7 @@ end subroutine ustsnv
 ! WARNING: If scalar is the temperature, the resulting equation
 !          solved by the code is:
 !
-!  rho*Cp*volume*dT/dt + .... = crvimp*T + crvexp
+!  rho*Cp*cell_f_vol*dT/dt + .... = crvimp*T + crvexp
 !
 !
 ! Note that crvexp and crvimp are defined after the Finite Volume integration
@@ -312,7 +312,7 @@ end subroutine ustsnv
 !   where f(n) is the value of f at time tn, the beginning of the time step.
 !
 ! This yields :
-!   crvexp = volume*F(f(n))
+!   crvexp = cell_f_vol*F(f(n))
 !   crvimp = 0
 !
 ! However, if the source term is potentially steep, this fully explicit
@@ -322,8 +322,8 @@ end subroutine ustsnv
 !   df/dt = .... + dF/df*f(n+1) - dF/df*f(n) + F(f(n))
 !
 ! This yields:
-!   crvexp = volume*( F(f(n)) - dF/df*f(n) )
-!   crvimp = volume*dF/df
+!   crvexp = cell_f_vol*( F(f(n)) - dF/df*f(n) )
+!   crvimp = cell_f_vol*dF/df
 
 !-------------------------------------------------------------------------------
 ! Arguments
@@ -389,11 +389,11 @@ double precision crvexp(ncelet), crvimp(ncelet)
 
 ! Local variables
 
-character*80     chaine
+character(len=80) :: chaine
 integer          ivar, iiscvr,  iel
 integer          ilelt, nlelt
 
-double precision tauf, prodf, volf, pwatt
+double precision tauf, prodf, voltf, pwatt
 
 integer, allocatable, dimension(:) :: lstelt
 double precision, dimension(:), pointer ::  cpro_rom
@@ -455,8 +455,8 @@ endif
 !     prodf  = 100.d0 [ [f]/s ] (production of f by unit of time)
 
 !which yields
-!     crvimp(iel) = volume(iel)* A = - volume(iel)*rho/tauf
-!     crvexp(iel) = volume(iel)* B =   volume(iel)*rho*prodf
+!     crvimp(iel) = cell_f_vol(iel)* A = - cell_f_vol(iel)*rho/tauf
+!     crvexp(iel) = cell_f_vol(iel)* B =   cell_f_vol(iel)*rho*prodf
 
 !===============================================================================
 
@@ -478,11 +478,11 @@ if (iscal.eq.2) then
    prodf = 100.d0
 
    do iel = 1, ncel
-      crvimp(iel) = - volume(iel)*cpro_rom(iel)/tauf
+      crvimp(iel) = - cell_f_vol(iel)*cpro_rom(iel)/tauf
    enddo
 
    do iel = 1, ncel
-      crvexp(iel) =   volume(iel)*cpro_rom(iel)*prodf
+      crvexp(iel) =   cell_f_vol(iel)*cpro_rom(iel)*prodf
    enddo
 
 endif
@@ -494,11 +494,11 @@ endif
 ! in the cells with coordinate X in [0;1.2] and Y in [3.1;4]
 
 ! The global heating power if Pwatt (in W) and the total volume of the selected
-! cells is volf (in m3)
+! cells is voltf (in m3)
 
 ! This yields
 !     crvimp(iel) = 0
-!     crvexp(iel) = volume(iel)* Pwatt/volf
+!     crvexp(iel) = cell_f_vol(iel)* Pwatt/voltf
 
 !===============================================================================
 
@@ -519,23 +519,23 @@ if (.true.) return
 ! by Cp because Cp is put outside the diffusion term and multiplied
 ! in the temperature equation as follows:
 !
-!  rho*Cp*volume*dT/dt + .... =  volume(iel)* Pwatt/volf
+!  rho*Cp*cell_f_vol*dT/dt + .... =  cell_f_vol(iel)* Pwatt/voltf
 
 pwatt = 100.d0
 
-! calculation of volf
+! calculation of voltf
 
-volf  = 0.d0
+voltf  = 0.d0
 call getcel('x > 0.0 and x < 1.2 and y > 3.1 and '//               &
             'y < 4.0', nlelt, lstelt)
 
 do ilelt = 1, nlelt
   iel = lstelt(ilelt)
-  volf = volf + volume(iel)
+  voltf = voltf + cell_f_vol(iel)
 enddo
 
 if (irangp.ge.0) then
-  call parsom(volf)
+  call parsom(voltf)
 endif
 
 do ilelt = 1, nlelt
@@ -543,7 +543,7 @@ do ilelt = 1, nlelt
 ! No implicit source term
   crvimp(iel) = 0.d0
 ! Explicit source term
-  crvexp(iel) = volume(iel)*pwatt/volf
+  crvexp(iel) = cell_f_vol(iel)*pwatt/voltf
 enddo
 
 !--------
@@ -680,11 +680,12 @@ double precision ff, tau
 
 type(var_cal_opt) vcopt
 
-character*80     fname
+character(len=80) :: fname
 
 integer, allocatable, dimension(:) :: lstelt
 double precision, dimension(:), pointer ::  cpro_rom
 double precision, dimension(:), pointer ::  cvar_var
+
 !===============================================================================
 
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_START
@@ -722,8 +723,8 @@ endif
 !    (Source term on the TKE 'k' here)
 
 !      Source term for cvar_var:
-!         rho volume d(cvar_var)/dt       = ...
-!                        ... - rho*volume*ff - rho*volume*cvar_var/tau
+!         rho cell_f_vol d(cvar_var)/dt       = ...
+!                        ... - rho*cell_f_vol*ff - rho*cell_f_vol*cvar_var/tau
 
 !      With ff=3.d0 and tau = 4.d0
 
@@ -747,13 +748,13 @@ if (.false.) then
 
     ! --- Explicit source terms
     do iel = 1, ncel
-      crvexp(iel) = -cpro_rom(iel)*volume(iel)*ff
+      crvexp(iel) = -cpro_rom(iel)*cell_f_vol(iel)*ff
     enddo
 
     ! --- Implicit source terms
     !        crvimp is already initialized to 0, no need to set it here
     do iel = 1, ncel
-      crvimp(iel) = -cpro_rom(iel)*volume(iel)/tau
+      crvimp(iel) = -cpro_rom(iel)*cell_f_vol(iel)/tau
     enddo
 
   endif
